package com.mints.goodmoney

import android.app.IntentService
import android.app.Notification
import android.content.Context
import android.content.Intent
import cn.jpush.android.api.BasicPushNotificationBuilder
import cn.jpush.android.api.JPushInterface
import com.downloader.PRDownloader
import com.downloader.PRDownloaderConfig
import com.mints.goodmoney.manager.BxmManager.initBxm
import com.mob.MobSDK

/**
 * 子线程初始化SDK
 */
class InitAppService : IntentService("InitializeService") {

    companion object {
        const val ACTION_INIT = "initApplication"
        var IS_DEBUG = BuildConfig.LOG_DEBUG

        /**
         * 开启intentService
         */
        fun start(context: Context) {
            try {
                val intent = Intent(context, InitAppService::class.java)
                intent.action = ACTION_INIT
                context.startService(intent)
            } catch (e: IllegalStateException) {
                e.printStackTrace()
            }
        }
    }

    private var isInit: Boolean = false

    override fun onHandleIntent(intent: Intent?) {
        if (isInit) return

        intent?.let {
            val action = intent.action
            if (ACTION_INIT == action) {

                initApplication()
                isInit = true
            }
        }
    }

    /**
     * 子线程进行初始化SDK操作【此处sdk属于非及时使用】
     */
    private fun initApplication() {
        // 初始化ShareSDK
        MobSDK.init(this)

        // 极光推送
        initJpush()

        // 变现猫
        initBxm(this.application)

        // PR下载附件
        initPRDownloader()

    }

    /**
     * PR下载附件
     */
    private fun initPRDownloader() {
        val config = PRDownloaderConfig.newBuilder()
                .setDatabaseEnabled(true)
                .build()
        PRDownloader.initialize(this, config)
    }

    /**
     * 绑定jpush
     */
    private fun initJpush() {
        JPushInterface.setDebugMode(BuildConfig.LOG_DEBUG) // 设置开启日志,发布时请关闭日志
        JPushInterface.init(this)
        val builder = BasicPushNotificationBuilder(applicationContext)
        builder.statusBarDrawable = R.mipmap.ic_launcher_main
        builder.notificationFlags = Notification.FLAG_AUTO_CANCEL //设置为自动消失
        builder.notificationDefaults = Notification.DEFAULT_SOUND or Notification.DEFAULT_VIBRATE or Notification.DEFAULT_LIGHTS // 设置为铃声与震动都要
        JPushInterface.setDefaultPushNotificationBuilder(builder)
    }
}