package com.mints.goodmoney.ad.download;

import androidx.annotation.Nullable;

import com.mints.goodmoney.MintsApplication;
import com.mints.goodmoney.common.Constant;
import com.mints.goodmoney.manager.UserManager;
import com.mints.goodmoney.utils.LogUtil;
import com.mints.library.utils.json.JsonUtil;
import com.tz.sdk.coral.ad.CoralAD;
import com.tz.sdk.coral.callback.CoralADListener;
import com.tz.sdk.coral.callback.h5.DownloadProcess;
import com.tz.sdk.coral.task.RewardTask;
import com.tz.sdk.core.ad.ADError;
import com.tz.sdk.core.ad.ADSource;
import com.tz.sdk.core.ad.ADType;
import com.tz.sdk.core.loader.ADLoader;

import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Random;

/**
 * 珊瑚CPD下载安装试玩
 */
public final class CoralDownload {

    /**
     * taskType 珊瑚的任务类型 103正式环境 134测试环境
     */
    public static final int RELEASE_TASK_TYPE_DEBUG = 134;
    public static final int RELEASE_TASK_TYPE_RELEASE = 103;

    public void pull() {

        int type;
//        if (BuildConfig.DEBUG) {
//            type = RELEASE_TASK_TYPE_DEBUG;
//        } else {
//            type = RELEASE_TASK_TYPE_RELEASE;
//        }
        type = RELEASE_TASK_TYPE_RELEASE;

        new ADLoader(MintsApplication.getContext())
                .get(ADType.APP_DOWNLOAD)
                .from(ADSource.CORAL)
                .count(1)
                .reward(true)
                .with(new HashMap<String, Object>() {
                    {
                        put(CoralAD.Key.TASK_TYPE, type);
                        put(CoralAD.Key.ACCOUNT_ID, UserManager.getInstance().getUserID());
                        put(CoralAD.Key.LOGIN_KEY, JsonUtil.toJson(getAdMapVO()));
                    }
                })
                .load(new CoralADListener() {

                    /**
                     * 任务拉取成功
                     *
                     * @param rewardTask 积分任务
                     * @return true：继续拉取广告，false：不拉取广告。默认：继续拉取广告
                     */
                    @Override
                    public boolean onTaskAvailable(RewardTask rewardTask) {
                        return super.onTaskAvailable(rewardTask);
                    }

                    /**
                     * 任务拉取失败
                     *
                     * @param taskType 任务类型
                     * @param adError  错误信息
                     * @return true：继续拉取广告，false：不拉取广告。默认：继续拉取广告
                     */
                    @Override
                    public boolean onTaskNotAvailable(int taskType, ADError adError) {
                        return super.onTaskNotAvailable(taskType, adError);
                    }

                    /**
                     * 跳转h5
                     *
                     * @param ad    广告
                     * @param h5Url h5地址
                     * @return true：使用sdk内部跳转，如果绑定了积分任务，sdk会自动提交任务。
                     * false：接入方自行跳转显示页面，如果绑定了积分任务，需要接入方手动提交任务。
                     */
                    @Override
                    public boolean openH5(CoralAD ad, String h5Url) {
                        return super.openH5(ad, h5Url);
                    }

                    /**
                     * 非广点通的App下载被点击触发
                     *
                     * @param downloadProcess 下载数据
                     * @return true：使用sdk内部进行下载，并自动上报数据，如果绑定了积分任务，可以在后续事件中选择由sdk自动提交任务。
                     * false：接入方自行创建下载流程，但需要手动上报下载、安装、打开等事件，如果绑定了积分任务，还需要手动提交任务。
                     */
                    @Override
                    public boolean download(DownloadProcess downloadProcess) {
                        LogUtil.d("download");
                        if (mOnAdLoadListener != null) {
                            mOnAdLoadListener.onGetDownloadProcess(downloadProcess);
                        }
                        return false;
                    }

                    /**
                     * 广告拉取失败
                     *
                     * @param adError 错误信息 {@link ADError}
                     */
                    @Override
                    public void onAdFailed(ADError adError) {
                        super.onAdFailed(adError);
                        LogUtil.d("onAdFailed");
                        if (mOnAdLoadListener != null) {
                            mOnAdLoadListener.onLoadFail();
                        }
                    }

                    /**
                     * 广告拉取成功
                     *
                     * @param adList 广告列表
                     */
                    @Override
                    public void onAdLoaded(List<CoralAD> adList) {
                        if (adList != null && adList.size() > 0) {
                            if (mOnAdLoadListener != null) {
                                try {
                                    Random r = new Random();
                                    int randomWeight = r.nextInt(adList.size());
                                    mOnAdLoadListener.onLoadSuccess(Collections.singletonList(adList.get(randomWeight)));
                                } catch (Exception e) {
                                    mOnAdLoadListener.onLoadSuccess(Collections.singletonList(adList.get(0)));
                                }
                            }
                        } else {
                            if (mOnAdLoadListener != null) {
                                mOnAdLoadListener.onLoadFail();
                            }
                        }
                    }

                    /**
                     * 广告已显示
                     *
                     * @param ad 广告（部分广告类型返回为空）
                     * @return true：如果绑定了积分任务，则sdk立即提交任务，并忽略后续的提交。
                     * false：如果绑定了积分任务，不做提交，由后续事件决定。
                     * 默认：不提交
                     */
                    @Override
                    public boolean onAdShow(@Nullable CoralAD ad) {
                        LogUtil.d("onAdShow");
                        return false;
                    }

                    /**
                     * 广告被点击
                     *
                     * @param ad 广告（部分广告类型返回为空）
                     * @return true：如果绑定了积分任务，则sdk立即提交任务，并忽略后续的提交。
                     * false：如果绑定了积分任务，不做提交，由后续事件决定。
                     * 默认：不提交
                     */
                    @Override
                    public boolean onAdClicked(@Nullable CoralAD ad) {
                        LogUtil.d("onAdClicked");
                        if (mOnAdLoadListener != null) {
                            mOnAdLoadListener.onSDKDownloadStart();
                        }
                        return false;
                    }

                    /**
                     * App开始下载
                     *
                     * @param ad          广告（广点通下载类返回为空）
                     * @param downloadUrl 下载地址
                     * @return true：如果绑定了积分任务，则sdk立即提交任务，并忽略后续的提交。
                     * false：如果绑定了积分任务，不做提交，由后续事件决定。
                     * 默认：不提交
                     */
                    @Override
                    public boolean onAppDownloading(@Nullable CoralAD ad, @Nullable String downloadUrl) {
                        LogUtil.d("onAppDownloading");
                        if (mOnAdLoadListener != null) {
                            mOnAdLoadListener.onSDKDownloadStart();
                        }
                        return false;
                    }

                    /**
                     * App下载完成
                     *
                     * @param ad          广告（广点通下载类返回为空）
                     * @param downloadUrl 下载地址
                     * @param localFile   本地保存文件
                     * @return true：如果绑定了积分任务，则sdk立即提交任务，并忽略后续的提交。
                     * false：如果绑定了积分任务，不做提交，由后续事件决定。
                     * 默认：不提交
                     */
                    @Override
                    public boolean onAppDownloaded(@Nullable CoralAD ad, @Nullable String downloadUrl, @Nullable String localFile) {
                        LogUtil.d("onAppDownloaded");
//                        if (mOnAdLoadListener != null) {
//                            mOnAdLoadListener.onSDKDownloaded();
//                        }
                        return false;
                    }

                    /**
                     * App已安装
                     *
                     * @param ad          广告（广点通下载类返回为空）
                     * @param downloadUrl 下载地址
                     * @param localFile   本地保存文件
                     * @return true：如果绑定了积分任务，则sdk立即提交任务，并忽略后续的提交。
                     * false：如果绑定了积分任务，不做提交，由后续事件决定。
                     * 默认：不提交
                     */
                    @Override
                    public boolean onAppInstalled(@Nullable CoralAD ad, @Nullable String downloadUrl, @Nullable String localFile) {
                        LogUtil.d("onAppInstalled");

//                        if (mOnAdLoadListener != null) {
//                            mOnAdLoadListener.onSDKInstalled();
//                        }
                        return false;
                    }

                    /**
                     * App已打开激活
                     *
                     * @param ad          广告（广点通下载类返回为空）
                     * @param downloadUrl 下载地址
                     * @param localFile   本地保存文件
                     * @return true：如果绑定了积分任务，则sdk立即提交任务，并忽略后续的提交。
                     * false：如果绑定了积分任务，不做提交，由后续事件决定。
                     * 默认：提交
                     */
                    @Override
                    public boolean onAppActivated(CoralAD ad, String downloadUrl, String localFile) {
                        LogUtil.d("onAppActivated");
                        return false;
                    }
                });
    }

    private OnAdLoadListener mOnAdLoadListener;

    public CoralDownload setOnAdLoadListener(OnAdLoadListener onAdLoadListener) {
        mOnAdLoadListener = onAdLoadListener;
        return this;
    }

    public void destroy() {
        mOnAdLoadListener = null;
    }

    public interface OnAdLoadListener {
        void onLoadSuccess(List<CoralAD> dataList);

        void onLoadFail();

        void onSDKDownloadStart();

//        void onSDKDownloaded();
//
//        void onSDKInstalled();

        void onGetDownloadProcess(DownloadProcess downloadProcess);
    }

    private HashMap<String, Object> getAdMapVO() {
        HashMap<String, Object> vo = new HashMap<>();
        vo.put("carrierType", Constant.CARRIER_CPD);
        return vo;
    }
}
