package com.mints.goodmoney.ad.draw

import android.app.Activity
import android.view.View
import com.bytedance.sdk.openadsdk.AdSlot
import com.bytedance.sdk.openadsdk.TTAdNative
import com.bytedance.sdk.openadsdk.TTNativeExpressAd
import com.bytedance.sdk.openadsdk.TTRewardVideoAd
import com.mints.goodmoney.manager.TTNativeExpressManager
import com.mints.goodmoney.manager.TtCsjAdManager
import com.mints.goodmoney.mvp.model.DrawVideoBean
import com.mints.goodmoney.ui.activitys.DrawNativeVideoActivity
import com.mints.goodmoney.utils.LogUtil
import com.mints.goodmoney.utils.ToastUtil
import com.mints.goodmoney.utils.UIUtils

/**
 * 描述：穿山甲Draw 信息流广告
 */
class CsjDrawAdManager private constructor(activity: Activity) {

    companion object {
        private var _inst: CsjDrawAdManager? = null
        fun getInstance(activity: Activity): CsjDrawAdManager? {
            return if (_inst != null) {
                _inst
            } else {
                _inst = CsjDrawAdManager(activity)
                _inst
            }
        }
    }

    private var activity: Activity? = null

    private var ttAdNative: TTAdNative? = null
    private var mttRewardVideoAd: TTRewardVideoAd? = null
    private var csjDrawAdListener: CsjDrawAdListener? = null

    init {
        this.activity = activity
        val ttNativeExpressManager = TTNativeExpressManager()
        ttAdNative = ttNativeExpressManager.initTTAd(false)
    }

    fun loadDrawNativeAd(activity: Activity, adCount: Int) {
        this.activity = activity

        //step3:创建广告请求参数AdSlot,具体参数含义参考文档
        val expressViewWidth: Float = UIUtils.getScreenWidthDp(activity)
        val expressViewHeight: Float = UIUtils.getHeight(activity)

        val adSlot = AdSlot.Builder()
                .setCodeId(TtCsjAdManager.TT_AD_EXPRESS_DRAW)
                .setExpressViewAcceptedSize(expressViewWidth, expressViewHeight)
                .setAdCount(adCount) //请求广告数量为1到3条
                .build()

        mttRewardVideoAd?.setRewardAdInteractionListener(null)

        //step4:请求广告,对请求回调的广告作渲染处理
        ttAdNative?.loadExpressDrawFeedAd(adSlot, object : TTAdNative.NativeExpressAdListener {
            override fun onError(p0: Int, p1: String?) {
//                ToastUtil.show(activity, p1)
                LogUtil.d(p1)

                this@CsjDrawAdManager.csjDrawAdListener?.csjDrawAdFail()
            }

            override fun onNativeExpressAdLoad(ads: MutableList<TTNativeExpressAd>?) {
                if (ads == null || ads.isEmpty()) {
//                    ToastUtil.show(activity, "未请求到广告")
                    this@CsjDrawAdManager.csjDrawAdListener?.csjDrawAdFail()
                    LogUtil.d("未请求到广告")
                    return
                }

                for (ad in ads) {
                    //点击监听器必须在getAdView之前调
                    ad.setVideoAdListener(object : TTNativeExpressAd.ExpressVideoAdListener {
                        override fun onVideoLoad() {
                        }

                        override fun onVideoError(p0: Int, p1: Int) {
                        }

                        override fun onVideoAdStartPlay() {
                        }

                        override fun onVideoAdPaused() {
                        }

                        override fun onVideoAdContinuePlay() {
                        }

                        override fun onProgressUpdate(p0: Long, p1: Long) {
                        }

                        override fun onVideoAdComplete() {
                        }

                        override fun onClickRetry() {
                        }

                    })
                    ad.setCanInterruptVideoPlay(true)
                    ad.setExpressInteractionListener(object : TTNativeExpressAd.ExpressAdInteractionListener {
                        override fun onAdClicked(p0: View?, p1: Int) {

                        }

                        override fun onAdShow(p0: View?, p1: Int) {

                        }

                        override fun onRenderFail(p0: View?, p1: String?, p2: Int) {
                            this@CsjDrawAdManager.csjDrawAdListener?.csjDrawAdFail()

                        }

                        override fun onRenderSuccess(p0: View?, p1: Float, p2: Float) {
                            this@CsjDrawAdManager.csjDrawAdListener?.csjDrawAdSuccess(ad)
                        }
                    })

                    ad.render()
                }


            }

        })
    }

    fun setCsjDrawAdListener(csjDrawAdListener: CsjDrawAdListener?) {
        this.csjDrawAdListener = csjDrawAdListener
    }

    interface CsjDrawAdListener {
        fun csjDrawAdFail()
        fun csjDrawAdSuccess(data: TTNativeExpressAd)
    }

    fun onDestroy() {
        this.csjDrawAdListener = null
        mttRewardVideoAd?.setRewardAdInteractionListener(null)

        activity = null
    }
}