package com.mints.goodmoney.ad.express

import android.annotation.SuppressLint
import android.text.TextUtils
import android.util.Log
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.FrameLayout
import android.widget.ImageView
import android.widget.TextView
import com.bumptech.glide.Glide
import com.kwad.sdk.api.*
import com.kwad.sdk.api.KsNativeAd.VideoPlayListener
import com.mints.goodmoney.MintsApplication
import com.mints.goodmoney.R
import com.mints.goodmoney.manager.KsManager
import com.mints.goodmoney.utils.LogUtil
import java.util.*

/**
 * 快手预加载信息流
 */
object KsPreLoadExpressManager {

    private var mADLoadSuccessListener: KSADLoadSuccessListener? = null

    private var mContext = MintsApplication.getContext()

    fun setListener(adLoadSuccessListener: KSADLoadSuccessListener?) {
        mADLoadSuccessListener = adLoadSuccessListener
    }

    fun loadKsFrameLayout(parent: ViewGroup) {
        try {
            var ksNativeAd: KsNativeAd?
            val scene = KsScene
                    .Builder(KsManager.KS_AD_NATIVEEXPRESS_AWARD)
                    .adNum(1)
                    .build()
            KsAdSDK.getLoadManager().loadNativeAd(scene, object : KsLoadManager.NativeAdListener {
                override fun onError(p0: Int, p1: String?) {
                    LogUtil.d("$p0 -> $p1")
                }

                override fun onNativeAdLoad(p0: MutableList<KsNativeAd>?) {
                    ksNativeAd = p0?.get(0)
                    mADLoadSuccessListener?.onKSAdLoadSuc(returnAdView(parent, ksNativeAd!!))
                }

            })
        } catch (e: Exception) {
            e.printStackTrace()
        }
    }

    private fun returnAdView(parent: ViewGroup, ksNativeAd: KsNativeAd): View {
        val adView: View
        // 判断广告素材类型
        when (ksNativeAd.materialType) {
            KsNativeAd.MaterialType.VIDEO -> {
                // 视频素材，渲染自定义的视频广告
                adView = getVideoItemView(parent, ksNativeAd)!!
            }
            KsNativeAd.MaterialType.SINGLE_IMG -> {
                // 单图素材，渲染自定义的单图广告
                adView = getSingleImageItemView(parent, ksNativeAd)!!
            }
            KsNativeAd.MaterialType.GROUP_IMG -> {
                // 组图素材，渲染自定义的组图广告
                adView = getGroupImageItemView(parent, ksNativeAd)!!
            }
            else -> {
                adView = getNormalItemView(parent)!!
            }
        }

        return adView
    }

    /**
     * 使用SDK渲染的播放控件
     */
    private fun getVideoItemView(parent: ViewGroup, ksNativeAd: KsNativeAd): View? {
        val convertView: View = LayoutInflater.from(mContext).inflate(R.layout.native_item_video, parent, false)
        val videoViewHolder = AdVideoViewHolder(convertView)

        // 设置广告数据
        bindCommonData(convertView as ViewGroup, videoViewHolder, ksNativeAd)
        ksNativeAd.setVideoPlayListener(object : VideoPlayListener {
            override fun onVideoPlayStart() {
            }

            override fun onVideoPlayComplete() {
            }

            override fun onVideoPlayError(what: Int, extra: Int) {
                LogUtil.d("KsPreLoadExpressManager","id=${what}  extra=${extra}")
            }
        })

        // SDK默认渲染的视频view
        val videoPlayConfig = KsAdVideoPlayConfig.Builder()
                .videoSoundEnable(true) // 有声播放
                .dataFlowAutoStart(false) // 流量下自动播放
                .build()
        val videoView = ksNativeAd.getVideoView(mContext, videoPlayConfig)
        if (videoView != null && videoView.parent == null) {
            videoViewHolder.mAdVideoContainer.removeAllViews()
            videoViewHolder.mAdVideoContainer.addView(videoView)
        }
        return convertView
    }

    /**
     * 自定义的单图广告
     */
    private fun getSingleImageItemView(parent: ViewGroup, ksNativeAd: KsNativeAd): View? {
        val convertView: View = LayoutInflater.from(mContext).inflate(R.layout.native_item_single_image, parent, false)
        val viewHolder = AdSingleImageViewHolder(convertView)
        bindCommonData(convertView as ViewGroup, viewHolder, ksNativeAd)

        // 获取图片资源
        if (ksNativeAd.imageList != null && ksNativeAd.imageList!!.isNotEmpty()) {
            val image = ksNativeAd.imageList!![0]
            if (image != null && image.isValid) {
                Glide.with(mContext).load(image.imageUrl).into(viewHolder.mAdImage)
            }
        }
        return convertView
    }

    /**
     * 自定义的组图广告
     */
    private fun getGroupImageItemView(parent: ViewGroup, ksNativeAd: KsNativeAd): View? {
        val convertView: View = LayoutInflater.from(mContext).inflate(R.layout.native_item_group_image, parent, false)
        val viewHolder = AdGroupImageViewHolder(convertView)
        bindCommonData(convertView as ViewGroup, viewHolder, ksNativeAd)

        // 获取图片资源
        val ksImageList = ksNativeAd.imageList
        if (ksImageList != null && ksImageList.isNotEmpty()) {
            for (i in ksImageList.indices) {
                val image = ksNativeAd.imageList!![i]
                if (image != null && image.isValid) {
                    when (i) {
                        0 -> {
                            Glide.with(mContext).load(image.imageUrl).into(viewHolder.mAdImageLeft)
                        }
                        1 -> {
                            Glide.with(mContext).load(image.imageUrl).into(viewHolder.mAdImageMid)
                        }
                        2 -> {
                            Glide.with(mContext).load(image.imageUrl).into(viewHolder.mAdImageRight)
                        }
                    }
                }
            }
        }
        return convertView
    }

    @SuppressLint("DefaultLocale")
    private fun getNormalItemView(parent: ViewGroup): View? {
        val convertView: View = LayoutInflater.from(mContext).inflate(R.layout.native_item_normal, parent, false)
        val normalViewHolder = NormalViewHolder(convertView)
        normalViewHolder.textView.text = "没有广告"
        return convertView
    }

    private fun bindCommonData(convertView: ViewGroup, adBaseViewHolder: AdBaseViewHolder,
                               ad: KsNativeAd) {
        // 点击转换view的集合，传入的view点击时会触发转换操作：app下载， 打开h5页面
        val clickViewList: MutableList<View> = ArrayList()
        clickViewList.add(convertView) // 点击整个view都可触发转换
        // clickViewList.add(adBaseViewHolder.mAppDownloadBtn);
        // clickViewList.add(adBaseViewHolder.mH5OpenBtn);

        // 注册View的点击，点击后触发转化
        ad.registerViewForInteraction(convertView, clickViewList,
                object : KsNativeAd.AdInteractionListener {
                    override fun onAdClicked(view: View, ad: KsNativeAd) {
                        if (ad != null) {
//                            Toast.makeText(MintsApplication.getContext(), "广告" + ad.appName + "被点击", Toast.LENGTH_SHORT).show()
                        }
                    }

                    override fun onAdShow(ad: KsNativeAd) {
                        if (ad != null) {
//                            Toast.makeText(mContext, "广告" + ad.appName + "展示", Toast.LENGTH_SHORT).show()
                        }
                    }
                })

        // 广告描述
        adBaseViewHolder.mAdDes.text = ad.adDescription

        // 其他数据
        Log.d("AppInfo", "应用名字 = " + ad.appName)
        Log.d("AppInfo", "应用包名 = " + ad.appPackageName)
        Log.d("AppInfo", "应用版本 = " + ad.appVersion)
        Log.d("AppInfo", "开发者 = " + ad.corporationName)
        Log.d("AppInfo", "包大小 = " + ad.appPackageSize)
        Log.d("AppInfo", "隐私条款链接 = " + ad.appPrivacyUrl)
        Log.d("AppInfo", "权限信息 = " + ad.permissionInfo)

        // 获取app的评分，取值范围0~5.0
        Log.d("AppInfo", "应用评分 = " + ad.appScore)
        // 获取app下载次数文案，例如：800W此下载，自行渲染。
        Log.d("AppInfo", "app下载次数文案 = " + ad.appDownloadCountDes)
        when (ad.interactionType) {
            KsNativeAd.InteractionType.H5 -> {
                // 广告描述
                adBaseViewHolder.mH5Desc.text = ad.adDescription
                // 广告转化文案
                adBaseViewHolder.mH5OpenBtn.text = ad.actionDescription
                adBaseViewHolder.mAppContainer.visibility = View.GONE
                adBaseViewHolder.mH5Container.visibility = View.VISIBLE
            }
            KsNativeAd.InteractionType.DOWNLOAD -> {
                // appIcon，非下载类型的没有
                if (TextUtils.isEmpty(ad.appIconUrl)) {
                    adBaseViewHolder.mAppIcon.visibility = View.GONE
                } else {
                    adBaseViewHolder.mAppIcon.visibility = View.VISIBLE
                    Glide.with(MintsApplication.getContext()).load(ad.appIconUrl).into(adBaseViewHolder.mAppIcon)
                }
                // app名称
                adBaseViewHolder.mAppName.text = ad.appName
                // 广告描述
                adBaseViewHolder.mAppDesc.text = ad.adDescription
                // 广告转化文案
                adBaseViewHolder.mAppDownloadBtn.text = ad.actionDescription
                // 下载类型的可以设置下载监听
                bindDownloadListener(adBaseViewHolder, ad)
                adBaseViewHolder.mAppContainer.visibility = View.VISIBLE
                adBaseViewHolder.mH5Container.visibility = View.GONE
            }
        }

        // 不喜欢
        adBaseViewHolder.mDislikeBtn.setOnClickListener {
//            LogUtil.d("广告" + ad.appName + "不喜欢点击")
        }
    }

    private fun bindDownloadListener(adBaseViewHolder: AdBaseViewHolder, ad: KsNativeAd) {
        val ksAppDownloadListener: KsAppDownloadListener = object : KsAppDownloadListener {
            override fun onIdle() {
                adBaseViewHolder.mAppDownloadBtn.text = ad.actionDescription
            }

            override fun onDownloadStarted() {
                adBaseViewHolder.mAppDownloadBtn.text = "开始下载"
            }

            override fun onProgressUpdate(progress: Int) {
                adBaseViewHolder.mAppDownloadBtn.text = String.format("%s/100", progress)
            }

            override fun onDownloadFinished() {
                adBaseViewHolder.mAppDownloadBtn.text = "立即安装"
            }

            override fun onDownloadFailed() {
                adBaseViewHolder.mAppDownloadBtn.text = ad.actionDescription
            }

            override fun onInstalled() {
                adBaseViewHolder.mAppDownloadBtn.text = "立即打开"
            }
        }
        // 注册下载监听器
        ad.setDownloadListener(ksAppDownloadListener)
    }


    private class NormalViewHolder(convertView: View) {
        var textView: TextView = convertView.findViewById(R.id.tv)

    }

    private class AdSingleImageViewHolder(convertView: View) : AdBaseViewHolder(convertView) {
        var mAdImage: ImageView = convertView.findViewById(R.id.ad_image)

    }

    private class AdGroupImageViewHolder(convertView: View) : AdBaseViewHolder(convertView) {
        var mAdImageLeft: ImageView = convertView.findViewById(R.id.ad_image_left)
        var mAdImageMid: ImageView = convertView.findViewById(R.id.ad_image_mid)
        var mAdImageRight: ImageView = convertView.findViewById(R.id.ad_image_right)

    }

    private class AdVideoViewHolder(convertView: View) : AdBaseViewHolder(convertView) {
        var mAdVideoContainer: FrameLayout = convertView.findViewById(R.id.video_container)

    }

    private abstract class AdBaseViewHolder(convertView: View) {
        var mAdDes: TextView = convertView.findViewById(R.id.ad_desc)
        var mAppContainer: ViewGroup = convertView.findViewById(R.id.ad_download_container)
        var mAppIcon: ImageView = convertView.findViewById(R.id.app_icon)
        var mAppName: TextView = convertView.findViewById(R.id.app_title)
        var mAppDesc: TextView = convertView.findViewById(R.id.app_desc)
        var mAppDownloadBtn: TextView = convertView.findViewById(R.id.app_download_btn)
        var mH5Container: ViewGroup = convertView.findViewById(R.id.ad_h5_container)
        var mH5Desc: TextView = convertView.findViewById(R.id.h5_desc)
        var mH5OpenBtn: TextView = convertView.findViewById(R.id.h5_open_btn)
        var mDislikeBtn: ImageView = convertView.findViewById(R.id.ad_dislike)
    }

    /**
     * 在页面销毁时调用  destroy
     */
    fun onDestroy() {
        // 使用完了每一个NativeExpressADView之后都要释放掉资源
//        ksFeedAd = null
    }

}