package com.mints.goodmoney.ad.express

import android.view.View
import android.view.ViewGroup
import android.widget.FrameLayout
import com.mints.goodmoney.MintsApplication
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.mvp.model.WeightBean
import com.mints.goodmoney.utils.LogUtil
import com.qq.e.ads.nativ.NativeExpressADView
import java.util.*


/**
 * 预加载信息流管理类
 */
object PreLoadExpressManager : TTADLoadSuccessListener, YLHADLoadSuccessListener, KSADLoadSuccessListener {

    private val TAG = PreLoadExpressManager::class.java.simpleName

//    @Volatile
//    private var currentIndex = 0

    @Volatile
    private var mAdFrameLayout: FrameLayout? = null

    private var weightList: MutableList<WeightBean> = mutableListOf()
    private var csjWeight = 0
    private var ylhWeight = 0
    private var ksWeight = 0

    init {
        mAdFrameLayout = FrameLayout(MintsApplication.getContext())
        YlhPreLoadExpressManager.setListener(this)
        TTPreLoadExpressManager.getInstance().setListener(this)
        KsPreLoadExpressManager.setListener(this)
    }

    fun init(csjWeight: Int, ylhWeight: Int, ksWeight: Int) {
        this.csjWeight = csjWeight
        this.ylhWeight = ylhWeight
        this.ksWeight = ksWeight
    }

    fun loadADFrameLayout() {
        mAdFrameLayout?.removeAllViews()

//        when (++currentIndex) {
//            1 -> {
//                TTPreLoadExpressManager.getInstance().loadTtFrameLayout(mAdFrameLayout)
//            }
//            2 -> {
//                YlhPreLoadExpressManager.loadYlhFrameLayout()
//            }
//            3 -> {
//                KsPreLoadExpressManager.loadKsFrameLayout(mAdFrameLayout as ViewGroup)
//            }
//        }

        when (getRandomWeight()) {
            Constant.CSJ_EXPRESS_AD -> TTPreLoadExpressManager.getInstance().loadTtFrameLayout(mAdFrameLayout)
            Constant.YLH_EXPRESS_AD -> YlhPreLoadExpressManager.loadYlhFrameLayout()
            Constant.KS_EXPRESS_AD -> KsPreLoadExpressManager.loadKsFrameLayout(mAdFrameLayout as ViewGroup)
            else -> {
                TTPreLoadExpressManager.getInstance().loadTtFrameLayout(mAdFrameLayout)
            }
        }
    }

    /**
     * 根据权重获取广告类型
     */
    private fun getRandomWeight(): String {
        weightList.clear()
        var weight = 0
        // 若没有视频完成数，不加入权重计算范围内
        if (csjWeight > 0) {
            weightList.add(WeightBean(csjWeight, Constant.CSJ_EXPRESS_AD))
            weight = weight + csjWeight
            LogUtil.d(TAG, "EXPRESS权重值：csjWeight:$csjWeight")
        }
        if (ylhWeight > 0) {
            weightList.add(WeightBean(ylhWeight, Constant.YLH_EXPRESS_AD))
            weight = weight + ylhWeight
            LogUtil.d(TAG, "EXPRESS权重值：ylhWeight:$ylhWeight")
        }
        if (ksWeight > 0) {
            weightList.add(WeightBean(ksWeight, Constant.KS_EXPRESS_AD))
            weight = weight + ksWeight
            LogUtil.d(TAG, "EXPRESS权重值：ksWeight:$ksWeight")
        }

        // 权重随机
        if (weightList.size > 0 && weight > 0) {
            LogUtil.d(TAG, "1、权重总值EXPRESS：$weight")
            val r = Random()
            var randomWeight = r.nextInt(weight) + 1
            LogUtil.d(TAG, "2、权重随机值EXPRESS：$randomWeight")

//            ToastUtil.show(MintsApplication.getContext(), "权重随机值EXPRESS：" + randomWeight);
            for (weightBean in weightList) {
                randomWeight -= weightBean.weight
                if (randomWeight <= 0) {
                    LogUtil.d(TAG, "3、权重结果EXPRESS：" + weightBean.type)
                    return weightBean.type
                }
            }
        }
        return ""
    }

    fun getADFrameLayout(): FrameLayout? {
//        if (currentIndex >= 3) currentIndex = 0

        return mAdFrameLayout
    }

    fun onDestroy() {
        TTPreLoadExpressManager.getInstance().onDestroy()
        YlhPreLoadExpressManager.onDestroy()
        KsPreLoadExpressManager.onDestroy()
    }

    override fun onTTAdLoadSuc(adFrameLayout: FrameLayout?) {
//        if (currentIndex == 1) {
//            mAdFrameLayout = adFrameLayout
//        }
        mAdFrameLayout = adFrameLayout
    }

    override fun onYlhAdLoadSuc(view: NativeExpressADView?) {
//        if (currentIndex == 2) {
//            mAdFrameLayout?.addView(view)
//        }
        mAdFrameLayout?.addView(view)
    }

    override fun onKSAdLoadSuc(view: View?) {
//        if (currentIndex == 3) {
//            mAdFrameLayout?.addView(view)
//        }
        mAdFrameLayout?.addView(view)
    }

}

interface TTADLoadSuccessListener {
    fun onTTAdLoadSuc(adFrameLayout: FrameLayout?)
}

interface YLHADLoadSuccessListener {
    fun onYlhAdLoadSuc(view: NativeExpressADView?)
}

interface KSADLoadSuccessListener {
    fun onKSAdLoadSuc(ksNativeAd: View?)
}