package com.mints.goodmoney.ad.video;

import android.app.Activity;

import com.bytedance.sdk.openadsdk.AdSlot;
import com.bytedance.sdk.openadsdk.TTAdConstant;
import com.bytedance.sdk.openadsdk.TTAdNative;
import com.bytedance.sdk.openadsdk.TTAdSdk;
import com.bytedance.sdk.openadsdk.TTFullScreenVideoAd;
import com.mints.goodmoney.ad.video.base.BaseVideoAd;
import com.mints.goodmoney.ad.video.base.VideoAdStatusListener;
import com.mints.goodmoney.common.Constant;
import com.mints.goodmoney.manager.TrackManager;
import com.mints.goodmoney.manager.TtCsjAdManager;

/**
 * 穿山甲全屏广告
 */
public class CsjFullVideoAdManager extends BaseVideoAd {

    private static CsjFullVideoAdManager _inst;

    private VideoAdStatusListener videoAdStatusListener;

    Activity activity;
    private TTAdNative ttAdNative;
    private TTFullScreenVideoAd mttFullVideoAd;

    private boolean isClickScreen = true; // 是否点击屏幕跳转广告

    public static CsjFullVideoAdManager getInstance(Activity activity) {
        if (_inst != null) {
            return _inst;
        } else {
            _inst = new CsjFullVideoAdManager(activity);
            return _inst;
        }
    }

    private CsjFullVideoAdManager(Activity activity) {
        init(activity);
    }

    private void init(Activity activity) {
        this.activity = activity;
        ttAdNative = TTAdSdk.getAdManager().createAdNative(activity);
    }

    /**
     * 全屏广告
     *
     * @param carrierType
     */
    @SuppressWarnings("SameParameterValue")
    @Override
    public void loadAd(Activity activity, int curCoin, String carrierType, String extraId) {
        this.activity = activity;
        if (mttFullVideoAd != null) {
            mttFullVideoAd.setFullScreenVideoAdInteractionListener(null);
        }
        AdSlot adSlot = new AdSlot.Builder()
                .setCodeId(TtCsjAdManager.TT_AD_FULLVEDIO_ALL)
                .setSupportDeepLink(true)
                .setOrientation(TTAdConstant.VERTICAL)
                .build();
        ttAdNative.loadFullScreenVideoAd(adSlot, new TTAdNative.FullScreenVideoAdListener() {
            @Override
            public void onError(int code, String message) {
                TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_CSJFULL, Constant.EVENT_TYPE_ONE, String.valueOf(code), message);

                if (videoAdStatusListener != null) {
                    videoAdStatusListener.adFail();
                }
            }

            @Override
            public void onFullScreenVideoAdLoad(TTFullScreenVideoAd ad) {
                mttFullVideoAd = ad;
                mttFullVideoAd.setFullScreenVideoAdInteractionListener(new TTFullScreenVideoAd.FullScreenVideoAdInteractionListener() {

                    @Override
                    public void onAdShow() {
                        TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_CSJFULL, Constant.EVENT_TYPE_ZERO, "", "");
                    }

                    @Override
                    public void onAdVideoBarClick() {
                        if (isClickScreen) {
                            // 防止重复
                            TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_CSJFULL, Constant.EVENT_TYPE_FOUR, "", "");
                            isClickScreen = false;
                        }
                        TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_CSJFULL, Constant.EVENT_TYPE_TWO, "", "");

                        if (videoAdStatusListener != null) {
                            videoAdStatusListener.adDownload();
                        }
                    }

                    @Override
                    public void onAdClose() {
                        TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_CSJFULL, Constant.EVENT_TYPE_THREE, "", "");
                        if (videoAdStatusListener != null) {
                            videoAdStatusListener.adSuccess();
                        }
                        if (activity != null) {
                            TrackManager.getInstance().reportAddCoinMsg(activity, getAdMapVO(carrierType, Constant.AD_SOURCE_CSJFULL, extraId, curCoin));
                        }
                    }

                    @Override
                    public void onVideoComplete() {
                    }

                    @Override
                    public void onSkippedVideo() {

                    }

                });
            }

            @Override
            public void onFullScreenVideoCached() {
                if (mttFullVideoAd != null) {
                    //step6:在获取到广告后展示
                    mttFullVideoAd.showFullScreenVideoAd(activity);
                    mttFullVideoAd = null;
                } else {
                    TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_CSJFULL, Constant.EVENT_TYPE_ONE, "999999", "Cached Fail");

                    if (videoAdStatusListener != null) {
                        videoAdStatusListener.adFail();
                    }
                }
            }
        });
    }

    @Override
    public void onDestroy() {
        if (mttFullVideoAd != null) {
            mttFullVideoAd.setFullScreenVideoAdInteractionListener(null);
        }

        activity = null;
    }

    public void setVideoAdStatusListener(VideoAdStatusListener videoAdStatusListener) {
        this.videoAdStatusListener = videoAdStatusListener;
    }

}
