package com.mints.goodmoney.ad.video

import android.app.Activity
import com.kwad.sdk.api.KsAdSDK
import com.kwad.sdk.api.KsLoadManager
import com.kwad.sdk.api.KsRewardVideoAd
import com.kwad.sdk.api.KsScene
import com.mints.goodmoney.ad.video.base.BaseVideoAd
import com.mints.goodmoney.ad.video.base.VideoAdStatusListener
import com.mints.goodmoney.common.AppConfig
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.manager.KsManager
import com.mints.goodmoney.manager.TrackManager
import com.mints.goodmoney.utils.LogUtil


private val TAG = KsVideoAdManager::class.java.simpleName

/**
 * 快手广告视频
 */
class KsVideoAdManager private constructor(activity: Activity) :
        BaseVideoAd() {

    private var videoAdStatusListener: VideoAdStatusListener? = null
    private var mRewardVideoAd: KsRewardVideoAd? = null

    private var isClickScreen: Boolean = true
    var activity: Activity? = null

    companion object {
        private var _inst: KsVideoAdManager? = null
        fun getInstance(activity: Activity): KsVideoAdManager? {
            return if (_inst != null) {
                _inst
            } else {
                _inst = KsVideoAdManager(activity)
                _inst
            }
        }
    }

    init {
        init(activity)
    }

    private fun init(activity: Activity) {
        this.activity = activity
    }

    override fun loadAd(activity: Activity, curCoin: Int, carrierType: String, extraId: String?) {
        this.activity = activity
        isClickScreen = true

        val scene = KsScene.Builder(KsManager.KS_AD_VEDIO_POSTID).build()
        KsAdSDK.getLoadManager().loadRewardVideoAd(scene, object : KsLoadManager.RewardVideoAdListener {
            override fun onError(p0: Int, p1: String?) {
                videoAdStatusListener?.adFail()
                TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_KS, Constant.EVENT_TYPE_ONE, p0.toString(), p1)

            }

            override fun onRewardVideoAdLoad(p0: MutableList<KsRewardVideoAd>?) {
                mRewardVideoAd = p0?.get(0)
                if (mRewardVideoAd != null && mRewardVideoAd!!.isAdEnable) {

                    mRewardVideoAd!!.setRewardAdInteractionListener(object : KsRewardVideoAd.RewardAdInteractionListener {
                        override fun onAdClicked() {
//                            ToastUtil.show(activity, "快手激励视频⼴告点击")

                            if (AppConfig.needReportClickAdEvent) {
                                TrackManager.getInstance().reportClickAdEvent()
                            }

                            LogUtil.d(TAG, "onADClick")
                            TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_KS, Constant.EVENT_TYPE_TWO, "", "")
                            if (isClickScreen) {
                                // 防止重复
                                TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_KS, Constant.EVENT_TYPE_FOUR, "", "")
                                isClickScreen = false
                            }
                            videoAdStatusListener?.adDownload()
                        }

                        override fun onPageDismiss() {
//                            ToastUtil.show(activity, "快手激励视频⼴告关闭")

                            TrackManager.getInstance().reportAddCoinMsg(activity, getAdMapVO(carrierType, Constant.AD_SOURCE_KS, extraId, curCoin))

                            TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_KS, Constant.EVENT_TYPE_THREE, "", "")

                            videoAdStatusListener?.adSuccess()
                        }

                        override fun onVideoPlayError(p0: Int, p1: Int) {
//                            ToastUtil.show(activity, "快手激励视频⼴告播放出错")

                            TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_KS, Constant.EVENT_TYPE_ONE, (p0).toString(), (p1).toString())

                            videoAdStatusListener?.adFail()
                        }

                        override fun onVideoPlayEnd() {
//                            ToastUtil.show(activity, "快手激励视频⼴告播放完成")
                        }

                        override fun onVideoPlayStart() {
//                            ToastUtil.show(activity, "快手激励视频⼴告播放开始")
                        }

                        override fun onRewardVerify() {
//                            ToastUtil.show(activity, "快手激励视频⼴告获取激励")

                            TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_KS, Constant.EVENT_TYPE_ZERO, "", "")
                        }

                    })
                    // PlayConfig默认竖屏播放，传null
                    mRewardVideoAd!!.showRewardVideoAd(activity, null)
                }
            }

        })


    }

    fun setVideoAdStatusListener(videoAdStatusListener: VideoAdStatusListener?) {
        this.videoAdStatusListener = videoAdStatusListener
    }


    override fun onDestroy() {
        mRewardVideoAd = null
        activity = null
    }
}