package com.mints.goodmoney.ad.video

import android.app.Activity
import com.fly.videowake.ad.ManageVideoAd
import com.fly.videowake.ad.VideoRewardListener
import com.mints.goodmoney.MintsApplication
import com.mints.goodmoney.ad.video.base.BaseVideoAd
import com.mints.goodmoney.ad.video.base.VideoAdStatusListener
import com.mints.goodmoney.common.AppConfig
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.manager.TrackManager
import com.mints.goodmoney.utils.LogUtil


private val TAG = RTAVideoAdManager::class.java.simpleName

/**
 * ACT激励视频
 */
class RTAVideoAdManager private constructor(activity: Activity) : BaseVideoAd() {

    private var videoAdStatusListener: VideoAdStatusListener? = null

    private var isClickScreen: Boolean = true
    private var activity: Activity? = null

    private var manageVideoAd: ManageVideoAd? = null

    companion object {
        const val RTA_ID = 38

        private var _inst: RTAVideoAdManager? = null
        fun getInstance(activity: Activity): RTAVideoAdManager? {
            return if (_inst != null) {
                _inst
            } else {
                _inst = RTAVideoAdManager(activity)
                _inst
            }
        }
    }

    init {
        init(activity)
    }

    private fun init(activity: Activity) {
        this.activity = activity
    }

    override fun loadAd(activity: Activity, curCoin: Int, carrierType: String, extraId: String?) {
        this.activity = activity
        isClickScreen = true

        manageVideoAd = ManageVideoAd(activity, RTA_ID, MintsApplication.OAID)

        manageVideoAd?.setVideoRewardListener(object : VideoRewardListener {
            override fun onVideoPlayStart() {
                LogUtil.d(TAG, "onVideoPlayStart -> ")

            }

            override fun onLoadSuccess() {
                LogUtil.d(TAG, "onLoadSuccess -> ")

                TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_RTA, Constant.EVENT_TYPE_ZERO, "", "")

                // 展示广告
                manageVideoAd?.showAD()
            }

            override fun onAdShow() {
                LogUtil.d(TAG, "onAdShow -> ")

            }

            override fun onVideoPlaySkip() {
                LogUtil.d(TAG, "onVideoPlaySkip -> ")

            }

            override fun onLoadFail(p0: String?) {
                LogUtil.d(TAG, "onLoadFail -> " + p0)

                TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_RTA, Constant.EVENT_TYPE_ONE, "999999", p0)

                videoAdStatusListener?.adFail()
            }

            override fun onAdClick() {
                LogUtil.d(TAG, "onAdClick -> ")

                if (AppConfig.needReportClickAdEvent) {
                    TrackManager.getInstance().reportClickAdEvent()
                }

                TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_RTA, Constant.EVENT_TYPE_TWO, "", "")
                if (isClickScreen) {
                    // 防止重复
                    TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_RTA, Constant.EVENT_TYPE_FOUR, "", "")
                    isClickScreen = false
                }
                videoAdStatusListener?.adDownload()
            }

            override fun onVideoPlayComplete() {
                LogUtil.d(TAG, "onVideoPlayComplete -> ")

            }

            override fun onAdClosed() {
                LogUtil.d(TAG, "onAdClosed -> ")

                TrackManager.getInstance().reportAddCoinMsg(activity, getAdMapVO(carrierType, Constant.AD_SOURCE_RTA, extraId, curCoin))

                TrackManager.getInstance().addCallImp(Constant.AD_SOURCE_RTA, Constant.EVENT_TYPE_THREE, "", "")

                videoAdStatusListener?.adSuccess()

            }
        })

        manageVideoAd?.loadAD()
    }

    fun setVideoAdStatusListener(videoAdStatusListener: VideoAdStatusListener?) {
        this.videoAdStatusListener = videoAdStatusListener
    }

    override fun onDestroy() {
        manageVideoAd?.setVideoRewardListener(null)
        manageVideoAd = null
        activity = null
    }
}