package com.mints.goodmoney.ad.video;

import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.text.TextUtils;

import com.mints.goodmoney.MintsApplication;
import com.mints.goodmoney.ad.video.base.VideoAdStatusListener;
import com.mints.goodmoney.common.AppConfig;
import com.mints.goodmoney.common.Constant;
import com.mints.goodmoney.manager.TrackManager;
import com.mints.goodmoney.mvp.model.VideoAdingBean;
import com.mints.goodmoney.mvp.model.WeightBean;
import com.mints.goodmoney.service.AppInstallService;
import com.mints.goodmoney.utils.AppUtil;
import com.mints.goodmoney.utils.LogUtil;
import com.mints.goodmoney.utils.ToastUtil;

import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Random;

/**
 * 视频广告播放
 */
public class VideoAdingManager {

    private static final String TAG = VideoAdingManager.class.getSimpleName();

    private static VideoAdingManager _inst;

    // APP下载回调广播
    private BroadcastReceiver mReceiverBroadcastReceiver = null;

    private VideoAdingListener videoAdingListener;

    private WnVideoAdManager wnVideoAdManager;
    private CsjVideoAdManager csjVideoAdManager;
    private YlhVideoAdManager ylhVideoAdManager;
    private MhVideoAdManager mhVideoAdManager;
    private ShVideoAdManager shVideoAdManager;
    private CsjFullVideoAdManager csjFullVideoAdManager;
    private KsVideoAdManager ksVideoAdManager;
    private RTAVideoAdManager rtaVideoAdManager;

    private int wnWeight;
    private int ylhWeight;
    private int csjVideoWeight;
    private int flVideoWeight;
    private int shVideoWeight;
    private int csjFullVideoWeight;
    private int ksVideoWeight;
    private int rtaVideoWeight;

    private ArrayList<WeightBean> weightList;

    private ArrayList<String> currentRandomAdList;//当前随机出的广告渠道
    private ArrayList<String> adList;//广告渠道

    // 是否是高额视频任务
    private boolean isHighWeight = false;
    private boolean isTTVideoAd = false;

    private Activity activity;
    private boolean isVideoAdDownload = false;// 是否点击广告下载 true-点击

    public static VideoAdingManager getInstance(Activity activity) {
        if (_inst == null) {
            WeakReference<Activity> activityWeakReference = new WeakReference<>(activity);
            _inst = new VideoAdingManager(activityWeakReference.get());
        }
        return _inst;
    }

    private VideoAdingManager(Activity activity) {
        init(activity);
    }

    /**
     * 初始化广告manager
     *
     * @param activity _
     */
    private void init(Activity activity) {
        this.activity = activity;
        csjVideoAdManager = CsjVideoAdManager.getInstance(activity);
        ylhVideoAdManager = YlhVideoAdManager.getInstance();
        csjFullVideoAdManager = CsjFullVideoAdManager.getInstance(activity);
        wnVideoAdManager = WnVideoAdManager.Companion.getInstance(activity);
        mhVideoAdManager = MhVideoAdManager.Companion.getInstance(activity);
        shVideoAdManager = ShVideoAdManager.Companion.getInstance(activity);
        ksVideoAdManager = KsVideoAdManager.Companion.getInstance(activity);
        rtaVideoAdManager = RTAVideoAdManager.Companion.getInstance(activity);
        weightList = new ArrayList<>();
    }

    private void registerBroad() {
        if (AppConfig.isSuperTask) {
            return;
        }

        if (mReceiverBroadcastReceiver != null) {
            return;
        }

        activity.startService(new Intent(activity, AppInstallService.class));

        mReceiverBroadcastReceiver = new BroadcastReceiver() {
            @Override
            public void onReceive(Context context, Intent intent) {
                if (intent == null) {
                    return;
                }

                try {
                    String pkg = intent.getStringExtra("pkg");
                    String appName = AppUtil.INSTANCE.getAppName(pkg, activity);

                    TrackManager.getInstance().saveInstallAppRecord(pkg, appName, "");

                } catch (Exception e) {
                    e.printStackTrace();
                }

            }
        };

        IntentFilter intentFilter = new IntentFilter();
        intentFilter.addAction(AppInstallService.APP_INSTALL_ACTION);
        activity.registerReceiver(this.mReceiverBroadcastReceiver, intentFilter);
    }

    /**
     * 初始化广告权重
     */
    public void initAdWeight(int csjVideoWeight, int ylhWeight,
                             int wnWeight, int flVideoWeight,
                             int shVideoWeight, int csjFullVideoWeight,
                             int ksVideoWeight, int rtaVideoWeight) {
        this.csjVideoWeight = csjVideoWeight;
        this.ylhWeight = ylhWeight;
        this.wnWeight = wnWeight;
        this.flVideoWeight = flVideoWeight;
        this.shVideoWeight = shVideoWeight;
        this.csjFullVideoWeight = csjFullVideoWeight;
        this.ksVideoWeight = ksVideoWeight;
        this.rtaVideoWeight = rtaVideoWeight;
    }

    /**
     * 根据类型加载对应视频(第一次加载)
     *
     * @param bean _
     */
    public void loadAding(Activity activity, VideoAdingBean bean) {
        WeakReference<Activity> activityWeakReference = new WeakReference<>(activity);
        this.activity = activityWeakReference.get();
        isVideoAdDownload = false;

        // 权重自有逻辑
        loadAdVideo(getVideoAdType(), bean);
    }

    /**
     * 根据广告优先级获取下一个
     * <p>
     * 穿山甲>优量汇>穿山甲全屏>快手>珊瑚>闪电盒子>枫岚(兜底)
     */
    private String getNextFailAdType() {
        // 高额任务时 会为空
        if (adList == null || currentRandomAdList == null) {
            return getHighWeight();
        }

        String nextAdType = Constant.FL_VEDIO_AD;
        try {
            List<String> tempList = listrem(adList, currentRandomAdList);
            for (String code : tempList) {
                nextAdType = getAdtype(code);
                currentRandomAdList.add(code);
                LogUtil.d(TAG, "失败返回adType：" + nextAdType);
                break;
            }
        } catch (Exception e) {
            LogUtil.d(TAG, "失败返回Error");
            e.printStackTrace();
        }
        return nextAdType;
    }

    /**
     * 加载失败优先级对应视频
     *
     * @param bean _
     */
    public void loadFailAding(Activity activity, VideoAdingBean bean) {
        WeakReference<Activity> activityWeakReference = new WeakReference<>(activity);
        this.activity = activityWeakReference.get();

        isVideoAdDownload = false;
        loadAdVideo(getNextFailAdType(), bean);
    }

    /**
     * 获取广告类型配置
     */
    private String getVideoAdType() {
        // 根据权重获取广告类型
        String adType;
        if (isHighWeight) {
            adType = getHighWeight();
        } else {
            adType = getRandomWeight();
        }
        isHighWeight = false;

        if (currentRandomAdList != null) {
            currentRandomAdList.add(getCode(adType));
        }

        LogUtil.d(TAG, "权重结果返回的广告类型：" + adType);
        return adType;
    }

    public void setIsHighWeight(boolean isHighWeight) {
        this.isHighWeight = isHighWeight;
    }

    /**
     * 高额任务广告类型
     *
     * @return _
     */
    private String getHighWeight() {
        isTTVideoAd = !isTTVideoAd;
        if (isTTVideoAd) {
            return Constant.CSJ_VEDIO_AD;
        } else {
            return Constant.YLH_VEDIO_AD;
        }
    }

    /**
     * 根据权重获取广告类型
     *
     * @return _
     */
    private String getRandomWeight() {
        if (currentRandomAdList == null) {
            currentRandomAdList = new ArrayList<>();
        }
        currentRandomAdList.clear();
        if (adList == null) {
            adList = new ArrayList<>();
        }
        adList.clear();

        if (weightList != null) {
            weightList.clear();
        }
        int weight = 0;
        // 穿山甲>优量汇>穿山甲全屏>快手>珊瑚>闪电盒子>枫岚(兜底)
        // 若没有视频完成数，不加入权重计算范围内
        if (AppConfig.csjVideoAdCount > 0) {
            weightList.add(new WeightBean(csjVideoWeight, Constant.CSJ_VEDIO_AD));
            weight = weight + csjVideoWeight;
            LogUtil.d(TAG, "权重值：csjVideoWeight:" + csjVideoWeight);
            adList.add("a");
        }
        if (AppConfig.ylhAdCount > 0) {
            weightList.add(new WeightBean(ylhWeight, Constant.YLH_VEDIO_AD));
            weight = weight + ylhWeight;
            LogUtil.d(TAG, "权重值：ylhWeight:" + ylhWeight);
            adList.add("b");
        }
        if (AppConfig.csjFullVideoAdCount > 0) {
            weightList.add(new WeightBean(csjFullVideoWeight, Constant.CSJ_FULL_AD));
            weight = weight + csjFullVideoWeight;
            LogUtil.d(TAG, "权重值：csjFullVideoWeight:" + csjFullVideoWeight);
            adList.add("c");
        }
        if (AppConfig.wnVideoAdCount > 0) {
            weightList.add(new WeightBean(wnWeight, Constant.SDHZ_VEDIO_AD));
            weight = weight + wnWeight;
            LogUtil.d(TAG, "权重值：sdhzWeight:" + wnWeight);
            adList.add("d");
        }
        if (AppConfig.shVideoAdCount > 0) {
            weightList.add(new WeightBean(shVideoWeight, Constant.SH_VEDIO_AD));
            weight = weight + shVideoWeight;
            LogUtil.d(TAG, "权重值：shWeight:" + shVideoWeight);
            adList.add("e");
        }
        if (AppConfig.ksVideoAdCount > 0) {
            weightList.add(new WeightBean(ksVideoWeight, Constant.KS_VEDIO_AD));
            weight = weight + ksVideoWeight;
            LogUtil.d(TAG, "权重值：ksWeight:" + ksVideoWeight);
            adList.add("f");
        }
        if (AppConfig.flVideoAdCount > 0) {
            weightList.add(new WeightBean(flVideoWeight, Constant.FL_VEDIO_AD));
            weight = weight + flVideoWeight;
            LogUtil.d(TAG, "权重值：flVideoWeight:" + flVideoWeight);
            adList.add("g");
        }
        if (AppConfig.rtaVideoAdCount > 0) {
            weightList.add(new WeightBean(rtaVideoWeight, Constant.RTA_VEDIO_AD));
            weight = weight + rtaVideoWeight;
            LogUtil.d(TAG, "权重值：rtaWeight:" + rtaVideoWeight);
        }

        // 权重随机
        if (weightList != null && weightList.size() > 0 && weight > 0) {
            LogUtil.d(TAG, "1、权重总值：" + weight);
            Random r = new Random();
            int randomWeight = r.nextInt(weight) + 1;
            LogUtil.d(TAG, "2、权重随机值：" + randomWeight);

//            ToastUtil.show(MintsApplication.getContext(), "权重随机值：" + randomWeight);

            for (WeightBean weightBean : weightList) {
                randomWeight -= weightBean.getWeight();
                if (randomWeight <= 0) {
                    LogUtil.d(TAG, "3、权重结果：" + weightBean.getType());
                    return weightBean.getType();
                }
            }
        }
        return "";
    }

    /**
     * 是否点击下载
     *
     * @return
     */
    public boolean isVideoAdDownload() {
        return this.isVideoAdDownload;
    }

    /**
     * 获取所有视频完成数状态  true-无可看视频
     *
     * @return
     */
    public boolean getVideoFinishFlag() {
        int csjVideoAdCount = AppConfig.csjVideoAdCount;
        int ylhAdCount = AppConfig.ylhAdCount;
        int wnAdCount = AppConfig.wnVideoAdCount;
        int flVideoAdCount = AppConfig.flVideoAdCount;
        int tzVideoAdCount = AppConfig.shVideoAdCount;
        int ksVideoAdCount = AppConfig.ksVideoAdCount;
        int csjFullVideoAdCount = AppConfig.csjFullVideoAdCount;

        if (ylhAdCount <= 0 &&
                csjVideoAdCount <= 0 &&
                wnAdCount <= 0 &&
                flVideoAdCount <= 0 &&
                tzVideoAdCount <= 0 &&
                csjFullVideoAdCount <= 0 &&
                ksVideoAdCount <= 0 ) {
//            showToast("今日视频已看完，请明天再来吧");
            return true;
        }
        return false;
    }

    /**
     * 释放资源
     */
    public void onDestroy() {
        if (csjVideoAdManager != null) {
            csjVideoAdManager.setVideoAdStatusListener(null);
            csjVideoAdManager.onDestroy();
            csjVideoAdManager = null;
        }
        if (ylhVideoAdManager != null) {
            ylhVideoAdManager.setVideoAdStatusListener(null);
            ylhVideoAdManager.onDestroy();
            ylhVideoAdManager = null;
        }
        if (wnVideoAdManager != null) {
            wnVideoAdManager.setVideoAdStatusListener(null);
            wnVideoAdManager.onDestroy();
            wnVideoAdManager = null;
        }
        if (mhVideoAdManager != null) {
            mhVideoAdManager.setVideoAdStatusListener(null);
            mhVideoAdManager.onDestroy();
            mhVideoAdManager = null;
        }
        if (csjFullVideoAdManager != null) {
            csjFullVideoAdManager.setVideoAdStatusListener(null);
            csjFullVideoAdManager.onDestroy();
            csjFullVideoAdManager = null;
        }
        if (shVideoAdManager != null) {
            shVideoAdManager.setVideoAdStatusListener(null);
            shVideoAdManager.onDestroy();
            shVideoAdManager = null;
        }
        if (ksVideoAdManager != null) {
            ksVideoAdManager.setVideoAdStatusListener(null);
            ksVideoAdManager.onDestroy();
            ksVideoAdManager = null;
        }
        if (rtaVideoAdManager != null) {
            rtaVideoAdManager.setVideoAdStatusListener(null);
            rtaVideoAdManager.onDestroy();
            rtaVideoAdManager = null;
        }

        if (mReceiverBroadcastReceiver != null) {
            activity.stopService(new Intent(activity, AppInstallService.class));
            activity.unregisterReceiver(mReceiverBroadcastReceiver);
            mReceiverBroadcastReceiver = null;
        }

        currentRandomAdList = null;
        adList = null;
        activity = null;
    }

    /**
     * 从listA里删除listB里有的数据
     *
     * @param adList
     * @param currentRandomAdList
     * @return
     */
    public List<String> listrem(List<String> adList, List<String> currentRandomAdList) {
        HashSet hs1 = new HashSet(adList);
        HashSet hs2 = new HashSet(currentRandomAdList);

//        LogUtil.d(TAG, "权重List：" + JsonUtil.toJson(adList));
//        LogUtil.d(TAG, "过滤List：" + JsonUtil.toJson(currentRandomAdList));
        hs1.removeAll(hs2);
        List<String> listC = new ArrayList<String>();
        listC.addAll(hs1);
        return listC;
    }

    public void setVideoAdingListener(VideoAdingListener videoAdingListener) {
        this.videoAdingListener = videoAdingListener;
    }

    /**
     * 加载成功失败回调
     */
    public interface VideoAdingListener {
        void videoAdingListenerError(String adType);

        void videoAdingListenerFail(String adType);

        void videoAdingListenerSuccess(String adType);
    }

    /**
     * 展示视频
     *
     * @param videoAdType
     * @param bean
     */
    private void loadAdVideo(String videoAdType, VideoAdingBean bean) {
        try {
            if (TextUtils.equals(videoAdType, Constant.YLH_VEDIO_AD)) {
                // 优量汇
                if (ylhVideoAdManager == null) {
                    if (activity == null) {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerError(Constant.YLH_VEDIO_AD);
                        }
                        return;
                    }
                    ylhVideoAdManager = YlhVideoAdManager.getInstance();
                }

                ylhVideoAdManager.setVideoAdStatusListener(new VideoAdStatusListener() {
                    @Override
                    public void adFail() {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerFail(Constant.YLH_VEDIO_AD);
                        }
                    }

                    @Override
                    public void adSuccess() {
                        AppConfig.ylhAdCount--;
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerSuccess(Constant.YLH_VEDIO_AD);
                        }
                    }

                    @Override
                    public void adDownload() {
                        isVideoAdDownload = true;

                        // 注册下载任务监听
                        registerBroad();
                    }
                });
                ylhVideoAdManager.loadAd(activity, bean.getCurCoin(), bean.getCarrierType(), bean.getExtraId());
            } else if (TextUtils.equals(videoAdType, Constant.CSJ_VEDIO_AD)) {
                // 穿山甲激励视频
                if (csjVideoAdManager == null) {
                    if (activity == null) {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerError(Constant.CSJ_VEDIO_AD);
                        }
                        return;
                    }
                    csjVideoAdManager = CsjVideoAdManager.getInstance(activity);
//                    csjVideoAdManager = CsjVideoAdManager.getInstance();
                }


                csjVideoAdManager.setVideoAdStatusListener(new VideoAdStatusListener() {
                    @Override
                    public void adFail() {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerFail(Constant.CSJ_VEDIO_AD);
                        }
                    }

                    @Override
                    public void adSuccess() {
                        AppConfig.csjVideoAdCount--;
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerSuccess(Constant.CSJ_VEDIO_AD);
                        }
                    }

                    @Override
                    public void adDownload() {
                        isVideoAdDownload = true;

                        // 注册下载任务监听
                        registerBroad();
                    }
                });
                csjVideoAdManager.loadAd(activity, bean.getCurCoin(), bean.getCarrierType(), bean.getExtraId());
            } else if (TextUtils.equals(videoAdType, Constant.SDHZ_VEDIO_AD)) {
                // 闪电盒子激励视频
                if (wnVideoAdManager == null) {
                    if (activity == null) {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerError(Constant.SDHZ_VEDIO_AD);
                        }
                        return;
                    }
                    wnVideoAdManager = WnVideoAdManager.Companion.getInstance(activity);
                }
                wnVideoAdManager.setVideoAdStatusListener(new VideoAdStatusListener() {
                    @Override
                    public void adSuccess() {
                        AppConfig.wnVideoAdCount--;
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerSuccess(Constant.SDHZ_VEDIO_AD);
                        }
                    }

                    @Override
                    public void adFail() {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerFail(Constant.SDHZ_VEDIO_AD);
                        }
                    }

                    @Override
                    public void adDownload() {
                        isVideoAdDownload = true;

                        // 注册下载任务监听
                        registerBroad();
                    }
                });
                wnVideoAdManager.loadAd(activity, bean.getCurCoin(), bean.getCarrierType(), bean.getExtraId());
            } else if (TextUtils.equals(videoAdType, Constant.FL_VEDIO_AD)) {
                // 枫岚广告激励视频
                if (mhVideoAdManager == null) {
                    if (activity == null) {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerError(Constant.FL_VEDIO_AD);
                        }
                        return;
                    }
                    mhVideoAdManager = MhVideoAdManager.Companion.getInstance(activity);
                }
                mhVideoAdManager.setVideoAdStatusListener(new VideoAdStatusListener() {
                    @Override
                    public void adSuccess() {
                        AppConfig.flVideoAdCount--;
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerSuccess(Constant.FL_VEDIO_AD);
                        }
                    }

                    @Override
                    public void adFail() {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerFail(Constant.FL_VEDIO_AD);
                        }
                    }

                    @Override
                    public void adDownload() {
                        isVideoAdDownload = true;

                        // 注册下载任务监听
                        registerBroad();
                    }
                });

                mhVideoAdManager.loadAd(activity, bean.getCurCoin(), bean.getCarrierType(), bean.getExtraId());
            } else if (TextUtils.equals(videoAdType, Constant.CSJ_FULL_AD)) {
                // 穿山甲全屏广告激励视频
                if (csjFullVideoAdManager == null) {
                    if (activity == null) {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerError(Constant.CSJ_FULL_AD);
                        }
                        return;
                    }
                    csjFullVideoAdManager = CsjFullVideoAdManager.getInstance(activity);
                }
                csjFullVideoAdManager.setVideoAdStatusListener(new VideoAdStatusListener() {
                    @Override
                    public void adSuccess() {
                        AppConfig.csjFullVideoAdCount--;
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerSuccess(Constant.CSJ_FULL_AD);
                        }
                    }

                    @Override
                    public void adFail() {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerFail(Constant.CSJ_FULL_AD);
                        }
                    }

                    @Override
                    public void adDownload() {
                        isVideoAdDownload = true;

                        // 注册下载任务监听
                        registerBroad();
                    }
                });

                csjFullVideoAdManager.loadAd(activity, bean.getCurCoin(), bean.getCarrierType(), bean.getExtraId());
            } else if (TextUtils.equals(videoAdType, Constant.SH_VEDIO_AD)) {
                // 珊瑚广告激励视频
                if (shVideoAdManager == null) {
                    if (activity == null) {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerError(Constant.SH_VEDIO_AD);
                        }
                        return;
                    }
                    shVideoAdManager = ShVideoAdManager.Companion.getInstance(activity);
                }
                shVideoAdManager.setVideoAdStatusListener(new VideoAdStatusListener() {
                    @Override
                    public void adSuccess() {
                        AppConfig.shVideoAdCount--;
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerSuccess(Constant.SH_VEDIO_AD);
                        }
                    }

                    @Override
                    public void adFail() {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerFail(Constant.SH_VEDIO_AD);
                        }
                    }

                    @Override
                    public void adDownload() {
                        isVideoAdDownload = true;

                        // 注册下载任务监听
                        registerBroad();
                    }
                });

                shVideoAdManager.loadAd(activity, bean.getCurCoin(), bean.getCarrierType(), bean.getExtraId());
            } else if (TextUtils.equals(videoAdType, Constant.KS_VEDIO_AD)) {
                // 快手广告激励视频
                if (ksVideoAdManager == null) {
                    if (activity == null) {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerError(Constant.KS_VEDIO_AD);
                        }
                        return;
                    }
                    ksVideoAdManager = KsVideoAdManager.Companion.getInstance(activity);
                }
                ksVideoAdManager.setVideoAdStatusListener(new VideoAdStatusListener() {
                    @Override
                    public void adSuccess() {
                        AppConfig.ksVideoAdCount--;
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerSuccess(Constant.KS_VEDIO_AD);
                        }
                    }

                    @Override
                    public void adFail() {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerFail(Constant.KS_VEDIO_AD);
                        }
                    }

                    @Override
                    public void adDownload() {
                        isVideoAdDownload = true;

                        // 注册下载任务监听
                        registerBroad();
                    }
                });

                ksVideoAdManager.loadAd(activity, bean.getCurCoin(), bean.getCarrierType(), bean.getExtraId());
            } else if (TextUtils.equals(videoAdType, Constant.RTA_VEDIO_AD)) {
                // RTA广告激励视频
                if (rtaVideoAdManager == null) {
                    if (activity == null) {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerError(Constant.RTA_VEDIO_AD);
                        }
                        return;
                    }
                    rtaVideoAdManager = RTAVideoAdManager.Companion.getInstance(activity);
                }
                rtaVideoAdManager.setVideoAdStatusListener(new VideoAdStatusListener() {
                    @Override
                    public void adSuccess() {
                        AppConfig.rtaVideoAdCount--;
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerSuccess(Constant.RTA_VEDIO_AD);
                        }
                    }

                    @Override
                    public void adFail() {
                        if (videoAdingListener != null) {
                            videoAdingListener.videoAdingListenerFail(Constant.RTA_VEDIO_AD);
                        }
                    }

                    @Override
                    public void adDownload() {
                        isVideoAdDownload = true;

                        // 注册下载任务监听
                        registerBroad();
                    }
                });

                rtaVideoAdManager.loadAd(activity, bean.getCurCoin(), bean.getCarrierType(), bean.getExtraId());
            }
        } catch (Exception e) {
            e.printStackTrace();
            if (videoAdingListener != null) {
                videoAdingListener.videoAdingListenerError(bean.getCarrierType());
            }
        }
    }
    private String getCode(String adtype) {
        String code = "g";
        switch (adtype) {
            case Constant.CSJ_VEDIO_AD:
                code = "a";
                break;
            case Constant.YLH_VEDIO_AD:
                code = "b";
                break;
            case Constant.CSJ_FULL_AD:
                code = "c";
                break;
            case Constant.SDHZ_VEDIO_AD:
                code = "d";
                break;
            case Constant.SH_VEDIO_AD:
                code = "e";
                break;
            case Constant.KS_VEDIO_AD:
                code = "f";
                break;
        }
        return code;
    }

    private String getAdtype(String code) {
        String adtype = Constant.FL_VEDIO_AD;
        switch (code) {
            case "a":
                adtype = Constant.CSJ_VEDIO_AD;
                break;
            case "b":
                adtype = Constant.YLH_VEDIO_AD;
                break;
            case "c":
                adtype = Constant.CSJ_FULL_AD;
                break;
            case "d":
                adtype = Constant.SDHZ_VEDIO_AD;
                break;
            case "e":
                adtype = Constant.SH_VEDIO_AD;
                break;
            case "f":
                adtype = Constant.KS_VEDIO_AD;
                break;
        }
        return adtype;
    }
}