package com.mints.goodmoney.manager

import com.mints.goodmoney.MintsApplication
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.common.DeviceInfo
import com.mints.goodmoney.net.CpdService
import com.mints.goodmoney.utils.MD5
import com.mints.goodmoney.utils.rxutil.CommonRxTask
import com.mints.goodmoney.utils.rxutil.RxjavaUtil
import com.mints.library.net.netstatus.NetUtils
import okhttp3.MediaType.Companion.toMediaTypeOrNull
import okhttp3.RequestBody
import org.json.JSONException
import org.json.JSONObject


/**
 * 圣于地Cpd下载
 */
object CpdManager {

    /*单个任务id*/
    const val BUSINESS_ID = "m8908"
    const val KEY = "sywnTAWBilog6LYancoe8wQFxK070X7B"

    /*列表任务id*/
    const val BUSINESS_ID_LIST = "m8910"
    const val KEY_LIST = "LTkB5MdZ5nWN6PSJ4ba0hs44N1STV3rg"

    /**
     * 单任务url
     */
    fun getCpdUrl(): String {
        val currentTimeMillis = System.currentTimeMillis().toString()
        val token = MD5.GetMD5Code(BUSINESS_ID + KEY + currentTimeMillis)
        // token=MD5（id + apikey+ timestamp）
        return CpdService.CPD_IP + "default/?businessId=" + BUSINESS_ID +
                "&token=" + token +
                "&timestamp=" + currentTimeMillis
    }

    /**
     * 列表任务url
     */
    fun getCpdLisrUrl(): String {
        val currentTimeMillis = System.currentTimeMillis().toString()
        val token = MD5.GetMD5Code(BUSINESS_ID_LIST + KEY_LIST + currentTimeMillis)
        // token=MD5（id + apikey+ timestamp）
        return CpdService.CPD_IP + "list/?businessId=" + BUSINESS_ID_LIST +
                "&token=" + token +
                "&timestamp=" + currentTimeMillis
    }

    /**
     * 单任务参数
     */
    fun getCpdBody(ip: String): RequestBody {
        val deviceInfo = DeviceInfo.instance

        val param = JSONObject()
        val application = JSONObject()
        val equipment = JSONObject()
        try {
            application.put("app_pkg_name", Constant.MINTS_PKG_NAME)
            application.put("app_ver_code", deviceInfo.versionCode)
            application.put("app_ver_name", deviceInfo.versionName)
            // 设备类型 4-手机
            equipment.put("type", "4")
            // 系统类型 1：android
            equipment.put("os_type", "1")
            equipment.put("android_id", deviceInfo.androidId)
            equipment.put("imei", deviceInfo.iMEI)
            equipment.put("mac", deviceInfo.getMacAddress())
            equipment.put("net_type", NetUtils.getNetworkStateForCpd(MintsApplication.getContext()))
            equipment.put("ip", ip)
            equipment.put("brand", deviceInfo.brand)
            equipment.put("model", deviceInfo.mobileModel)
            param.put("application", application)
            param.put("equipment", equipment)
        } catch (e: JSONException) {
            e.printStackTrace()
        }

        return RequestBody.create("application/json".toMediaTypeOrNull(), param.toString())
    }

    /**
     * 列表任务参数
     */
    fun getCpdListBody(ip: String,number:Int): RequestBody {
        val deviceInfo = DeviceInfo.instance

        val param = JSONObject()
        val application = JSONObject()
        val equipment = JSONObject()
        val advertising = JSONObject()
        try {
            application.put("app_pkg_name", Constant.MINTS_PKG_NAME)
            application.put("app_ver_code", deviceInfo.versionCode)
            application.put("app_ver_name", deviceInfo.versionName)
            // 设备类型 4-手机
            equipment.put("type", "4")
            // 系统类型 1：android
            equipment.put("os_type", "1")
            equipment.put("android_id", deviceInfo.androidId)
            equipment.put("imei", deviceInfo.iMEI)
            equipment.put("mac", deviceInfo.getMacAddress())
            equipment.put("net_type", NetUtils.getNetworkStateForCpd(MintsApplication.getContext()))
            equipment.put("ip", ip)
            equipment.put("brand", deviceInfo.brand)
            equipment.put("model", deviceInfo.mobileModel)
            equipment.put("make", deviceInfo.brand)
            advertising.put("number", number)
            param.put("application", application)
            param.put("equipment", equipment)
            param.put("advertising", advertising)
        } catch (e: JSONException) {
            e.printStackTrace()
        }

        return RequestBody.create("application/json".toMediaTypeOrNull(), param.toString())
    }

}