package com.mints.goodmoney.manager;

import android.app.Activity;
import android.content.Context;
import android.view.View;
import android.widget.Toast;

import com.bytedance.sdk.openadsdk.AdSlot;
import com.bytedance.sdk.openadsdk.TTAdConstant;
import com.bytedance.sdk.openadsdk.TTAdNative;
import com.bytedance.sdk.openadsdk.TTAdSdk;
import com.bytedance.sdk.openadsdk.TTAppDownloadListener;
import com.bytedance.sdk.openadsdk.TTFeedAd;
import com.bytedance.sdk.openadsdk.TTImage;
import com.bytedance.sdk.openadsdk.TTNativeExpressAd;
import com.bytedance.sdk.openadsdk.TTRewardVideoAd;
import com.chineseall.reader.lib.reader.callbacks.OnAdViewReceiver;
import com.chineseall.reader17ksdk.ChineseAllReaderApplication;
import com.chineseall.reader17ksdk.aop.AspectTest;
import com.chineseall.reader17ksdk.utils.LogUtils;
import com.chineseall.reader17ksdk.utils.book.ScreenUtils;
import com.mints.goodmoney.utils.ToastUtil;
import com.mints.library.utils.json.JsonUtil;

import java.util.List;

/**
 * 中文在线 听读 穿山甲广告
 */
public class ReadToutiaoAD {

    private static final String tag = "ToutiaoAD";

    private TTAdNative mTTAdNative;

    private TTRewardVideoAd mttRewardVideoAd;
    private View mView;

    public void loadAD(final Context context, OnAdViewReceiver receiver, int width, int height, OnClickListener listener) {
        LogUtils.d(tag, "load ad");

        if (mTTAdNative == null) {
            mTTAdNative = TtCsjAdManager.get().createAdNative(context);
        }

        initFeedAD(receiver, width, height, listener);
    }

    public void loadVideoAd(Context context, OnAdViewReceiver receiver) {
        if (mTTAdNative == null) {
            mTTAdNative = TtCsjAdManager.get().createAdNative(context);
        }
        initVedioAD(context, receiver);
    }

    private void initFeedAD(OnAdViewReceiver receiver, int width, int height, OnClickListener clickListener) {
        //设置广告参数
        AdSlot adSlot = new AdSlot.Builder()
                .setCodeId(TtCsjAdManager.TT_AD_NATIVEEXPRESS_READ) //广告位id
                .setSupportDeepLink(true)
                .setAdCount(1) //请求广告数量为1到3条
                .setExpressViewAcceptedSize(width, height) //必填：期望个性化模板广告view的size,单位dp
                .setImageAcceptedSize(400, 150) //这个参数设置即可，不影响个性化模板广告的size
                .build();
        mTTAdNative.loadNativeExpressAd(adSlot, new TTAdNative.NativeExpressAdListener() {
            @Override
            public void onError(int code, String message) {
                LogUtils.d(tag, "code: " + code + ", " + message);
                receiver.onReceive(false, null);
            }

            @Override
            public void onNativeExpressAdLoad(List<TTNativeExpressAd> ads) {
                if (ads == null || ads.size() == 0) {
                    return;
                }
                LogUtils.d(tag, "onNativeExpressAdLoad : " + ads.size());
                TTNativeExpressAd mTTAd = ads.get(0);
                bindAdListener(mTTAd, receiver, clickListener);
                mTTAd.render();//调用render开始渲染广告
            }
        });
    }

    //绑定广告行为
    private void bindAdListener(TTNativeExpressAd ad, OnAdViewReceiver receiver, OnClickListener clickListener) {
        ad.setExpressInteractionListener(new TTNativeExpressAd.ExpressAdInteractionListener() {
            @Override
            public void onAdClicked(View view, int type) {
                LogUtils.d(tag, "onAdClicked : " + type);
                LogUtils.d("onAdClicked");
                if (clickListener != null) {
                    clickListener.onClick();
                }
            }

            @Override
            public void onAdShow(View view, int type) {
                LogUtils.d(tag, "onAdShow : " + type);
                LogUtils.d("onAdShow");
            }

            @Override
            public void onRenderFail(View view, String msg, int code) {
                LogUtils.d(tag, "onRenderFail : " + msg + ", " + code);
                receiver.onReceive(false, view);
            }

            @Override
            public void onRenderSuccess(View view, float width, float height) {
                LogUtils.d(tag, "onRenderSuccess : " + view.getClass().getName());
                //返回view的宽高 单位 dp
                //在渲染成功回调时展示广告，提升体验
//                getAdParamers().parent.removeAllViews();
//                getAdParamers().parent.addView(view);
                mView = view;
                if (mView != null && !AspectTest.views.contains(view.getClass().getName())) {
                    AspectTest.views.add(view.getClass().getName());
                }
                receiver.onReceive(true, view);
//                adParamers.listener.onADLoaded(com.rice.gluepudding.ad.impl.ToutiaoAD.this);
            }
        });
        //dislike设置
//        bindDislike(ad, false);
        if (ad.getInteractionType() != TTAdConstant.INTERACTION_TYPE_DOWNLOAD) {
            return;
        }
        //可选，下载监听设置
        ad.setDownloadListener(new TTAppDownloadListener() {
            @Override
            public void onIdle() {
                LogUtils.d(tag, "onIdle : ");
//                TToast.show(NativeExpressActivity.this, "点击开始下载", Toast.LENGTH_LONG);
            }

            @Override
            public void onDownloadActive(long totalBytes, long currBytes, String fileName, String appName) {
                LogUtils.d(tag, "onDownloadActive : ");
//                if (!mHasShowDownloadActive) {
//                    mHasShowDownloadActive = true;
//                    TToast.show(NativeExpressActivity.this, "下载中，点击暂停", Toast.LENGTH_LONG);
//                }
            }

            @Override
            public void onDownloadPaused(long totalBytes, long currBytes, String fileName, String appName) {
                LogUtils.d(tag, "onDownloadPaused : ");
//                TToast.show(NativeExpressActivity.this, "下载暂停，点击继续", Toast.LENGTH_LONG);
            }

            @Override
            public void onDownloadFailed(long totalBytes, long currBytes, String fileName, String appName) {
                LogUtils.d(tag, "onDownloadFailed : ");
//                TToast.show(NativeExpressActivity.this, "下载失败，点击重新下载", Toast.LENGTH_LONG);
            }

            @Override
            public void onInstalled(String fileName, String appName) {
                LogUtils.d(tag, "onInstalled : ");
//                TToast.show(NativeExpressActivity.this, "安装完成，点击图片打开", Toast.LENGTH_LONG);
            }

            @Override
            public void onDownloadFinished(long totalBytes, String fileName, String appName) {
                LogUtils.d(tag, "onDownloadFinished : ");
//                TToast.show(NativeExpressActivity.this, "点击安装", Toast.LENGTH_LONG);
            }
        });
    }

    private void initVedioAD(final Context context, OnAdViewReceiver receiver) {
        AdSlot adSlot = new AdSlot.Builder()
                .setCodeId(TtCsjAdManager.TT_AD_VEDIO_READ)
                .setSupportDeepLink(true)
                //个性化模板广告需要设置期望个性化模板广告的大小,单位dp,激励视频场景，只要设置的值大于0即可。仅模板广告需要设置此参数
                .setExpressViewAcceptedSize(500, 500)
                .setImageAcceptedSize(1080, 1920)
                .setUserID(UserManager.getInstance().getUserID())//用户id,必传参数
                .setMediaExtra("media_extra")
                .setOrientation(TTAdConstant.VERTICAL)
                .build();
        mTTAdNative.loadRewardVideoAd(adSlot, new TTAdNative.RewardVideoAdListener() {
            @Override
            public void onError(int code, String message) {
                LogUtils.i("ToutiaoAd", message);
//                adParamers.listener.onAdFailed("error");
                receiver.onReceive(false, null);
                ToastUtil.show(context,"视频加载失败，请退出重试");

            }

            //视频广告加载后的视频文件资源缓存到本地的回调
            @Override
            public void onRewardVideoCached() {
                LogUtils.i("ToutiaoAd", "rewardVideoAd video cached");
            }

            //视频广告素材加载到，如title,视频url等，不包括视频文件
            @Override
            public void onRewardVideoAdLoad(TTRewardVideoAd ad) {
//                    Log.i("ToutiaoAd","rewardVideoAd loaded");
                mttRewardVideoAd = ad;
                receiver.onReceive(true, null);
                //mttRewardVideoAd.setShowDownLoadBar(false);
            }
        });
    }

    public void showVideo(Context context, OnVideoCloseCallBack callBack) {
        if (mttRewardVideoAd != null) {
            mttRewardVideoAd.setRewardAdInteractionListener(new TTRewardVideoAd.RewardAdInteractionListener() {

                @Override
                public void onAdShow() {
                    LogUtils.i("ToutiaoAd", "rewardVideoAd onAdShow");
//                        adParamers.listener.onADLoaded(com.rice.gluepudding.ad.impl.ToutiaoAD.this);
                }

                @Override
                public void onAdVideoBarClick() {
                    LogUtils.i("ToutiaoAd", "rewardVideoAd onAdVideoBarClick");
//                        adParamers.listener.onAdClick();
                }

                @Override
                public void onAdClose() {
                    LogUtils.i("ToutiaoAd", "rewardVideoAd onAdClose");
                    if (callBack != null) {
                        callBack.onClose();
                    }
//                        adParamers.listener.onAdDismiss();
//                        EventBus.getDefault().post(new ADCloseEvent(SharedPreferencesUtil.getInstance().getInt(StringConstants.LOOK_VEDIO_TYPE, LOOK_VEDIO_AD_TYPE.NORMAL)));

                }

                @Override
                public void onVideoComplete() {
                    LogUtils.i("ToutiaoAd", "rewardVideoAd complete");
//                        Toast.makeText(context,"恭喜您，观看完毕！",Toast.LENGTH_SHORT).show();
                }

                @Override
                public void onVideoError() {
                    LogUtils.i("ToutiaoAd", "rewardVideoAd onVideoError");
//                        if (com.burst.ad_toutiao_lib.BuildConfig.DEBUG){
//                    Toast.makeText(context, "视频播放错误", Toast.LENGTH_SHORT).show();
//                        }
//                    ToastUtil.show(context,"视频加载失败，请退出重试");
                }

                @Override
                public void onRewardVerify(boolean b, int i, String s, int i1, String s1) {

                }

                @Override
                public void onSkippedVideo() {

                }
            });
            mttRewardVideoAd.setDownloadListener(new TTAppDownloadListener() {
                @Override
                public void onIdle() {

                }

                @Override
                public void onDownloadActive(long totalBytes, long currBytes, String fileName, String appName) {

                }

                @Override
                public void onDownloadPaused(long totalBytes, long currBytes, String fileName, String appName) {

                }

                @Override
                public void onDownloadFailed(long totalBytes, long currBytes, String fileName, String appName) {

                }

                @Override
                public void onDownloadFinished(long totalBytes, String fileName, String appName) {

                }

                @Override
                public void onInstalled(String fileName, String appName) {

                }
            });
            mttRewardVideoAd.showRewardVideoAd((Activity) context);
        }
    }

    public interface OnVideoCloseCallBack {
        void onClose();
    }

    public interface OnClickListener {
        void onClick();
    }
}
