package com.mints.goodmoney.manager

import android.app.Application
import android.app.Dialog
import android.view.View
import androidx.appcompat.app.AlertDialog
import com.chineseall.reader.lib.reader.callbacks.OnAdViewReceiver
import com.chineseall.reader17ksdk.ChineseAllReaderApplication.Companion.install
import com.chineseall.reader17ksdk.callbacks.AdProvider
import com.chineseall.reader17ksdk.utils.ActivityStackManager
import com.chineseall.reader17ksdk.utils.DensityUtil.dip2px
import com.chineseall.reader17ksdk.utils.DensityUtil.px2dip
import com.chineseall.reader17ksdk.utils.NetworkUtil.isNetworkAvailable
import com.chineseall.reader17ksdk.utils.NetworkUtil.isWifiConnected
import com.chineseall.reader17ksdk.utils.book.ScreenUtils
import com.mints.goodmoney.MintsApplication

/**
 * 中文在线 听读
 * 作者：孟崔广
 * 时间：2021/04/08 14:44
 * 邮箱：mengcga@163.com
 */
object ReaderManager {

    private const val APP_ID = "1242"
    private const val SECRET = "hzq@1242"
    private const val APP = "32"
    private const val SUBAPP = "0"

    private val csjAd by lazy { ReadToutiaoAD() }
    private val ylhAd by lazy { ReadYlhAd() }

    private const val csjVedioAD: String = "CSJ"
    private const val ylhVedioAD: String = "Ylh"
    private var curVedioAd: String = ""

    private var isCsjAd: Boolean = true

    fun init() {
        val applicationContext = MintsApplication.getContext()
        install(applicationContext, APP_ID, SECRET, APP, SUBAPP, object : AdProvider {
            /**
             * 阅读⻚弹窗广告确认按钮的点击回调-激励视频
             * @param dialog
             * @param block 对话框关闭回调，必须调用，否则计时每次切换章节都会出现弹窗
             */
            override fun onAdDialogPositiveClick(dialog: Dialog?, function0: Function0<Unit>) {
                if (isNetworkAvailable(applicationContext) && !isWifiConnected(applicationContext)) {
                    AlertDialog.Builder(ActivityStackManager.getInstance().topActivity)
                            .setTitle("温馨提示")
                            .setMessage("当前处于移动网络，播放视频会消耗流量，确定播放？")
                            .setPositiveButton("观看视频") { dialog, which ->
                                onAdDialogInvoke(function0)
                            }.setNegativeButton("取消") { dialog, which -> dialog.dismiss() }
                            .create().show()
                    return
                } else {
                    onAdDialogInvoke(function0)
                }
            }

            /**
             * 阅读⻚首次打开 弹框广告(信息流) 广告宽度 320 高度 260 * @param adViewContainer 广告view的容器
             */
            override fun getReaderScreenAd(view: View, receiver: OnAdViewReceiver,
                                           dialog: Dialog?) {
                csjAd.loadAD(applicationContext, receiver, 320, 260, ReadToutiaoAD.OnClickListener { dialog!!.dismiss() })
            }

            /**
             * 阅读⻚翻⻚广告(信息流) 广告宽度 320 高度 260
             */
            override fun getReaderPageAd(receiver: OnAdViewReceiver) {
                csjAd.loadAD(applicationContext, receiver, px2dip(applicationContext, ScreenUtils.getScreenWidth(applicationContext) - dip2px(applicationContext, 30f).toFloat()), px2dip(applicationContext, 854f), null)
            }

            /**
             * 阅读⻚定时弹窗广告 (激励视频)
             */
            override fun getReaderDialogAd(view: View, receiver: OnAdViewReceiver, dialog: Dialog?) {
                if (isCsjAd) {
                    curVedioAd = csjVedioAD
                    csjAd.loadVideoAd(ActivityStackManager.getInstance().topActivity, receiver)
                } else {
                    curVedioAd = ylhVedioAD
                    ylhAd.loadVideoAd(ActivityStackManager.getInstance().topActivity, receiver)
                }
                isCsjAd = !isCsjAd
            }
        })
    }

    private fun onAdDialogInvoke(function0: () -> Unit) {
        when (curVedioAd) {
            csjVedioAD -> {
                csjAd.showVideo(ActivityStackManager.getInstance().topActivity) { function0.invoke() }
            }
            ylhVedioAD -> {
                ylhAd.showVideo(ActivityStackManager.getInstance().topActivity) { function0.invoke() }
            }
        }
    }
}