package com.mints.goodmoney.manager;


import android.app.Activity;
import android.text.TextUtils;

import com.mints.goodmoney.MintsApplication;
import com.mints.goodmoney.mvp.presenters.TrackPresenter;

import java.util.HashMap;

/**
 * 描述：离线管理器
 */
public class TrackManager {

    private static volatile TrackManager _inst;

    private TrackPresenter trackPresenter = null;

    public static TrackManager getInstance() {
        if (_inst == null) {
            synchronized (TrackManager.class) {
                if (_inst == null) {
                    _inst = new TrackManager();
                }
            }
        }
        return _inst;
    }

    private TrackManager() {
        init();
    }

    private void init() {
        trackPresenter = new TrackPresenter();
        trackPresenter.attachView(MintsApplication.getContext());
    }

    /**
     * 离线收益
     */
    public void offline() {
        if (trackPresenter != null &&
                UserManager.getInstance().userIsLogin() &&
                !TextUtils.isEmpty(UserManager.getInstance().getTokenID())) {
            trackPresenter.offline();
        }
    }

    /**
     * 广告事件
     */
    public void addCallImp(String adSource, String eventType, String errorcode, String errormsg) {
        if (trackPresenter != null) {
            trackPresenter.addCallImp(adSource, eventType, errorcode, errormsg);
        }
    }

    /**
     * 激励视频点击
     */
    public void reportClickAdEvent() {
        if (trackPresenter != null) {
            trackPresenter.reportClickAdEvent();
        }
    }

    /**
     * 每日任务是否刷新任务数
     */
    public void innerApp() {
        if (trackPresenter != null) {
            trackPresenter.innerApp();
        }
    }


    /**
     * 提现看视频
     */
    public void drawcashVideo() {
        if (trackPresenter != null) {
            trackPresenter.drawcashVideo();
        }
    }

    /**
     * 喜马拉雅听书时间
     */
    public void addXmlyTime(int second) {
        if (trackPresenter != null) {
            trackPresenter.addCarrierTypeTime(second);
        }
    }

    public void getCommonHallBaseMsg() {
        if (trackPresenter != null) {
            trackPresenter.getCommonHallBaseMsg();
        }
    }

    public void firstApiWithUid() {
        if (trackPresenter != null
                && !TextUtils.isEmpty(UserManager.getInstance().getUserID())) {
            trackPresenter.firstApiWithUid();
        }
    }

    public void saveInstallAppRecord(String pkg, String name, String icon) {
        if (trackPresenter != null && !TextUtils.isEmpty(UserManager.getInstance().getUserID())) {
            trackPresenter.saveInstallAppRecord(pkg, name, icon);
        }
    }

    /**
     * 穿山甲和珊瑚由回调发放奖励
     *
     * @param activity
     * @param vo
     */
    public void reportAddCoinMsg(Activity activity, HashMap<String, Object> vo) {
        if (trackPresenter != null) {
            trackPresenter.reportAddCoinMsg(activity, vo);
        }
    }

    public void reportErrornterface(String url, String request) {
        if (trackPresenter != null ) {
            trackPresenter.reportErrornterface(url, request);
        }
    }

    public void getAdWeight() {
        if (trackPresenter != null && !TextUtils.isEmpty(UserManager.getInstance().getUserID())) {
            trackPresenter.getAdWeight();
        }
    }

    public void riskinfo() {
        if (trackPresenter != null && !TextUtils.isEmpty(UserManager.getInstance().getUserID())) {
            trackPresenter.riskinfo();
        }
    }
}
