package com.mints.goodmoney.mvp.presenters

import com.google.gson.JsonObject
import com.mints.goodmoney.manager.AppHttpManager
import com.mints.goodmoney.manager.UserManager
import com.mints.goodmoney.mvp.model.AccountMsgBean
import com.mints.goodmoney.mvp.model.BaseResponse
import com.mints.goodmoney.mvp.model.UserBean
import com.mints.goodmoney.mvp.views.AccountMergeView
import com.mints.library.net.neterror.BaseSubscriber
import com.mints.library.net.neterror.Throwable
import java.util.HashMap

class AccountMergePresenter : BasePresenter<AccountMergeView>() {

    /**
     * 获取双账号用户信息
     */
    fun getKeepAccountMsg(keepOneAccountKey: String) {
        val vo = HashMap<String, Any>()
        vo["keepOneAccountKey"] = keepOneAccountKey
        AppHttpManager.getInstance(loanApplication)
                .call(loanService.getKeepAccountMsg(vo),
                        object : BaseSubscriber<BaseResponse<AccountMsgBean>>() {
                            override fun onCompleted() {
                            }

                            override fun onError(e: Throwable) {
                            }

                            override fun onNext(baseResponse: BaseResponse<AccountMsgBean>) {
                                if (isLinkView) return
                                val code = baseResponse.status
                                val message = baseResponse.message
                                when (code) {
                                    200 -> {
                                        view.getKeepAccountMsgSuc(baseResponse.data)
                                    }
                                    else -> {
                                        view.showToast(message)
                                        view.getKeepAccountMsgFail()
                                    }
                                }
                            }
                        })
    }

    /**
     * 保留双账号用户信息
     */
    fun toKeepAccount(toDoKey: String, saveType: Int) {
        val vo = HashMap<String, Any>()
        vo["toDoKey"] = toDoKey
        vo["saveType"] = saveType
        AppHttpManager.getInstance(loanApplication)
                .call(loanService.toKeepAccount(vo),
                        object : BaseSubscriber<BaseResponse<UserBean>>() {
                            override fun onCompleted() {
                            }

                            override fun onError(e: Throwable) {
                            }

                            override fun onNext(baseResponse: BaseResponse<UserBean>) {
                                if (isLinkView) return
                                val code = baseResponse.status
                                val message = baseResponse.message
                                when (code) {
                                    200 -> if (baseResponse.data != null) {
                                        UserManager.getInstance().saveUserInfo(baseResponse.data)
                                        view.toKeepAccountSuc()
                                    }
                                    else -> {
                                        view.showToast(message)
                                        view.toKeepAccountFail()
                                    }
                                }
                            }
                        })
    }

}