package com.mints.goodmoney.mvp.presenters

import com.google.gson.JsonObject
import com.mints.goodmoney.manager.AppHttpManager
import com.mints.goodmoney.mvp.model.BaseResponse
import com.mints.goodmoney.mvp.model.FriendHallMsgBean
import com.mints.goodmoney.mvp.views.FriendsView
import com.mints.library.net.neterror.BaseSubscriber
import com.mints.library.net.neterror.Throwable

class FriendsPresenter : BasePresenter<FriendsView>() {

    /**
     * 分红奖励信息
     */
    fun getFriendHallMsg() {
        AppHttpManager.getInstance(loanApplication)
                .call(loanService.friendHallMsg(), object : BaseSubscriber<BaseResponse<FriendHallMsgBean>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onError(e: Throwable) {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onNext(baseResponse: BaseResponse<FriendHallMsgBean>) {
                        if (isLinkView) return
                        view.hideLoading()

                        when (baseResponse.status) {
                            200 -> {
                                view.getFriendsHallMsgSuc(baseResponse.data)
                            }
                            else -> {
                                view.showToast("网络出小差儿了")
                            }
                        }
                    }
                })
    }

    /**
     * 今日收益榜
     */
    fun getContributionLeaders() {
        AppHttpManager.getInstance(loanApplication)
                .call(loanService.contributionLeaders(), object : BaseSubscriber<BaseResponse<FriendHallMsgBean>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onError(e: Throwable) {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onNext(baseResponse: BaseResponse<FriendHallMsgBean>) {
                        if (isLinkView) return
                        view.hideLoading()

                        when (baseResponse.status) {
                            200 -> {
                                view.getContributionLeadersSuc(baseResponse.data)
                            }
                            else -> {
                                view.showToast(baseResponse.message)
                            }
                        }
                    }
                })
    }


    /**
     * 总榜单
     */
    fun getContributionBigLeaders() {
        AppHttpManager.getInstance(loanApplication)
                .call(loanService.contributionBigLeaders(), object : BaseSubscriber<BaseResponse<FriendHallMsgBean>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onError(e: Throwable) {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onNext(baseResponse: BaseResponse<FriendHallMsgBean>) {
                        if (isLinkView) return
                        view.hideLoading()

                        when (baseResponse.status) {
                            200 -> {
                                view.getContributionBigLeadersSuc(baseResponse.data)
                            }
                            else -> {
                                view.showToast(baseResponse.message)
                            }
                        }
                    }
                })
    }

    /**
     * 今日贡献榜
     */
    fun getFriendsGiveTodayList() {
        AppHttpManager.getInstance(loanApplication)
                .call(loanService.friendsGiveTodayList, object : BaseSubscriber<BaseResponse<FriendHallMsgBean>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onError(e: Throwable) {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onNext(baseResponse: BaseResponse<FriendHallMsgBean>) {
                        if (isLinkView) return
                        view.hideLoading()

                        when (baseResponse.status) {
                            200 -> {
                                view.getFriendsGiveTodayListSuc(baseResponse.data)
                            }
                            else -> {
                                view.showToast(baseResponse.message)
                            }
                        }
                    }
                })
    }

    /**
     * 收益提现
     */
    fun getContributionOutToCash() {
        AppHttpManager.getInstance(loanApplication)
                .call(loanService.contributionOutToCash(), object : BaseSubscriber<BaseResponse<JsonObject>>() {
                    override fun onCompleted() {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onError(e: Throwable) {
                        if (isLinkView) return
                        view.hideLoading()
                    }

                    override fun onNext(baseResponse: BaseResponse<JsonObject>) {
                        if (isLinkView) return
                        view.hideLoading()

                        when (baseResponse.status) {
                            200 -> {
                                view.getContributionOutToCashSuc()
                            }
                            else -> {
                                view.showToast(baseResponse.message)
                            }
                        }
                    }
                })
    }

    /**
     * 设置邀请成功
     *
     */
//    fun cmtShareStatus() {
//        val vo = HashMap<String, Any>()
//        vo["carrierType"] = Constant.CHALLENGE_SHAREFRIEND
//        vo["value"] = "1"
//        AppHttpManager.getInstance(loanApplication)
//                .call(loanService.setStatusInOneDayByCarrierType(vo), object : BaseSubscriber<BaseResponse<Any>>() {
//                    override fun onCompleted() {
//                        if (isLinkView) return
//                    }
//
//                    override fun onError(e: Throwable) {
//                        if (isLinkView) return
//                    }
//
//                    override fun onNext(baseResponse: BaseResponse<Any>) {
//                        if (isLinkView) return
//                        when (baseResponse.status) {
//                                    200 -> baseMsg()
//                        }
//                    }
//                })
//    }


}