package com.mints.goodmoney.mvp.presenters

import android.text.TextUtils
import com.google.gson.Gson
import com.google.gson.JsonObject
import com.mints.goodmoney.BuildConfig
import com.mints.goodmoney.common.DeviceInfo
import com.mints.goodmoney.manager.AppHttpManager
import com.mints.goodmoney.manager.CpdManager
import com.mints.goodmoney.mvp.model.BaseResponse
import com.mints.goodmoney.mvp.model.CpdModelBean
import com.mints.goodmoney.mvp.model.SydCpdListBean
import com.mints.goodmoney.mvp.views.TaskView
import com.mints.goodmoney.net.CpdService
import com.mints.goodmoney.utils.LogUtil
import com.mints.library.net.neterror.BaseSubscriber
import com.mints.library.net.neterror.Throwable
import com.mints.library.utils.json.JsonUtil

class TaskPresenter : BasePresenter<TaskView>() {

    fun getShCpdTime() {
        val vo = HashMap<String, Any>()
        vo["isAndroid10"] = TextUtils.isEmpty(DeviceInfo.instance.iMEI)

        view.showLoading("加载中...")
        AppHttpManager.getInstance(loanApplication)
                .call(loanService.getShCpdTime(vo),
                        object : BaseSubscriber<BaseResponse<JsonObject>>() {
                            override fun onCompleted() {
                            }

                            override fun onError(e: Throwable) {
                                if (isLinkView) return

                                view.hideLoading()
                            }

                            override fun onNext(baseResponse: BaseResponse<JsonObject>) {
                                if (isLinkView) return
                                val code = baseResponse.status
                                val data = baseResponse.data
                                when (code) {
                                    200 -> {
                                        if (data != null) {
                                            view.getShCpdTimeSuc(
                                                    data.get("needSeconds").asInt,
                                                    data.get("coin").asInt,
                                                    data.get("CPD").asInt,
                                                    data.get("CPD_SYD").asInt,
                                                    data.get("cpdOrder").asString
                                            )
                                        }
                                    }
                                }
                            }
                        })
    }

    fun cmtImp(url: String) {
        AppHttpManager.getInstance(loanApplication)
                .call(CpdService.Factory.getInstance().cmtImp(url),
                        object : BaseSubscriber<JsonObject>() {
                            override fun onCompleted() {
                            }

                            override fun onError(e: Throwable) {
                                if (isLinkView) return
                                LogUtil.d("TaskPresenter", "onError->${e.printStackTrace()}")
                            }

                            override fun onNext(baseResponse: JsonObject) {
                                if (isLinkView) return
                                if (BuildConfig.DEBUG) {
                                    LogUtil.d("TaskPresenter", "onNext->${url}   JsonUtil:${JsonUtil.toJson(baseResponse)}")
                                }

                            }
                        })
    }

    fun getCpdDetail(ip: String) {
        AppHttpManager.getInstance(loanApplication)
                .call(CpdService.Factory.getInstance().getAdVedio(CpdManager.getCpdUrl(), CpdManager.getCpdBody(ip)),
                        object : BaseSubscriber<JsonObject>() {
                            override fun onCompleted() {
                            }

                            override fun onError(e: Throwable) {
                                view.getCpdModelFail()
                            }

                            override fun onNext(t: JsonObject?) {
                                if (isLinkView) return
                                val gson = Gson()
                                val response = gson.fromJson<CpdModelBean>(t.toString(), CpdModelBean::class.java)
                                if (response.code == 0) {
                                    val data = response.data
                                    if (data != null) {
                                        view.getCpdModelSuc(data)
                                    } else {
                                        view.getCpdModelFail()
                                    }
                                } else {
                                    view.getCpdModelFail()
                                }
                            }

                        })
    }

    fun getCpdListDetail(ip: String, number: Int) {
        AppHttpManager.getInstance(loanApplication)
                .call(CpdService.Factory.getInstance().getAdVedio(CpdManager.getCpdLisrUrl(), CpdManager.getCpdListBody(ip, number)),
                        object : BaseSubscriber<JsonObject>() {
                            override fun onCompleted() {
                            }

                            override fun onError(e: Throwable) {
                                view.getCpdModelFail()
                            }

                            override fun onNext(t: JsonObject?) {
                                if (isLinkView) return
                                val gson = Gson()
                                val response = gson.fromJson<SydCpdListBean>(t.toString(), SydCpdListBean::class.java)
                                if (response.code == 0) {
                                    val data = response.data
                                    if (data != null) {
                                        view.getCpdListModelSuc(data)
                                    } else {
                                        view.getCpdModelFail()
                                    }
                                } else {
                                    view.getCpdModelFail()
                                }
                            }
                        })
    }
}