package com.mints.goodmoney.mvp.presenters

import android.text.TextUtils
import com.google.gson.Gson
import com.google.gson.JsonObject
import com.google.gson.reflect.TypeToken
import com.mints.goodmoney.MintsApplication
import com.mints.goodmoney.common.DeviceInfo
import com.mints.goodmoney.manager.AppHttpManager
import com.mints.goodmoney.manager.ShumeiManager
import com.mints.goodmoney.manager.UserManager
import com.mints.goodmoney.mvp.model.BaseResponse
import com.mints.goodmoney.mvp.model.ClickTurnBean
import com.mints.goodmoney.mvp.model.TurnBean
import com.mints.goodmoney.mvp.model.UserBean
import com.mints.goodmoney.mvp.views.TurnTableView
import com.mints.goodmoney.utils.DeviceUuidFactory
import com.mints.library.net.neterror.BaseSubscriber
import com.mints.library.net.neterror.Throwable
import java.util.*


class TurnTablePresenter : BasePresenter<TurnTableView>() {

    fun getTurnMsg() {
        AppHttpManager.getInstance(loanApplication)
                .call(loanService.getTurnMsg(),
                        object : BaseSubscriber<BaseResponse<TurnBean>>() {
                            override fun onCompleted() {
                            }

                            override fun onError(e: Throwable) {
                                if (isLinkView) return
                                view.showToast(e.message)
                            }

                            override fun onNext(baseResponse: BaseResponse<TurnBean>) {
                                if (isLinkView) return
                                val code = baseResponse.getStatus()
                                val message = baseResponse.getMessage()
                                when (code) {
                                    200 -> {
                                        view.getTurnTableSuc(baseResponse.data)
                                    }
                                    else -> view.showToast(message)
                                }
                            }
                        })
    }

    fun addTurnToOtherMsg(toOtherKey: String) {
        val vo = HashMap<String, Any>()
        vo["toOther"] = toOtherKey
        AppHttpManager.getInstance(loanApplication)
                .call(loanService.addTurnToOtherMsg(vo),
                        object : BaseSubscriber<BaseResponse<Any>>() {
                            override fun onCompleted() {
                            }

                            override fun onError(e: Throwable) {
                                if (isLinkView) return
                                view.showToast(e.message)
                            }

                            override fun onNext(baseResponse: BaseResponse<Any>) {
                                if (isLinkView) return
                                val code = baseResponse.getStatus()
                                val message = baseResponse.getMessage()
                                when (code) {
                                    200 -> {
                                    }
                                    else -> view.showToast(message)
                                }
                            }
                        })
    }

    fun cashoutLeaders() {
        AppHttpManager.getInstance(loanApplication)
                .call(loanService.cashoutLeaders(),
                        object : BaseSubscriber<BaseResponse<JsonObject>>() {
                            override fun onCompleted() {
                            }

                            override fun onError(e: Throwable) {
                            }

                            override fun onNext(baseResponse: BaseResponse<JsonObject>) {
                                if (isLinkView) return
                                val code = baseResponse.getStatus()
                                val message = baseResponse.getMessage()
                                when (code) {
                                    200 -> {
                                        val data = baseResponse.data
                                        if (data.get("list") != null) {
                                            val listArray = Gson().fromJson(data.get("list"),
                                                    object : TypeToken<ArrayList<String>>() {}.type) as ArrayList<String>
                                            view.cashoutLeadersSuc(listArray)
                                        }
                                    }
                                    else -> view.showToast(message)
                                }
                            }
                        })
    }

    fun clickForTurn() {
        AppHttpManager.getInstance(loanApplication)
                .call(loanService.clickForTurn(),
                        object : BaseSubscriber<BaseResponse<ClickTurnBean>>() {
                            override fun onCompleted() {
                            }

                            override fun onError(e: Throwable) {
                                if (isLinkView) return
                                view.showToast(e.message)
                            }

                            override fun onNext(baseResponse: BaseResponse<ClickTurnBean>) {
                                if (isLinkView) return
                                val code = baseResponse.getStatus()
                                val message = baseResponse.getMessage()
                                when (code) {
                                    200 -> {
                                        view.clickForTurnSuc(baseResponse.data)
                                    }
                                    else -> view.showToast(message)
                                }
                            }
                        })
    }

    /**
     * 游客登录
     */
    fun userLogin() {
        val vo = HashMap<String, Any>()
        vo["device"] = DeviceUuidFactory().deviceUuid.toString()
        vo["shumeiId"] = ShumeiManager.getInstance().shumeiDeviceId
        AppHttpManager.getInstance(loanApplication)
                .call(loanService.visitorlogin(vo),
                        object : BaseSubscriber<BaseResponse<UserBean>>() {
                            override fun onCompleted() {
                            }

                            override fun onError(e: Throwable) {
                            }

                            override fun onNext(baseResponse: BaseResponse<UserBean>) {
                                if (isLinkView) return
                                val code = baseResponse.getStatus()
                                val message = baseResponse.getMessage()
                                val data: UserBean? = baseResponse.getData()
                                when (code) {
                                    200 -> if (data != null) {
                                        UserManager.getInstance().saveUserInfo(data)
                                        saveTerminalInfo()
                                    }
                                    else -> view.showToast(message)
                                }
                            }
                        })
    }

    /**
     * 提交设备信息
     *
     * @param context
     */
    fun saveTerminalInfo() {
        val vo = HashMap<String, Any>()
        val deviceInfo: DeviceInfo = DeviceInfo.instance
        val macAddress: String = deviceInfo.getMacAddress()
        val mac = macAddress.replace(":", "")
        vo["mac"] = mac
        vo["mac1"] = macAddress
        vo["androidid"] = deviceInfo.getAndroidId(null)
        vo["imei"] = deviceInfo.iMEI
        if (!TextUtils.isEmpty(MintsApplication.OAID)) {
            vo["oaid"] = MintsApplication.OAID
        }
        vo["os"] = "android"
        vo["model"] = deviceInfo.newModel
        vo["uuid"] = DeviceUuidFactory().deviceUuid
        vo["osversion"] = deviceInfo.oSVersion
        vo["appversion"] = deviceInfo.versionName
        vo["shumeiId"] = ShumeiManager.getInstance().getShumeiDeviceId()
        AppHttpManager.getInstance(loanApplication)
                .call(loanService.saveTerminalInfo(vo),
                        object : BaseSubscriber<BaseResponse<Any>>() {
                            override fun onCompleted() {
                                if (isLinkView) return
                            }

                            override fun onError(e: Throwable) {
                                if (isLinkView) return
                            }

                            override fun onNext(baseResponse: BaseResponse<Any>) {
                                if (isLinkView) return
                                val code = baseResponse.status
                                when (code) {
                                    200 -> {
                                        getTurnMsg()
                                    }
                                }
                            }
                        })
    }
}