package com.mints.goodmoney.ui.activitys

import android.annotation.SuppressLint
import android.os.Bundle
import android.view.View
import androidx.core.content.ContextCompat
import com.mints.goodmoney.R
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.manager.BxmManager
import com.mints.goodmoney.manager.RsNewsManager
import com.mints.goodmoney.manager.SceneManager
import com.mints.goodmoney.mvp.model.AccountMsgBean
import com.mints.goodmoney.mvp.presenters.AccountMergePresenter
import com.mints.goodmoney.mvp.views.AccountMergeView
import com.mints.goodmoney.ui.activitys.base.BaseActivity
import com.mints.goodmoney.ui.widgets.dialog.CustomDialogAsApple
import com.mints.goodmoney.ui.widgets.dialog.DialogListener
import com.mints.goodmoney.utils.SpanUtils
import com.mints.library.utils.GlideUtils
import kotlinx.android.synthetic.main.activity_account_merge.*
import kotlinx.android.synthetic.main.header_layout.*

/**
 * 描述：账号合并
 * 作者：孟崔广
 * 时间：2020/9/23 18:39
 */
@SuppressLint("SetTextI18n")
class AccountMergeActivity : BaseActivity(), View.OnClickListener, AccountMergeView {

    private lateinit var mobile: String
    private lateinit var wxOpenId: String
    private lateinit var keepOneAccountKey: String

    private var cdaa: CustomDialogAsApple? = null
    private var toDoKey: String? = null

    private val accountMergePresenter by lazy { AccountMergePresenter() }

    companion object {
        const val TYPE_SAVE_MOBILE = 1
        const val TYPE_SAVE_WECHAT = 2
    }

    override fun getContentViewLayoutID() = R.layout.activity_account_merge

    override fun isApplyKitKatTranslucency() = false

    override fun getBundleExtras(extras: Bundle?) {
        super.getBundleExtras(extras)
        extras?.let {
            mobile = it.getString(Constant.MERGE_MOBILE, "")
            wxOpenId = it.getString(Constant.MERGE_WXOPENID, "")
            keepOneAccountKey = it.getString(Constant.MERGE_KEY, "")
        }
    }

    override fun initViewsAndEvents() {
        tv_title.text = "账号合并"
        iv_left_icon.visibility = View.VISIBLE
        iv_left_icon.setImageResource(R.mipmap.ic_arrow_back)
        accountMergePresenter.attachView(this)
        initListener()

        if (::keepOneAccountKey.isInitialized) {
            accountMergePresenter.getKeepAccountMsg(keepOneAccountKey)
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        accountMergePresenter.detachView()
    }

    override fun onClick(v: View?) {
        when (v?.id) {
            R.id.iv_left_icon -> finish()
            R.id.btn_invite_left -> {
                toDoKey?.let {
                    hintDialog(it, "微信", TYPE_SAVE_WECHAT)
                }
            }
            R.id.btn_invite_right -> {
                toDoKey?.let {
                    hintDialog(it, "手机", TYPE_SAVE_MOBILE)
                }
            }
        }
    }

    private fun initListener() {
        iv_left_icon.setOnClickListener(this)
        btn_invite_left.setOnClickListener(this)
        btn_invite_right.setOnClickListener(this)
    }

    private fun hintDialog(toDoKey: String, str: String, type: Int) {
        val content = SpanUtils()
                .append("保留后微信会跟手机号绑定\r\n仅保留")
                .append(str + "账号").setForegroundColor(ContextCompat.getColor(mContext, R.color.color_FF2326))
                .append("下的数据\r\n")
                .append("另一个账号的数据将会被删除")
                .create()

        cdaa = CustomDialogAsApple(context, object : DialogListener() {
            override fun onClick(v: View) {
                if (cdaa != null && cdaa!!.isShowing) {
                    cdaa!!.dismiss()
                }
                when (v.id) {
                    R.id.dialog_btn_left -> {

                    }
                    R.id.dialog_btn_right -> {
                        accountMergePresenter.toKeepAccount(toDoKey, type)
                    }
                }
            }
        })
        cdaa!!.setTitle("温馨提示")
        cdaa!!.setContent(content)
        cdaa!!.setLeft("考虑一下")
        cdaa!!.setRightDelay("确认绑定", 5)
        cdaa!!.show()
    }

    override fun getKeepAccountMsgSuc(data: AccountMsgBean) {
        data.let {
            toDoKey = it.toDoKey

            GlideUtils.loadImageViewLoding(context, it.wxUser.head, civ_avatar_left, R.mipmap.ic_my, R.mipmap.ic_my)
            GlideUtils.loadImageViewLoding(context, it.mobileUser.head, civ_avatar_right, R.mipmap.ic_my, R.mipmap.ic_my)
            tv_name_left.text = "" + it.wxUser.account
            tv_coin_left.text = "金币 " + it.wxUser.coin
            tv_bonus_left.text = "贡献 " + it.wxUser.contribution
            tv_invited_left.text = "亲友 " + it.wxUser.sons
            tv_name_right.text = "" + it.mobileUser.account
            tv_coin_right.text = "金币 " + it.mobileUser.coin
            tv_bonus_right.text = "贡献 " + it.mobileUser.contribution
            tv_invited_right.text = "亲友 " + it.mobileUser.sons
        }
    }

    override fun getKeepAccountMsgFail() {}

    override fun toKeepAccountSuc() {
        showToast("账号合并成功！")

        SceneManager.signIn(this)
        BxmManager.bindUserData()


        readyGoThenKill(MainActivity::class.java)
    }

    override fun toKeepAccountFail() {}
}
