package com.mints.goodmoney.ui.activitys

import android.annotation.SuppressLint
import android.content.BroadcastReceiver
import android.content.Context
import android.content.Intent
import android.content.IntentFilter
import android.os.Bundle
import android.text.TextUtils
import android.view.KeyEvent
import android.view.View
import androidx.core.content.ContextCompat
import com.mints.goodmoney.R
import com.mints.goodmoney.ad.express.PreLoadExpressManager
import com.mints.goodmoney.ad.video.VideoAdingManager
import com.mints.goodmoney.common.AppConfig
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.common.DeviceInfo.Companion.instance
import com.mints.goodmoney.manager.AppTryPlayManager
import com.mints.goodmoney.manager.TrackManager
import com.mints.goodmoney.manager.UserManager
import com.mints.goodmoney.mvp.model.VideoAdingBean
import com.mints.goodmoney.mvp.presenters.AwardPresenter
import com.mints.goodmoney.mvp.views.AwardView
import com.mints.goodmoney.service.AppInstallService
import com.mints.goodmoney.ui.activitys.base.BaseActivity
import com.mints.goodmoney.ui.widgets.countdowntimer.CountDownTimerSupport
import com.mints.goodmoney.ui.widgets.countdowntimer.OnCountDownTimerListener
import com.mints.goodmoney.utils.*
import com.mints.goodmoney.utils.AppUtil.getAppName
import com.mints.goodmoney.utils.rxutil.CommonRxTask
import com.mints.goodmoney.utils.rxutil.RxjavaUtil
import com.umeng.analytics.MobclickAgent
import kotlinx.android.synthetic.main.activity_award.*
import java.math.BigDecimal
import java.util.*

/**
 * 描述：奖励界面
 * 作者：孟崔广
 * 时间：2020/10/09 15:47
 */
@SuppressLint("SetTextI18n")
class AwardActivity : BaseActivity(), AwardView, View.OnClickListener {

    private lateinit var videoAdingManager: VideoAdingManager
    private val awardPresenter by lazy { AwardPresenter() }
    private var mTimer: CountDownTimerSupport? = null
    private var curCoin = 0 //传入金币
    private var extraId = ""//传入key
    private var carrierType = ""//传入载体
    private var aid = ""//传入体验任务的aid
    private var loadVideoFailCount = 0 // 视频失败次数

    // 超级翻倍领取状态 0-去下载 1-去试玩 2-试玩时间不足 3-领取奖励 4-放弃试玩
    private var superTaskStatus = 0
    private var mCurrentPkg: String? = null
    private var mReceiverBroadcastReceiver: BroadcastReceiver? = null

    override fun getContentViewLayoutID() = R.layout.activity_award

    override fun isApplyKitKatTranslucency() = false

    override fun toggleOverridePendingTransition() = true

    override fun getOverridePendingTransitionMode() = TransitionMode.SCALE

    override fun initViewsAndEvents() {
        awardPresenter.attachView(this)

        videoAdingManager = VideoAdingManager.getInstance(this)

        if (!AppConfig.app_black_flag) {
            // 首次进行黑名单校验
            judgeAppInfo()
        } else {
            pushAward()
        }

//        initExpress()
        initListener()
        initDataView()
    }

    /**
     * 校验是否属于黑名单
     */
    private fun judgeAppInfo() {
        val deviceInfo = instance
        RxjavaUtil.executeRxTask<String>(object : CommonRxTask<String?>("") {
            override fun doInIOThread() {
                var result = "false"

                val serverBlackName = AppConfig.app_black_name
                val serverBlackPkg = AppConfig.app_black_pkg

                // 校验应用名称
                if (!TextUtils.isEmpty(serverBlackName)) {
                    val sysNameList = deviceInfo.getAppNameInfoList()
                    if (sysNameList != null && sysNameList.size > 0) {
                        val serverBlackNameList = serverBlackName.split(",")
                        for (serverBlackName in serverBlackNameList) {
                            if (TextUtils.equals(result, "true")) {
                                break
                            }
                            for (sysName in sysNameList) {
                                // 系统名称 包含 服务名称
                                if (sysName.contains(serverBlackName)) {
                                    result = "true"
                                    break
                                }
                            }
                        }
                    }
                }

                // 校验应用包名
                if (TextUtils.equals(result, "false") && !TextUtils.isEmpty(serverBlackPkg)) {
                    val sysPkgList = deviceInfo.getAppPkgInfoList()
                    if (sysPkgList != null && sysPkgList.size > 0) {
                        val serverBlackPkgList = serverBlackPkg.split(",")
                        for (serverBlackPkg in serverBlackPkgList) {
                            if (TextUtils.equals(result, "true")) {
                                break
                            }
                            for (sysPkgName in sysPkgList) {
                                // 系统名称 包含 服务名称
                                if (sysPkgName.contains(serverBlackPkg)) {
                                    result = "true"
                                    break
                                }
                            }
                        }
                    }
                }

                t = result
            }

            override fun doInUIThread() {
                if (TextUtils.equals(t.toString(), "true")) {
                    // 黑名单
                    awardPresenter.saveTerminalInfo()
                    carrierType = Constant.CARRIER_BLACK
                }
                AppConfig.app_black_flag = true
                pushAward()
            }
        })
    }

    private fun initDataView() {
        // 金币声音
        try {
            SoundPoolUtil.getInstance().getGoldVoice()
        } catch (e: Exception) {
            e.printStackTrace()
        }
        // 获取按键栏
        Utils.hideBottomUIMenu(this)
        // 开启3秒倒计时
        startTime()

        // 第一次进来上送友盟
        pushUmengEvent()
    }

    /**
     * 发放奖励
     */
    private fun pushAward() {
        when (carrierType) {
            Constant.CARRIER_HOMEVEDIO_CHALLENGE, Constant.CARRIER_MINIVEDIO_CHALLENGE,
            Constant.CARRIER_GAME_ONLINE, Constant.CARRIER_EATMEAL,
            Constant.CARRIER_RUISHINEWS_CHALLANGE, Constant.CARRIER_ZHANGYUE_CHALLENGE,
            Constant.CARRIER_XMLY_CHALLENGE, Constant.CARRIER_SHARE_NEWS,
            Constant.CARRIER_MC_FIRSTDOWNLOAD -> {
                val vo = HashMap<String, Any>()
                vo["carrierType"] = carrierType
                awardPresenter.reportAddCoinMsg(vo)

                tvAwardContent.text = "${curCoin}金币已到账"
                tvAwardNext.text = "我知道了"
            }
            Constant.CARRIER_FIRSTDOWNLOADS -> {
                val vo = HashMap<String, Any>()
                vo["carrierType"] = carrierType
                vo["key"] = extraId
                awardPresenter.reportAddCoinMsg(vo)

                tvAwardContent.text = "${curCoin}金币已到账"
                tvAwardNext.text = "我知道了"
            }
            Constant.CARRIER_BLESSINGBAG -> {
                val vo = HashMap<String, Any>()
                vo["carrierType"] = carrierType
                awardPresenter.reportAddCoinMsg(vo)

                tvAwardContent.text = "${curCoin}金币已到账"
                tvAwardNext.setCompoundDrawablesWithIntrinsicBounds(ContextCompat.getDrawable(this, R.mipmap.icon_video), null, null, null)
                tvAwardNext.text = "再领${extraId}金币"

                curCoin = extraId.toInt()
                carrierType = Constant.CARRIER_BLESSINGBAG_DOUBLE
            }
            Constant.CARRIER_HOMEVEDIO -> {
                val vo = HashMap<String, Any>()
                vo["carrierType"] = carrierType
                awardPresenter.reportAddCoinMsg(vo)

                tvAwardContent.text = "${curCoin}金币已到账"
                tvAwardNext.setCompoundDrawablesWithIntrinsicBounds(ContextCompat.getDrawable(this, R.mipmap.icon_video), null, null, null)
                tvAwardNext.text = "再领${extraId}金币"

                curCoin = extraId.toInt()
                carrierType = Constant.CARRIER_HOMEVEDIO_DOUBLE
            }
            Constant.CARRIER_RUISHINEWS -> {
                val vo = HashMap<String, Any>()
                vo["carrierType"] = carrierType
                awardPresenter.reportAddCoinMsg(vo)

                tvAwardContent.text = "${curCoin}金币已到账"
                tvAwardNext.setCompoundDrawablesWithIntrinsicBounds(ContextCompat.getDrawable(this, R.mipmap.icon_video), null, null, null)
                tvAwardNext.text = "再领${extraId}金币"

                curCoin = extraId.toInt()
                carrierType = Constant.CARRIER_RUISHINEWS_DOUBLE
            }
            Constant.CARRIER_SMALLHOMEVEDIO -> {
                val vo = HashMap<String, Any>()
                vo["carrierType"] = carrierType
                awardPresenter.reportAddCoinMsg(vo)

                tvAwardContent.text = "${curCoin}金币已到账"
                tvAwardNext.setCompoundDrawablesWithIntrinsicBounds(ContextCompat.getDrawable(this, R.mipmap.icon_video), null, null, null)
                tvAwardNext.text = "再领${extraId}金币"

                curCoin = extraId.toInt()
                carrierType = Constant.CARRIER_SMALLHOMEVEDIO_DOUBLE
            }
            Constant.CHALLENGE_SHAREFRIEND -> {
                val vo = HashMap<String, Any>()
                vo["carrierType"] = carrierType
                awardPresenter.reportAddCoinMsg(vo)

                tvAwardContent.text = "${curCoin}金币已到账"
                tvAwardNext.setCompoundDrawablesWithIntrinsicBounds(ContextCompat.getDrawable(this, R.mipmap.icon_video), null, null, null)
                tvAwardNext.text = "再领${extraId}金币"

                curCoin = extraId.toInt()
                carrierType = Constant.CARRIER_CHALLENGE_SHAREFRIEND_DOUBLE
            }
            Constant.CARRIER_NEW_USER -> {
                tvAwardContent.text = "新人红包"
                tvAwardNext.text = "我知道了"
                tvAwardHint.visibility = View.VISIBLE
                tvAwardHint.text = "${curCoin}金币已到账"
            }
            Constant.CARRIER_NEW_VISITOR -> {
                tvAwardContent.text = "新人红包"
                tvAwardNext.text = "点击领取"
                tvAwardHint.visibility = View.VISIBLE
                tvAwardHint.text = "${curCoin}金币已到账"
            }
            Constant.CARRIER_OFFLINE_DOUBLE -> {
                tvAwardContent.text = "离线收益奖励${curCoin}金币"
                tvAwardNext.setCompoundDrawablesWithIntrinsicBounds(ContextCompat.getDrawable(this, R.mipmap.icon_video), null, null, null)
                tvAwardNext.text = "金币翻倍"
            }
            Constant.CARRIER_ZHANGYUE -> {
                tvAwardContent.text = "阅读奖励${curCoin}金币"
                tvAwardNext.text = "领取金币"
            }
            Constant.CARRIER_SIGNIN_HOMEPAGE_AWARD -> {
                tvAwardContent.text = "签到奖励${curCoin}金币"
                tvAwardNext.setCompoundDrawablesWithIntrinsicBounds(ContextCompat.getDrawable(this, R.mipmap.icon_video), null, null, null)
                tvAwardNext.text = "最高可得3倍金币奖励"

                carrierType = Constant.CARRIER_SIGNIN_HOMEPAGE_CARD
            }
            Constant.CARRIER_EATMEAL_SUBSIDY_NOT -> {
                tvAwardContent.text = "还未到吃饭时间"
                tvAwardNext.text = "我知道了"
            }
            Constant.CARRIER_GAME -> {
                if (curCoin > 0) {
                    tvAwardContent.text = "游戏奖励${curCoin}金币"
                } else {
                    tvAwardContent.text = "很遗憾,游戏试玩不足3秒"
                }
                tvAwardNext.text = "我知道了"
            }
            Constant.CARRIER_HIGH_ACTIVITY, Constant.CARRIER_CPD, Constant.CARRIER_CPD_SYD, Constant.CARRIER_CPD_USEAPP -> {
                if (curCoin > 0) {
                    tvAwardContent.text = "试玩奖励${curCoin}金币"
                    tvAwardNext.text = "领取金币"

                    val vo = HashMap<String, Any>()
                    vo["carrierType"] = carrierType
                    if (carrierType == Constant.CARRIER_CPD_USEAPP) {
                        vo["aid"] = aid
                    }
                    awardPresenter.reportAddCoinMsg(vo)

                } else {
                    tvAwardContent.text = "很遗憾,试玩时间不足"
                    tvAwardNext.text = "我知道了"
                }
            }
            Constant.CARRIER_SIGNIN_HOMEPAGE_CARD -> {
                tvAwardContent.text = "奖励金币已发放"
                tvAwardNext.visibility = View.GONE
                tvAwardHint.visibility = View.GONE
                tvAwardHighInfo2.visibility = View.GONE
            }
            Constant.CARRIER_CHALLENGE_TURN, Constant.CARRIER_CHALLENGE_CARD,
            Constant.CARRIER_WALK_BUBBLE, Constant.CARRIER_EATMEAL_SUBSIDY,
            Constant.CARRIER_WALK, Constant.CARRIER_HOMEWATER -> {
                tvAwardContent.text = "+${curCoin}金币"
                tvAwardNext.setCompoundDrawablesWithIntrinsicBounds(ContextCompat.getDrawable(this, R.mipmap.icon_video), null, null, null)
                tvAwardNext.text = "领取金币"
            }
            else -> {
                tvAwardContent.text = "${curCoin}金币已到账"
                tvAwardNext.text = "领取金币"
            }
        }
    }

    /**
     * 推送umeng事件埋点
     */
    private fun pushUmengEvent() {
        if (!TextUtils.isEmpty(carrierType) && curCoin > 0) {
            // 埋点上送事件
            val map = mutableMapOf<String, String>()
            map["userId"] = UserManager.getInstance().userID
            map["coin"] = "" + curCoin
            MobclickAgent.onEvent(this, carrierType, map)
        }
    }

    override fun finish() {
        super.finish()
        //关闭窗体动画显示
        overridePendingTransition(0, R.anim.scale_out)
    }

    override fun getBundleExtras(extras: Bundle?) {
        super.getBundleExtras(extras)
        extras?.let {
            curCoin = it.getInt(Constant.MAIN_CUR_COIN, 0)
            extraId = it.getString(Constant.MAIN_EXTRA_ID, "")
            carrierType = it.getString(Constant.MAIN_CARRIER_TYPE, "")
            aid = it.getString(Constant.MAIN_AID, "")
        }
    }

    override fun onResume() {
        super.onResume()

        MobclickAgent.onPageStart(this::class.java.simpleName)
        MobclickAgent.onResume(this)

        awardPresenter.getCoinMsg()
    }

    override fun onPause() {
        super.onPause()

        MobclickAgent.onPageEnd(this::class.java.simpleName)
        MobclickAgent.onPause(this)
    }

    override fun onDestroy() {
        AppConfig.isSuperTask = false

        if (mReceiverBroadcastReceiver != null) {
            if (mReceiverBroadcastReceiver!!.isInitialStickyBroadcast) {
                mContext.stopService(Intent(context, AppInstallService::class.java))
                mContext.unregisterReceiver(mReceiverBroadcastReceiver)
                mReceiverBroadcastReceiver = null
            }
        }

        awardPresenter.setHighTaskType("0")

        mTimer?.stop()
        mTimer = null

        try {
            PreLoadExpressManager.loadADFrameLayout()
        } catch (e: java.lang.Exception) {
            e.printStackTrace()
        }

        SoundPoolUtil.getInstance().onDestory()
        PreLoadExpressManager.onDestroy()

//        flAwardAd?.removeAllViews()
        videoAdingManager.setVideoAdingListener(null)
        videoAdingManager.onDestroy()

        awardPresenter.detachView()

        super.onDestroy()
    }

    override fun onKeyDown(keyCode: Int, event: KeyEvent): Boolean {
        return if (keyCode == KeyEvent.KEYCODE_BACK) {
            true
        } else super.onKeyDown(keyCode, event)
    }

    override fun onClick(v: View) {
        when (v.id) {
            R.id.ivAwardBack -> {
                finish()
            }
            R.id.tvAwardHigh -> {
                when (superTaskStatus) {
                    // 播放激励视频，注册安装监听
                    0 -> {
                        // 是否开启应用使用情况权限
                        if (AppUtil.isOpenUsageStats()) {
                            registerBroad()
                            awardVideo()
                        } else {
                            AppTryPlayManager.openAppUsageStats(this)
                        }
                    }
                    // 下载完成，点击去试玩
                    1 -> {
                        if (mCurrentPkg == null) {
                            showToast("任务异常，请重试~")
                            awardPresenter.setHighTaskType("0")

                        } else {
                            if (AppUtil.checkPackInfo(mContext, mCurrentPkg!!)) {
                                AppTryPlayManager.toTryPlay(mCurrentPkg!!)
                            } else {
                                showToast("未找到当前APP、可能被卸载，请重试~")
                            }
                        }
                    }
                    // 试玩时间不足，继续试玩
                    2 -> {
                        if (mCurrentPkg == null) {
                            showToast("任务异常，请重试~")
                            awardPresenter.setHighTaskType("0")
                        } else {
                            if (AppUtil.checkPackInfo(mContext, mCurrentPkg!!)) {
                                AppTryPlayManager.toTryPlay(mCurrentPkg!!)
                            } else {
                                showToast("未找到当前APP、可能被卸载，请重试~")
                            }
                        }
                    }
                    // 试玩完成，领取奖励
                    3 -> {
                        val vo = HashMap<String, Any>()
                        vo["carrierType"] = Constant.CARRIER_HIGH_ACTIVITY
                        awardPresenter.reportAddCoinMsg(vo)

                        readyGoThenKill(DrawcashActivity::class.java)
                    }
                }
            }
            R.id.tvAwardNext -> {
                // 普通视频奖励 走公共下载监听
                AppConfig.isSuperTask = false
                superTaskStatus = 4

                when (carrierType) {
                    // 只有看视频才能领金币
                    Constant.CARRIER_OFFLINE_DOUBLE, Constant.CARRIER_SIGNIN_HOMEPAGE_CARD,
                    Constant.CARRIER_CHALLENGE_TURN, Constant.CARRIER_CHALLENGE_CARD,
                    Constant.CARRIER_WALK_BUBBLE, Constant.CARRIER_EATMEAL_SUBSIDY,
                    Constant.CARRIER_WALK, Constant.CARRIER_HOMEWATER -> {
                        awardVideo()
                    }
                    Constant.CARRIER_BLESSINGBAG_DOUBLE, Constant.CARRIER_CHALLENGE_SHAREFRIEND_DOUBLE,
                    Constant.CARRIER_HOMEVEDIO_DOUBLE, Constant.CARRIER_SMALLHOMEVEDIO_DOUBLE,
                    Constant.CARRIER_RUISHINEWS_DOUBLE -> {
                        // 翻倍载体上送友盟
                        pushUmengEvent()
                        awardVideo()
                    }
                    Constant.CARRIER_NEW_VISITOR -> {
                        readyGoThenKill(WxLoginActivity::class.java)
                    }
                    else -> {
                        finish()
                    }
                }
            }
        }
    }

    /**
     * 获取激励视频
     */
    private fun awardVideo() {
        if (AppConfig.isVideoSleep) {
            showToast("加载失败，请稍后重试。")
            return
        } else if (videoAdingManager.videoFinishFlag) {
            showToast("今日视频已看完，请明天再来吧")
            return
        }

        showLoading("加载中...")

        val bean = VideoAdingBean()
        bean.carrierType = carrierType
        bean.curCoin = curCoin
        bean.extraId = extraId

        loadVideo(videoAdingManager, bean, true)
    }

    /**
     * 加载激励视频
     */
    private fun loadVideo(videoAdingManager: VideoAdingManager, bean: VideoAdingBean, isFirstLoad: Boolean) {
        videoAdingManager.setVideoAdingListener(object : VideoAdingManager.VideoAdingListener {
            override fun videoAdingListenerError(adType: String) {
                showToast("加载超时，请休息一下")
                hideLoading()
            }

            override fun videoAdingListenerFail(adType: String) {
                loadVideoFailCount++
                if (loadVideoFailCount >= 3) {
                    hideLoading()
                    showToast("加载失败，请稍后重试!")
                } else {
                    loadVideo(videoAdingManager, bean, false)
                }
            }

            override fun videoAdingListenerSuccess(adType: String) {
                hideLoading()
                videoAdingSuccess(adType)
            }
        })
        if (isFirstLoad) {
            // 首页按权重加载
            videoAdingManager.loadAding(this, bean)
        } else {
            // 失败按优先级加载
            videoAdingManager.loadFailAding(this, bean)
        }
    }

    private fun initListener() {
        tvAwardHigh.setOnClickListener(this)
        tvAwardNext.setOnClickListener(this)
        ivAwardBack.setOnClickListener(this)
    }

    /**
     * 弹窗倒计时
     */
    private fun startTime() {
        mTimer = CountDownTimerSupport(3000L, 1000L)
        mTimer?.setOnCountDownTimerListener(object : OnCountDownTimerListener {
            override fun onTick(millisUntilFinished: Long) {
                if (!this@AwardActivity.isFinishing) {
                    tvAwardBack?.text = "${millisUntilFinished / 1000}"
                }
            }

            override fun onFinish() {
                if (!this@AwardActivity.isFinishing) {
                    ivAwardBack?.visibility = View.VISIBLE
                    tvAwardBack?.visibility = View.GONE
                }
            }
        })
        mTimer?.start()
    }

    override fun getUserTaskMsgSuc(coin: Int, riskFlag: Boolean, showHigh: Boolean, highCoin: Int) {
        if (carrierType == Constant.CARRIER_CHALLENGE_TURN || // 大转盘
                carrierType == Constant.CARRIER_BLESSINGBAG || // 首页福袋
                carrierType == Constant.CARRIER_HOMEVEDIO || // 首页红包
                carrierType == Constant.CARRIER_SMALLHOMEVEDIO || // 短视频红包
                carrierType == Constant.CARRIER_BLESSINGBAG_DOUBLE || // 首页福袋翻倍
                carrierType == Constant.CARRIER_SMALLHOMEVEDIO_DOUBLE || // 短视频红包翻倍
                carrierType == Constant.CARRIER_HOMEVEDIO_DOUBLE) { // 小视频红包翻倍
            AppConfig.isSuperTask = showHigh
            if (AppConfig.isSuperTask) {
                refreshHighTask(highCoin)
            }
        }

        val sumCoin = coin.toString()
        val allcoinBig = BigDecimal(sumCoin)
        val rateBig = BigDecimal("10000")
        val cashStr = allcoinBig.divide(rateBig).setScale(2, BigDecimal.ROUND_DOWN).toString()

        tvAwardCash.text = SpanUtils()
                .append("我的金币").setFontSize(40).setForegroundColor(ContextCompat.getColor(this, R.color.color_333))
                .append(sumCoin).setFontSize(40).setForegroundColor(ContextCompat.getColor(this, R.color.color_FF9837))
                .append("≈").setFontSize(40).setForegroundColor(ContextCompat.getColor(this, R.color.color_333))
                .append("" + cashStr).setFontSize(40).setForegroundColor(ContextCompat.getColor(this, R.color.color_FF9837))
                .append("元").setFontSize(40).setForegroundColor(ContextCompat.getColor(this, R.color.color_333))
                .create()

        // 上传风控信息
        if (riskFlag) {
            TrackManager.getInstance().riskinfo()
        }
    }

    /**
     * 随机广告完成回调
     */
    private fun setAdFinshLayout() {
        if (!isFinishing) {
            tvAwardContent.text = "奖励金币已发放"
            tvAwardNext.visibility = View.GONE
            tvAwardHint.visibility = View.GONE
            tvAwardHighInfo2.visibility = View.GONE
        }
    }

    /**
     * 广告返回结果
     */
    private fun videoAdingSuccess(adType: String) {
        setAdFinshLayout()
    }

    private fun initExpress() {
        try {
            if (flAwardAd != null) {
                flAwardAd.removeAllViews()
                flAwardAd.addView(PreLoadExpressManager.getADFrameLayout())
            }
        } catch (e: Exception) {
            e.printStackTrace()
        }
    }

    /**
     * 刷新高额任务
     */
    private fun refreshHighTask(highCoin: Int) {
        if (mCurrentPkg == null) {
            // 用户点击激励视频但并未下载安装
            // 超级翻倍领取状态 0-去下载 1-去试玩 2-试玩时间不足 3-领取奖励 4-放弃试玩
            //(mReceiverBroadcastReceiver != null && superTaskStatus == 0)  表示 点击超级翻倍去下载
            //(mReceiverBroadcastReceiver == null && superTaskStatus == 4)  表示 普通任务未下载
            if ((mReceiverBroadcastReceiver != null && superTaskStatus == 0) ||
                    (mReceiverBroadcastReceiver == null && superTaskStatus == 4)) {

                tvAwardHighContent.visibility = View.VISIBLE
                tvAwardHighInfo.visibility = View.GONE
                tvAwardHighInfo2.visibility = View.GONE
                tvAwardHigh.visibility = View.GONE

                tvAwardHighContent.text = "未完成下载安装"
            } else {
                tvAwardHighContent.visibility = View.VISIBLE
                tvAwardHighInfo.visibility = View.VISIBLE
                tvAwardHigh.visibility = View.VISIBLE
                tvAwardHighInfo2.visibility = View.VISIBLE

                tvAwardHighContent.text = "超级加倍即可领取" + highCoin + "金币，" + highCoin + "金币=" + ToolUtil.formatNumCNY(highCoin) + "元，可立即到账"
                tvAwardHighInfo.text = "下载安装打开领取" + highCoin + "金币"
                tvAwardHighInfo2.text = "获得少量金币"
                tvAwardHigh.text = "超级加倍领取"
            }
        } else {
            // 用户没有开启
            if (AppUtil.getTimePkgUsed(this, mCurrentPkg!!) == -1) {
                superTaskStatus = 1
                tvAwardHighContent.visibility = View.VISIBLE
                tvAwardHighInfo.visibility = View.VISIBLE
                tvAwardHigh.visibility = View.VISIBLE

                tvAwardContent.text = "超级加倍 领取" + highCoin + "金币"
                tvAwardHighContent.text = "打开APP，试玩30秒钟，提现" + ToolUtil.formatNumCNY(highCoin) + "元，可立即到账"
                tvAwardHighInfo.visibility = View.GONE
                tvAwardHighInfo2.visibility = View.GONE
                tvAwardHigh.text = "打开APP领取" + highCoin + "金币"
                return
            }

            // 用户开启
            if (AppTryPlayManager.getTryPlayIsOK(mCurrentPkg!!, 30)) {
                awardPresenter.setHighTaskType("1")

                tvAwardHighContent.visibility = View.VISIBLE
                tvAwardHighInfo.visibility = View.VISIBLE
                tvAwardHigh.visibility = View.VISIBLE

                superTaskStatus = 3
                tvAwardContent.text = "超级加倍 领取" + highCoin + "金币"
                tvAwardHighContent.text = "超级加倍即可领取" + highCoin + "金币，" + highCoin + "金币=" + ToolUtil.formatNumCNY(highCoin) + "元，可立即到账"
                tvAwardHighInfo.visibility = View.GONE
                tvAwardHighInfo2.visibility = View.GONE
                tvAwardHigh.text = "领取" + highCoin + "金币提现" + ToolUtil.formatNumCNY(highCoin) + "元"
            } else {
                tvAwardHighContent.visibility = View.VISIBLE
                tvAwardHighInfo.visibility = View.VISIBLE
                tvAwardHigh.visibility = View.VISIBLE

                superTaskStatus = 2
                tvAwardContent.text = "超级加倍 领取" + highCoin + "金币"
                tvAwardHighContent.text = "打开APP，试玩30秒钟，提现" + ToolUtil.formatNumCNY(highCoin) + "元，可立即到账"
                tvAwardHighInfo.visibility = View.GONE
                tvAwardHighInfo2.visibility = View.GONE
                tvAwardHigh.text = "时间不足，打开继续体验"
            }
        }
    }

    /**
     * 注册任务监听
     */
    private fun registerBroad() {
        if (mReceiverBroadcastReceiver != null) return

        mContext.startService(Intent(context, AppInstallService::class.java))

        mReceiverBroadcastReceiver = object : BroadcastReceiver() {
            override fun onReceive(context: Context?, intent: Intent?) {
                if (intent == null) return
                // 非高额任务不监听下载安装
                if (AppConfig.isSuperTask) {
                    try {
                        val pkg = intent.getStringExtra("pkg")
                        mCurrentPkg = pkg

                        awardPresenter.setHighTaskType("3")

                        val appName = getAppName(pkg, this@AwardActivity)
                        TrackManager.getInstance().saveInstallAppRecord(pkg, appName, "")

                    } catch (e: Exception) {
                        e.printStackTrace()
                    }
                }
            }
        }

        val intentFilter = IntentFilter()
        intentFilter.addAction(AppInstallService.APP_INSTALL_ACTION)
        mContext.registerReceiver(this.mReceiverBroadcastReceiver, intentFilter)
    }
}