package com.mints.goodmoney.ui.activitys

import android.Manifest
import android.os.Bundle
import android.text.TextUtils
import android.view.View
import com.mints.goodmoney.R
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.manager.UserManager
import com.mints.goodmoney.mvp.presenters.LoginPresenter
import com.mints.goodmoney.mvp.views.LoginView
import com.mints.goodmoney.ui.activitys.base.BaseActivity
import com.mints.goodmoney.utils.BackInputUtil
import com.mints.library.utils.nodoubleclick.AntiShake
import com.tbruyelle.rxpermissions.RxPermissions
import kotlinx.android.synthetic.main.activity_bind_mobile.*
import kotlinx.android.synthetic.main.header_layout.*

/**
 * 描述：绑定手机号
 * 作者：孟崔广
 * 时间：2020/9/22 13:55
 */
class BindMobileActivity : BaseActivity(), LoginView, View.OnClickListener {

    private val loginPresenter by lazy { LoginPresenter() }
    private var mobile: String? = null

    override fun initViewsAndEvents() {
        loginPresenter.attachView(this)
        initView()
        initListener()
    }

    override fun getContentViewLayoutID() = R.layout.activity_bind_mobile

    override fun isApplyKitKatTranslucency() = false

    override fun onDestroy() {
        super.onDestroy()
        loginPresenter.detachView()
    }

    override fun onClick(v: View?) {
        if (AntiShake.check(v?.id)) return

        when (v?.id) {
            R.id.iv_left_icon -> {
                finish()
            }
            R.id.tvLoginSendcode -> {
                var mobile = etLoginMobile.text.toString().trim()
                if (mobile.length < 13) {
                    showToast("请输入手机号")
                    return
                }
                sendCodeThread()

                mobile = mobile.replace(" ".toRegex(), "")
                loginPresenter.sendMobileBindingCode(mobile)
            }
            R.id.tvLoginNext -> {
                var mobile = etLoginMobile.text.toString().trim()
                if (mobile.length < 13) {
                    showToast("请输入手机号")
                    return
                }

                val code = etLoginCode.text.toString().trim()
                if (code.length < 4) {
                    showToast("请输入验证码")
                    return
                }

                RxPermissions(this@BindMobileActivity)
                        .request(Manifest.permission.READ_PHONE_STATE)
                        .subscribe { granted: Boolean ->
                            if (granted) {

                                mobile = mobile.replace(" ".toRegex(), "")
                                loginPresenter.bindingMobile(mobile, code)
                            } else {
                                showMissingPermissionDialog("设备")
                            }
                        }
            }
        }
    }

    override fun loginSuc() {
        showToast("绑定成功")
        progressDialog?.dismiss()
        finish()
    }

    override fun sendCodeSuc() {

    }

    override fun mergeAccount(mobile: String, wxOpenId: String, key: String) {
        val bundle = Bundle()
        bundle.putString(Constant.MERGE_MOBILE, mobile)
        bundle.putString(Constant.MERGE_WXOPENID, wxOpenId)
        bundle.putString(Constant.MERGE_KEY, key)
        readyGo(AccountMergeActivity::class.java, bundle)
    }

    private fun initView() {
        tv_title.text = "绑定手机号"
        iv_left_icon.visibility = View.VISIBLE
        iv_left_icon.setImageResource(R.mipmap.ic_arrow_back)

        BackInputUtil.phoneNumAddSpace(etLoginMobile)
        mobile = UserManager.getInstance().mobile
        if (!TextUtils.isEmpty(mobile)) {
            etLoginMobile.setText(mobile)
            etLoginMobile.setSelection(mobile!!.length + 2)
        }
    }

    private fun initListener() {
        iv_left_icon.setOnClickListener(this)
        tvLoginSendcode.setOnClickListener(this)
        tvLoginNext.setOnClickListener(this)
    }

    var num = 0
    var run: Runnable? = null

    fun sendCodeThread() {
        num = 60
        tvLoginSendcode?.let {
            it.isEnabled = false
            it.text = "（$num）重新获取"

            run = object : Runnable {
                override fun run() {
                    num--
                    if (num == 0) {
                        it.text = "重新获取"
                        it.isEnabled = true
                    } else {
                        it.text = "（$num）重新获取"
                        it.postDelayed(this, 1000)
                    }
                }
            }
            it.postDelayed(run, 1000)
        }
    }
}
