package com.mints.goodmoney.ui.activitys

import android.annotation.SuppressLint
import android.content.Intent
import android.content.pm.ApplicationInfo
import android.net.Uri
import android.os.Build
import android.view.View
import android.view.ViewGroup
import android.webkit.WebSettings
import android.webkit.WebViewClient
import com.mints.goodmoney.R
import com.mints.goodmoney.manager.UserManager
import com.mints.goodmoney.ui.activitys.base.BaseActivity
import com.mints.goodmoney.utils.MD5
import com.mints.goodmoney.utils.URIEncoder
import kotlinx.android.synthetic.main.fragment_main_dh.*
import kotlinx.android.synthetic.main.header_layout.*
import java.util.*
import kotlin.collections.HashMap

class DhGameActivity : BaseActivity(), View.OnClickListener {

    companion object {
        const val CHANNEL = "14533"
        const val KEY = "4932d9037fd94f6ba24fa09605203cd6"
        const val AUTH_URL = "http://www.shandw.com/auth/"
    }

    override fun getContentViewLayoutID() = R.layout.fragment_main_dh

    override fun isApplyKitKatTranslucency() = false

    override fun initViewsAndEvents() {
        tv_title.text = "游戏大厅"
        iv_left_icon.visibility = View.VISIBLE
        iv_left_icon.setImageResource(R.mipmap.ic_arrow_back)

        loadH5Game()
        initListener()
    }

    override fun onPause() {
        super.onPause()

        loadH5Game()
    }

    override fun onDestroy() {
        super.onDestroy()

        dh_webview?.let {
            it.destroyDrawingCache()
            (it.parent as ViewGroup).apply {
                removeView(it)
            }
            it.removeAllViews()
            it.destroy()
        }

    }

    override fun onClick(v: View?) {
        when (v?.id) {
            R.id.iv_left_icon -> finish()
        }
    }

    private fun initListener() {
        iv_left_icon.setOnClickListener(this)
    }

    /**
     * 加载H5Game
     */
    @SuppressLint("SetJavaScriptEnabled")
    private fun loadH5Game() {
        dh_webview?.let {
            val loadUrl = getLoadUrl()
            val settings = it.settings
            // 本地 DOM 存储（解决加载某些网页出现白板现象）
            settings.domStorageEnabled = true
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
                // 解决 Android 5.0 上 WebView 默认不允许加载 Http 与 Https 混合内容
                settings.mixedContentMode = WebSettings.MIXED_CONTENT_ALWAYS_ALLOW
            }
            settings.javaScriptEnabled = true
            settings.javaScriptCanOpenWindowsAutomatically = true
            it.webViewClient = object : WebViewClient() {
                override fun shouldOverrideUrlLoading(
                        view: android.webkit.WebView,
                        url: String
                ): Boolean {
                    if (url.startsWith("weixin://wap/pay?") || url.startsWith("alipay")) {
                        val hasApp: Boolean = if (url.startsWith("weixin://wap/pay?")) {
                            isAppExist("com.tencent.mm")
                        } else {
                            (isAppExist("com.eg.android.AlipayGphone") || isAppExist("com.alipay.android.app"))
                        }
                        if (hasApp) {
                            val intent = Intent()
                            intent.action = Intent.ACTION_VIEW
                            intent.data = Uri.parse(url)
                            startActivity(intent)
                        } else {
                            showToast("客官，请先安装支付App哦~")
                        }
                        return true
                    }

                    if (url.startsWith("https")) {
                        val map = HashMap<String, String>()
                        map["Referer"] = "http://www.shandw.com"
                        it.loadUrl(url, map)
                    }
                    return super.shouldOverrideUrlLoading(view, url)
                }
            }
            it.loadUrl(loadUrl)
        }
    }

    /**
     * 获取拼接url
     */
    fun getLoadUrl(): String {
        val currentTimeMillis = System.currentTimeMillis() / 1000
        return "$AUTH_URL?" +
                "channel=$CHANNEL&" +
                "openid=${URIEncoder.encodeURIComponent(UserManager.getInstance().userID)}&" +
                "time=${currentTimeMillis}&" +
                "nick=${URIEncoder.encodeURIComponent(UserManager.getInstance().userID)}&" +
                "avatar=${URIEncoder.encodeURIComponent("https://mints-pkg.oss-cn-beijing.aliyuncs.com/pkg_goodmoney/img/ic_my.png")}&" +
                "sex=${0}&" +
                "phone=${UserManager.getInstance().mobile}&" +
                "sdw_simple=${2}&" +
                "sign=${getSignStr(currentTimeMillis)}"
    }

    /**
     * 获取签名
     */
    fun getSignStr(currentTimeMillis: Long): String {
        val signStr = "channel=${CHANNEL}&" +
                "openid=${URIEncoder.encodeURIComponent(UserManager.getInstance().userID)}&" +
                "time=${currentTimeMillis}&" +
                "nick=${UserManager.getInstance().userID}&" +
                "avatar=https://mints-pkg.oss-cn-beijing.aliyuncs.com/pkg_goodmoney/img/ic_my.png&" +
                "sex=${0}&" +
                "phone=${UserManager.getInstance().mobile}${KEY}"
        return MD5.GetMD5Code(signStr).toLowerCase(Locale.ROOT)
    }

    fun isAppExist(pkgName: String): Boolean {
        var info: ApplicationInfo? = null
        try {
            info = context?.packageManager!!.getApplicationInfo(pkgName, 0)
            context!!.startActivity(context!!.packageManager.getLaunchIntentForPackage(pkgName))
        } catch (e: Exception) {
        }
        return info != null
    }
}