package com.mints.goodmoney.ui.activitys

import android.Manifest
import android.content.Context
import android.content.ContextWrapper
import android.media.MediaPlayer
import android.os.Bundle
import android.text.TextUtils
import android.util.Log
import android.view.View
import android.widget.FrameLayout
import android.widget.ImageView
import android.widget.VideoView
import androidx.recyclerview.widget.OrientationHelper
import com.bytedance.sdk.openadsdk.TTNativeExpressAd
import com.dingmouren.layoutmanagergroup.viewpager.OnViewPagerListener
import com.dingmouren.layoutmanagergroup.viewpager.ViewPagerLayoutManager
import com.downloader.Error
import com.downloader.OnDownloadListener
import com.downloader.PRDownloader
import com.mints.goodmoney.R
import com.mints.goodmoney.ad.draw.CsjDrawAdManager
import com.mints.goodmoney.ad.video.VideoAdingManager
import com.mints.goodmoney.call.business.VideoDBHelper
import com.mints.goodmoney.call.detail.DetailApplyActivity
import com.mints.goodmoney.call.permission.PermissionActivity
import com.mints.goodmoney.call.permission.PermissionManager
import com.mints.goodmoney.common.AppConfig
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.manager.UserManager
import com.mints.goodmoney.mvp.model.DrawVideoBean
import com.mints.goodmoney.mvp.model.KylBean
import com.mints.goodmoney.mvp.model.VideoAdingBean
import com.mints.goodmoney.mvp.presenters.KylVideoPresenter
import com.mints.goodmoney.mvp.views.KylVideoView
import com.mints.goodmoney.ui.activitys.base.BaseActivity
import com.mints.goodmoney.ui.adapter.DrawVideoAdapter
import com.mints.goodmoney.utils.MD5
import com.tbruyelle.rxpermissions.RxPermissions
import kotlinx.android.synthetic.main.activity_draw_native_video.*

private const val TAG = "DrawNativeVideoActivity"

/**
 * 描述：讯飞彩铃展示
 *
 */
class DrawNativeVideoActivity : BaseActivity(),
        View.OnClickListener,
        CsjDrawAdManager.CsjDrawAdListener,
        KylVideoView {

    override fun getContentViewLayoutID() = R.layout.activity_draw_native_video

    override fun isApplyKitKatTranslucency() = false

    companion object {
        const val TYPE_COMMON_ITEM = 1
        const val TYPE_AD_ITEM = 2

        // 当前数据page
        const val CURRENT_PAGE = "CURRENT_PAGE"

        // 传递过来的数据
        const val VIDEO_DATA = "VIDEO_DATA"

        // 请求视频的target_id
        const val TARGET_ID = "TARGET_ID"

        // 广告插入数值
        const val AD_INSERT_INDEX = 3

        // 来电秀跳转地址
        const val WEB_VIDEO_URL = "https://vring.kuyin123.com/friend/94aa83142f7f5c98?videoId="
    }

    // 列表页面播放page
    private var mCurrentPage = 0

    // 当前播放视频下标
    private var mCurrentPlayIndex = 0

    // 当前播放视频数据源
    private val drawDatas: MutableList<DrawVideoBean> = mutableListOf()

    // 广告请求次数
    private var mAdPage = 0

    // targerId 视频类别
    private var targerId = ""

    private val kylVideoPresenter by lazy { KylVideoPresenter() }
    private lateinit var videoAdingManager: VideoAdingManager
    private var downloadVedioSucFlag = false // 下载视频成功
    private var videoPathName = "" // 视频下载名称
    private var downloadId: Int = -1 // video下载id
    private var loadVideoFailCount = 0

    private var mDrawVideoAdapter: DrawVideoAdapter? = null
    private var mLayoutManager: ViewPagerLayoutManager? = null
    private var mCsjDrawAdManager: CsjDrawAdManager? = null

    override fun getBundleExtras(extras: Bundle?) {
        super.getBundleExtras(extras)
        mCurrentPage = extras?.getInt(CURRENT_PAGE, 0)!!
        targerId = extras.getString(TARGET_ID, "")
        val parcelableArrayList = extras.getParcelableArrayList<DrawVideoBean>(VIDEO_DATA)
        if (parcelableArrayList != null) {
            drawDatas.addAll(parcelableArrayList)
        }
    }

    override fun initViewsAndEvents() {
        kylVideoPresenter.attachView(this)

        mCsjDrawAdManager = CsjDrawAdManager.getInstance(this)
        mCsjDrawAdManager?.setCsjDrawAdListener(this)

        mLayoutManager = ViewPagerLayoutManager(this, OrientationHelper.VERTICAL)
//        mDrawVideoAdapter = DrawVideoAdapter(this, drawDatas)
        mDrawVideoAdapter = DrawVideoAdapter(drawDatas)
        recy_draw_native.setItemViewCacheSize(1)
        recy_draw_native.layoutManager = mLayoutManager
        recy_draw_native.adapter = mDrawVideoAdapter

        videoAdingManager = VideoAdingManager.getInstance(this)

        // 第一次加载广告
        if (drawDatas.size > AD_INSERT_INDEX) {
            mCsjDrawAdManager?.loadDrawNativeAd(this, 2)
        } else {
            mCsjDrawAdManager?.loadDrawNativeAd(this, 1)
        }

        initListener()
    }

    override fun onClick(v: View?) {

        when (v?.id) {
            R.id.ivBack -> finish()
            R.id.ivVedio -> {
                val bundle = Bundle()
                bundle.putString(WebActivity.WEB_TITLE, "开通视频彩铃")
                bundle.putString(WebActivity.WEB_URL, WEB_VIDEO_URL + drawDatas[mCurrentPlayIndex].videoId)
                readyGo(WebActivity::class.java, bundle)
            }
            R.id.ivSetting -> {
                if (downloadVedioSucFlag) {
                    readyGo()
                    return
                }
                RxPermissions(this)
                        .request(Manifest.permission.READ_EXTERNAL_STORAGE, Manifest.permission.WRITE_EXTERNAL_STORAGE)
                        .subscribe { granted: Boolean ->
                            if (granted) {
                                downloadVideoToCacheFile()
                                awardVideo()
                            } else {
                                showMissingPermissionDialog("存储")
                            }
                        }
            }
        }
    }

    private fun playVideo(position: Int) {
        if (isFinishing) {
            return
        }
        val itemView: View = recy_draw_native.getChildAt(0) ?: return
        val videoLayout = itemView.findViewById<FrameLayout>(R.id.video_layout)
        val view = videoLayout.getChildAt(0)
        if (view !is VideoView) {
            Log.e(TAG, "view not instanceof VideoView")
            return
        }
        val videoView = videoLayout.getChildAt(0) as VideoView
        val imgPlay = itemView.findViewById<ImageView>(R.id.img_play)
        val imgThumb = itemView.findViewById<ImageView>(R.id.img_thumb)
        val mediaPlayer = arrayOfNulls<MediaPlayer>(1)
        videoView.start()
        videoView.setOnInfoListener { mp, what, extra ->
            mediaPlayer[0] = mp
            Log.e(TAG, "onInfo")
            mp.isLooping = true
            imgThumb.animate().alpha(0f).setDuration(200).start()
            false
        }
        videoView.setOnPreparedListener { Log.e(TAG, "onPrepared") }
        videoView.setOnClickListener(object : View.OnClickListener {
            var isPlaying = true
            override fun onClick(v: View) {
                isPlaying = if (videoView.isPlaying) {
                    Log.e(TAG, "isPlaying:" + videoView.isPlaying)
                    imgPlay.animate().alpha(1f).start()
                    videoView.pause()
                    false
                } else {
                    Log.e(TAG, "isPlaying:" + videoView.isPlaying)
                    imgPlay.animate().alpha(0f).start()
                    videoView.start()
                    true
                }
            }
        })
    }

    private fun downloadVideoToCacheFile() {
        downloadVedioSucFlag = false
        val videoPath: String = try {
            getExternalFilesDir(null)!!.absolutePath + "/video/"
        } catch (e: java.lang.Exception) {
            filesDir.absolutePath + "/video/"
        }
        val videoName = MD5.GetMD5Code(System.currentTimeMillis().toString() +
                UserManager.getInstance().userID + drawDatas[mCurrentPlayIndex].videoId) + ".mp4"
        videoPathName = videoPath + videoName
        downloadId = PRDownloader.download(drawDatas[mCurrentPlayIndex].videoUrl, videoPath, videoName)
                .build()
                .start(object : OnDownloadListener {
                    override fun onDownloadComplete() {
                        downloadVedioSucFlag = true
                    }

                    override fun onError(error: Error) {
                    }
                })
    }

    private fun releaseVideo(index: Int) {
        if (isFinishing) {
            return
        }
        val itemView: View = recy_draw_native.getChildAt(index)
        val videoLayout = itemView.findViewById<FrameLayout>(R.id.video_layout) ?: return
        val view = videoLayout.getChildAt(0)
        if (view is VideoView) {
            val videoView = videoLayout.getChildAt(0) as VideoView
            val imgThumb = itemView.findViewById<ImageView>(R.id.img_thumb)
            val imgPlay = itemView.findViewById<ImageView>(R.id.img_play)
            videoView.stopPlayback()
            imgThumb.animate().alpha(1f).start()
            imgPlay.animate().alpha(0f).start()
        }
    }

    private fun initListener() {
        ivBack.setOnClickListener(this)
        ivVedio.setOnClickListener(this)
        ivSetting.setOnClickListener(this)

        mLayoutManager?.setOnViewPagerListener(object : OnViewPagerListener {
            override fun onInitComplete() {
                onLayoutComplete()
            }

            override fun onPageRelease(isNext: Boolean, position: Int) {
                Log.e(TAG, "释放位置:$position 下一页:$isNext")
                val index: Int = if (isNext) {
                    0
                } else {
                    1
                }

                if (drawDatas[position].type == TYPE_COMMON_ITEM) {
                    releaseVideo(index)
                }
            }

            override fun onPageSelected(position: Int, isBottom: Boolean) {
                Log.e(TAG, "选中位置:$position  是否是滑动到底部:$isBottom")
                mCurrentPlayIndex = position
                if (drawDatas[position].type == TYPE_COMMON_ITEM) {
                    playVideo(0)
                    changeBottomTopLayoutVisibility(true)
                } else {
                    changeBottomTopLayoutVisibility(false)
                }
                if (isBottom) {
                    loadMoreData()
                }
            }

            private fun onLayoutComplete() {
                if (drawDatas[0].type == TYPE_COMMON_ITEM) {
                    playVideo(0)
                    changeBottomTopLayoutVisibility(true)
                } else {
                    changeBottomTopLayoutVisibility(false)
                }
            }
        })
    }

    private fun loadMoreData() {
        mCurrentPage++
        kylVideoPresenter.getXfPageMsg(targerId, mCurrentPage, 3)
    }

    private fun changeBottomTopLayoutVisibility(visibility: Boolean) {
        ivVedio.visibility = if (visibility) View.VISIBLE else View.GONE
        ivSetting.visibility = if (visibility) View.VISIBLE else View.GONE
    }

    override fun onDestroy() {
        mCsjDrawAdManager?.onDestroy()
        videoAdingManager.setVideoAdingListener(null)
        videoAdingManager.onDestroy()

        super.onDestroy()

        if (downloadId != -1) {
            PRDownloader.cancel(downloadId)
        }
        kylVideoPresenter.detachView()

        mLayoutManager?.setOnViewPagerListener(null)
    }

    /**
     * 获取激励视频
     */
    private fun awardVideo() {
        if (AppConfig.isVideoSleep) {
            showToast("加载失败，请稍后重试。")
            return
        } else if (videoAdingManager.videoFinishFlag) {
            showToast("今日视频已看完，请明天再来吧")
            return
        }
        loadVideoFailCount = 0
        showLoading("加载中...")

        val bean = VideoAdingBean()
        bean.carrierType = Constant.CARRIER_KUYINYUE_VEDIO
        loadVideo(videoAdingManager, bean, true)
    }

    /**
     * 加载激励视频
     */
    private fun loadVideo(videoAdingManager: VideoAdingManager, bean: VideoAdingBean, isFirstLoad: Boolean) {
        videoAdingManager.setVideoAdingListener(object : VideoAdingManager.VideoAdingListener {
            override fun videoAdingListenerError(adType: String) {
                showToast("加载超时，请休息一下")
                hideLoading()
            }

            override fun videoAdingListenerFail(adType: String) {
                loadVideoFailCount++
                if (loadVideoFailCount >= 3) {
                    hideLoading()
                    showToast("加载失败，请稍后重试!")
                } else {
                    loadVideo(videoAdingManager, bean, false)
                }
            }

            override fun videoAdingListenerSuccess(adType: String) {
                hideLoading()
                vedioAdingSuccess(adType)
            }
        })
        if (isFirstLoad) {
            // 首页按权重加载
            videoAdingManager.loadAding(this, bean)
        } else {
            // 失败按优先级加载
            videoAdingManager.loadFailAding(this, bean)
        }
    }

    private fun vedioAdingSuccess(adType: String) {
        if (!downloadVedioSucFlag || TextUtils.isEmpty(videoPathName)) {
            showToast("视频处理中，请稍候")
            return
        }
        readyGo()
    }

    private fun readyGo() {
        if (PermissionManager.getInstance().checkEssential(this)) {
            VideoDBHelper.getInstance().setSelectVideo(this, VideoDBHelper.UNKNOWN_NUMBER, videoPathName)
            DetailApplyActivity.startSelf(this, videoPathName, true)
        } else {
            PermissionActivity.startSelf(this)
        }
    }

    override fun csjDrawAdFail() {
//        showToast("当前视频加载失败")
//        finish()
    }

    override fun csjDrawAdSuccess(ad: TTNativeExpressAd) {
        // 数据源每次刷新添加3个视频加1个广告 则需+1
        var index = drawDatas.size / (AD_INSERT_INDEX + 1) + mAdPage * AD_INSERT_INDEX
        if (index == 0) {
            index++
        }

        drawDatas.add(index, DrawVideoBean(TYPE_AD_ITEM, ad, "", "", ""))

        // 列表只展示当前数据
        mDrawVideoAdapter?.notifyItemInserted(mCurrentPlayIndex + 1)

        mAdPage++
    }

    override fun getXfPageMsgSuc(data: KylBean) {
        for (data in data.data) {
            drawDatas.add(DrawVideoBean(TYPE_COMMON_ITEM, null, data.vedioId, data.url, data.pvurl))
        }
        mCsjDrawAdManager?.loadDrawNativeAd(this, 1)
    }

    override fun getXfPageMsgFail() {
        showToast("加载失败，请稍候再试")
        finish()
    }

    override fun attachBaseContext(newBase: Context?) {
        super.attachBaseContext(newBase)
        // 处理VideoView setVideoPath方法中 AudioManager对Activity持有强引用，导致内存泄漏

        object : ContextWrapper(newBase) {
            override fun getSystemService(name: String): Any {
                if (Context.AUDIO_SERVICE == name)
                    return applicationContext.getSystemService(name)

                return super.getSystemService(name)
            }
        }
    }

    override fun onPause() {
        super.onPause()
        // 释放当前页Video
        releaseVideo(0)
    }

    override fun onResume() {
        super.onResume()
        playVideo(0)
    }
}
