package com.mints.goodmoney.ui.activitys

import android.content.Context
import android.media.AudioManager
import android.os.Bundle
import android.text.TextUtils
import android.view.KeyEvent
import android.view.View
import androidx.fragment.app.Fragment
import androidx.fragment.app.FragmentManager
import androidx.fragment.app.FragmentTransaction
import com.mints.goodmoney.R
import com.mints.goodmoney.ad.express.TTPreLoadCarrierExpressManager
import com.mints.goodmoney.ad.video.VideoAdingManager
import com.mints.goodmoney.common.AppConfig
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.manager.MokuManager
import com.mints.goodmoney.manager.SceneManager
import com.mints.goodmoney.manager.UserManager
import com.mints.goodmoney.mvp.views.MainView
import com.mints.goodmoney.ui.activitys.base.BaseActivity
import com.mints.goodmoney.ui.fragment.*
import dagger.hilt.android.AndroidEntryPoint
import kotlinx.android.synthetic.main.activity_main.*

/**
 * 描述：main
 * 作者：孟崔广
 * 时间：2020/10/9 10:39
 * 邮箱：mengcga@163.com
 */
@AndroidEntryPoint
class MainActivity : BaseActivity(), MainView, View.OnClickListener {

    private val audioManager by lazy { getSystemService(Context.AUDIO_SERVICE) as AudioManager }

    // 底部标签切换的Fragment
    private var moneyFragment: Fragment? = null
    private var turnTableFragment: Fragment? = null

    private var friendsFragment: Fragment? = null
    private var myFragment: Fragment? = null
    private var channelFragment: Fragment? = null
    private var kuYinyueFragment: Fragment? = null
    private var idiomFragment: Fragment? = null
    private var wzFragment: Fragment? = null

    private var currentFragment: Fragment? = null

    private var mainFriendsStatus: Int = 0// 0-平台分红 1-微转 2-猜成语，防止线程不一样

    override fun getContentViewLayoutID() = R.layout.activity_main

    override fun initViewsAndEvents() {
        showShortVedioLayout()

        if (moneyFragment == null) {
            moneyFragment = MoneyFragment()
        }

        if (!moneyFragment!!.isAdded) {
            // 提交事务
            supportFragmentManager.beginTransaction()
                    .add(R.id.content_layout, moneyFragment!!).commitAllowingStateLoss()

            // 记录当前Fragment
            currentFragment = moneyFragment
        }
        mainFriendsStatus=AppConfig.mainFriendsStatus
        // 0-平台分红 1-微转 2-猜成语，防止线程不一样
        when (mainFriendsStatus) {
            0 -> {
                tab_iv_four.setImageResource(R.drawable.tab_friends_btn)
                tab_tv_four.text = "平台分红"
                mainFriendsStatus = 0
            }
            1 -> {
                tab_iv_four.setImageResource(R.drawable.tab_friends_btn)
                tab_tv_four.text = "分享"
                mainFriendsStatus = 1
            }
            2 -> {
                tab_iv_four.setImageResource(R.drawable.tab_wz_share_btn)
                tab_tv_four.text = "猜成语"
                mainFriendsStatus = 2
            }
        }

        tab_iv_one.isSelected = true
        tab_tv_one.isSelected = true

        tab_rl_one.setOnClickListener(this)
        tab_rl_three.setOnClickListener(this)
        tab_rl_two.setOnClickListener(this)
        tab_rl_four.setOnClickListener(this)
        tab_rl_five.setOnClickListener(this)
    }

    override fun isApplyKitKatTranslucency() = false

    public override fun onDestroy() {
        super.onDestroy()

        TTPreLoadCarrierExpressManager.getInstance().onDestroy()
        VideoAdingManager.getInstance(this).setVideoAdingListener(null)
        VideoAdingManager.getInstance(this).onDestroy()
    }

    public override fun onSaveInstanceState(outState: Bundle) {
        //将这一行注释掉，阻止activity保存fragment的状态，防止UI重叠
        //super.onSaveInstanceState(outState);
    }

    var oldTime: Long = 0
    override fun onKeyDown(keyCode: Int, event: KeyEvent): Boolean {
        when (keyCode) {
            KeyEvent.KEYCODE_VOLUME_UP -> {
                audioManager.adjustStreamVolume(AudioManager.STREAM_MUSIC, AudioManager.ADJUST_RAISE, AudioManager.FX_FOCUS_NAVIGATION_UP)
                return true
            }
            KeyEvent.KEYCODE_VOLUME_DOWN -> {
                audioManager.adjustStreamVolume(AudioManager.STREAM_MUSIC, AudioManager.ADJUST_LOWER, AudioManager.FX_FOCUS_NAVIGATION_UP)
                return true
            }
            KeyEvent.KEYCODE_BACK -> {
                // 设置为后台
                val currentTime = System.currentTimeMillis()
                if (currentTime - oldTime < 2 * 1000) {
                    baseApplication.exitApp()
                } else {
                    showToast("再次点击退出" + getString(R.string.app_name))
                    oldTime = currentTime
                }
            }
        }
        return true
    }

    override fun onClick(view: View) {
        when (view.id) {
            R.id.tab_rl_one -> clickTab1Layout()
            R.id.tab_rl_two -> clickTab2Layout()
            R.id.tab_rl_four -> clickTab4Layout()
            R.id.tab_rl_three -> clickTab3Layout()
            R.id.tab_rl_five -> clickTab5Layout()
        }
    }

    /**
     * 点击第一个tab
     */
    fun clickTab1Layout() {
        AppConfig.fragmentClickFlag = Constant.FRAGMENT_CLICK_ONE
        if (moneyFragment == null) {
            moneyFragment = MoneyFragment()
        }
        addOrShowFragment(supportFragmentManager, moneyFragment!!, Constant.FRAGMENT_TAG_ONE)

        tab_iv_one.isSelected = true
        tab_tv_one.isSelected = true
        tab_iv_two.isSelected = false
        tab_tv_two.isSelected = false
//        tab_iv_three.isSelected = false
//        tab_tv_three.isSelected = false
        tab_iv_four.isSelected = false
        tab_tv_four.isSelected = false
        tab_iv_five.isSelected = false
        tab_tv_five.isSelected = false
    }

    fun selectVedio() {
        moneyFragment?.let {
            (it as MoneyFragment).selectVedio()
        }
    }

    fun selectBook() {
        moneyFragment?.let {
            (it as MoneyFragment).selectBook()
        }
    }

    fun selectXmly() {
        moneyFragment?.let {
            (it as MoneyFragment).selectXmly()
        }
    }

    fun turnDayTask() {
        clickTab5Layout()
        myFragment?.let {
            (it as MyFragment).turnDayTask()
        }
    }

    /**
     * 点击第二个tab
     */
    fun clickTab2Layout() {
        AppConfig.fragmentClickFlag = Constant.FRAGMENT_CLICK_TWO
        if (channelFragment == null) {
            channelFragment = HorizonChannelFragment()
        }
        addOrShowFragment(supportFragmentManager, channelFragment!!, Constant.FRAGMENT_TAG_TWO)
        tab_iv_one.isSelected = false
        tab_tv_one.isSelected = false
        tab_iv_two.isSelected = true
        tab_tv_two.isSelected = true
//        tab_iv_three.isSelected = false
//        tab_tv_three.isSelected = false
        tab_iv_four.isSelected = false
        tab_tv_four.isSelected = false
        tab_iv_five.isSelected = false
        tab_tv_five.isSelected = false
    }


    /**
     * 点击第四个tab
     */
    fun clickTab4Layout() {
        AppConfig.fragmentClickFlag = Constant.FRAGMENT_CLICK_FOUR
        // 0-平台分红 1-微转 2-猜成语，防止线程不一样
        when (mainFriendsStatus) {
            0 -> {
                if (friendsFragment == null) {
                    friendsFragment = FriendsFragment()
                }
                addOrShowFragment(supportFragmentManager, friendsFragment!!, Constant.FRAGMENT_TAG_FOUR)
            }
            1 -> {
                if (wzFragment == null) {
                    wzFragment = WzFragment()
                }
                addOrShowFragment(supportFragmentManager, wzFragment!!, Constant.FRAGMENT_TAG_FOUR)
            }
            2 -> {
                if (!AppConfig.scene_flag) {
                    SceneManager.signIn(this)
                }

                if (TextUtils.isEmpty(UserManager.getInstance().userID)) {
                    showToast("请先登录账号")
                    return
                }
                // 猜成语
                if (idiomFragment == null) {
                    idiomFragment = SceneIdiomFragment()
                }
                addOrShowFragment(supportFragmentManager, idiomFragment!!, Constant.FRAGMENT_TAG_FOUR)
            }
        }
        tab_iv_one.isSelected = false
        tab_tv_one.isSelected = false
        tab_iv_two.isSelected = false
        tab_tv_two.isSelected = false
        tab_iv_four.isSelected = true
        tab_tv_four.isSelected = true
        tab_iv_five.isSelected = false
        tab_tv_five.isSelected = false
    }

    /**
     * 点击第三个tab
     */
    private fun clickTab3Layout() {
        AppConfig.fragmentClickFlag = Constant.FRAGMENT_CLICK_THREE
        if (turnTableFragment == null) {
            turnTableFragment = TurnTableFragment()
        }
        addOrShowFragment(supportFragmentManager, turnTableFragment!!, Constant.FRAGMENT_TAG_THREE)
        tab_iv_one.isSelected = false
        tab_tv_one.isSelected = false
        tab_iv_two.isSelected = false
        tab_tv_two.isSelected = false
//        tab_iv_three.isSelected = true
//        tab_tv_three.isSelected = true
        tab_iv_four.isSelected = false
        tab_tv_four.isSelected = false
        tab_iv_five.isSelected = false
        tab_tv_five.isSelected = false
    }

    /**
     * 点击第五个tab
     */
    private fun clickTab5Layout() {
        AppConfig.fragmentClickFlag = Constant.FRAGMENT_CLICK_FIVE
        if (myFragment == null) {
            myFragment = MyFragment()
        }
        addOrShowFragment(supportFragmentManager, myFragment!!, Constant.FRAGMENT_TAG_FIVE)
        tab_iv_one.isSelected = false
        tab_tv_one.isSelected = false
        tab_iv_two.isSelected = false
        tab_tv_two.isSelected = false
//        tab_iv_three.isSelected = false
//        tab_tv_three.isSelected = false
        tab_iv_four.isSelected = false
        tab_tv_four.isSelected = false
        tab_iv_five.isSelected = true
        tab_tv_five.isSelected = true
    }

    /**
     * 添加或者显示碎片
     *
     * @param fm
     * @param fragment
     */
    private fun addOrShowFragment(fm: FragmentManager,
                                  fragment: Fragment, tag: String) {
        if (currentFragment === fragment) return
        val ft: FragmentTransaction = fm.beginTransaction()
        if (!fragment.isAdded && null == fm.findFragmentByTag(tag)) { // 如果当前fragment未被添加，则添加到Fragment管理器中
            ft.hide(currentFragment!!)
                    .add(R.id.content_layout, fragment, tag).commitAllowingStateLoss()
        } else {
            ft.hide(currentFragment!!).show(fragment).commitAllowingStateLoss()
        }
        currentFragment = fragment
    }

    fun showShortVedioLayout() {
        if (AppConfig.showAdFlag) {
            tab_rl_two.visibility = View.VISIBLE
        } else {
            tab_rl_two.visibility = View.GONE
        }
    }
}