package com.mints.goodmoney.ui.activitys

import android.os.Handler
import android.os.Looper
import android.view.KeyEvent
import android.view.View
import android.view.ViewGroup
import com.kwad.sdk.api.KsAdSDK
import com.kwad.sdk.api.KsLoadManager
import com.kwad.sdk.api.KsScene
import com.kwad.sdk.api.KsSplashScreenAd
import com.mints.goodmoney.R
import com.mints.goodmoney.manager.KsManager
import com.mints.goodmoney.ui.activitys.base.BaseActivity
import com.mints.goodmoney.utils.LogUtil
import com.mints.library.net.netstatus.NetUtils

private val TAG = SplashKsADActivity::class.java.simpleName

/**
 * 后台返回时每次都展示 快手广告
 */
class SplashKsADActivity : BaseActivity() {
    private var container: ViewGroup? = null
    private var mIsPaused = false
    var canJump = false

    /**
     * 记录拉取广告的时间
     */
    private val handler = Handler(Looper.getMainLooper())
    override fun getContentViewLayoutID(): Int {
        return R.layout.activity_splash_ylh
    }

    override fun initViewsAndEvents() {
        if (!NetUtils.isNetworkConnected(context)) {
            finish()
        } else {
            try {
                container = findViewById<View>(R.id.splash_container) as ViewGroup
                requestSplashScreenAd()
            } catch (e: Exception) {
                readyGoOtherActivity()
            }
        }

    }

    private fun addView(splashScreenAd: KsSplashScreenAd) {
        val view = splashScreenAd.getView(this, object : KsSplashScreenAd.SplashScreenAdInteractionListener {
            override fun onAdClicked() {
                canJump = true
                LogUtil.d(TAG, "onAdClicked")
            }

            override fun onAdShowError(p0: Int, p1: String?) {
                LogUtil.d(TAG, "onAdShowError -> $p1")

                next()
            }

            override fun onAdShowEnd() {
                LogUtil.d(TAG, "onAdShowEnd")

                next()
            }

            override fun onAdShowStart() {
                LogUtil.d(TAG, "onAdShowStart")
            }

            override fun onSkippedAd() {
                LogUtil.d(TAG, "onSkippedAd")

                next()
            }
        })

        if (!isFinishing) {
            container?.removeAllViews()
            view.layoutParams = ViewGroup.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT,
                    ViewGroup.LayoutParams.MATCH_PARENT)
            container?.addView(view)
        }
    }

    override fun isApplyKitKatTranslucency(): Boolean {
        return false
    }

    private fun requestSplashScreenAd() {
        val scene = KsScene
                .Builder(KsManager.KS_AD_SPLASH_POSTID)
                .build()
        KsAdSDK.getLoadManager().loadSplashScreenAd(scene, object : KsLoadManager.SplashScreenAdListener {
            override fun onError(p0: Int, p1: String?) {
                LogUtil.d(TAG, "onError -> $p1")

                next()
            }

            override fun onSplashScreenAdLoad(p0: KsSplashScreenAd?) {
                LogUtil.d(TAG, "onSplashScreenAdLoad")

                addView(p0!!)
            }

        })
    }

    /**
     * 设置一个变量来控制当前开屏页面是否可以跳转，当开屏广告为普链类广告时，点击会打开一个广告落地页，此时开发者还不能打开自己的App主页。当从广告落地页返回以后，
     * 才可以跳转到开发者自己的App主页；当开屏广告是App类广告时只会下载App。
     */
    private operator fun next() {
        if (mIsPaused) {
            canJump = true
        } else {
            readyGoOtherActivity()
        }
    }

    override fun onPause() {
        super.onPause()
        mIsPaused = true

    }

    override fun onResume() {
        super.onResume()
        mIsPaused = false

        if (canJump) {
            next()
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        handler.removeCallbacksAndMessages(null)
    }

    /**
     * 开屏页一定要禁止用户对返回按钮的控制，否则将可能导致用户手动退出了App而广告无法正常曝光和计费
     */
    override fun onKeyDown(keyCode: Int, event: KeyEvent): Boolean {
        return if (keyCode == KeyEvent.KEYCODE_BACK) {
            true
        } else super.onKeyDown(keyCode, event)
    }

    private fun readyGoOtherActivity() {
        finish()
    }

}