package com.mints.goodmoney.ui.activitys

import android.app.Dialog
import android.view.View
import androidx.fragment.app.Fragment
import androidx.viewpager.widget.ViewPager
import com.mints.goodmoney.R
import com.mints.goodmoney.common.AppConfig
import com.mints.goodmoney.ui.activitys.base.BaseActivity
import com.mints.goodmoney.ui.adapter.MessageFragAdapter
import com.mints.goodmoney.ui.fragment.TaskCpdFragment
import com.mints.goodmoney.ui.fragment.TaskCpdHistoryFragment
import com.mints.goodmoney.ui.widgets.dialog.DialogListener
import com.mints.goodmoney.ui.widgets.dialog.DialogUtils
import com.mints.goodmoney.utils.CacheUtil
import kotlinx.android.synthetic.main.activity_task_cpd.*
import kotlinx.android.synthetic.main.header_layout.*

/**
 * 描述：cpd管理
 * 作者：孟崔广
 * 时间：2021/1/28 14:29
 */
class TaskCpdActivity : BaseActivity(), View.OnClickListener {

    override fun getContentViewLayoutID() = R.layout.activity_task_cpd

    override fun isApplyKitKatTranslucency() = false

    override fun initViewsAndEvents() {
        tv_title.text = "下载试玩任务"
        iv_left_icon.visibility = View.VISIBLE
        iv_left_icon.setImageResource(R.mipmap.ic_arrow_back)

        CacheUtil.clearAllCache()

        initViewAndData()
        initListener()
    }

    override fun onBackPressed() {
        backDialog()
    }

    override fun onClick(v: View?) {
        when (v?.id) {
            R.id.iv_left_icon -> backDialog()
        }
    }

    private fun initListener() {
        iv_left_icon.setOnClickListener(this)
    }

    private fun initViewAndData() {
        val tabs: MutableList<String> = ArrayList()
        val fragments: MutableList<Fragment> = ArrayList()
        tabs.add("每日精选")
        fragments.add(TaskCpdFragment())

        if (AppConfig.useAppCpdModelShow) {
            tabs.add("获取更多金币")
            fragments.add(TaskCpdHistoryFragment())
            xtTaskCpd.visibility = View.VISIBLE
        } else {
            xtTaskCpd.visibility = View.GONE
        }

        xtTaskCpd.overScrollMode = ViewPager.OVER_SCROLL_NEVER
        val adapter = MessageFragAdapter(supportFragmentManager, fragments, tabs)
        vpTaskCpd.adapter = adapter
        xtTaskCpd.setxTabDisplayNum(tabs.size)
        xtTaskCpd.setupWithViewPager(vpTaskCpd)
    }

    fun selectTwoFragment() {
        vpTaskCpd.setCurrentItem(1, true)
    }

    private fun backDialog() {
        DialogUtils.showDialog(context, "提示", "退出当前页面将会重置当前任务状态", "取消", "确定", object : DialogListener() {
            override fun onClick(dialog: Dialog?, v: View?) {
                dialog?.dismiss()

                when (v?.id) {
                    R.id.dialog_btn_right -> {
                        finish()
                    }
                }
            }
        })
    }

}
