package com.mints.goodmoney.ui.activitys

import android.os.Bundle
import android.view.View
import androidx.fragment.app.Fragment
import androidx.fragment.app.FragmentTransaction
import com.chineseall.reader17ksdk.feature.main.bookshop.wellchosen.WellChosenFragment
import com.mints.goodmoney.R
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.ui.activitys.base.BaseActivity
import com.mints.goodmoney.ui.fragment.*
import com.mints.goodmoney.ui.widgets.seekbar.BubbleUtils
import dagger.hilt.android.AndroidEntryPoint
import kotlinx.android.synthetic.main.activity_wrapper.*
import kotlinx.android.synthetic.main.header_layout.*

/**
 * 描述：活动包装页
 * 作者：孟崔广
 * 时间：2020/12/10 12:39
 */
@AndroidEntryPoint
class WrapperActivity : BaseActivity(), View.OnClickListener {

    private var wrapperType = Constant.WRAPPER_TYPE_NEWS

    override fun getContentViewLayoutID() = R.layout.activity_wrapper

    override fun isApplyKitKatTranslucency() = false

    override fun initViewsAndEvents() {
        iv_left_icon.visibility = View.VISIBLE
        iv_left_icon.setImageResource(R.mipmap.ic_arrow_back)

        initPage()
        initListener()
    }

    override fun getBundleExtras(extras: Bundle?) {
        super.getBundleExtras(extras)
        extras?.let {
            wrapperType = it.getInt(Constant.WRAPPER_TYPE, Constant.WRAPPER_TYPE_NEWS)
        }
    }

    override fun onClick(v: View?) {
        when (v?.id) {
            R.id.iv_left_icon -> finish()
        }
    }

    private fun initPage() {
        var currentFragment: Fragment?
        when (wrapperType) {
            Constant.WRAPPER_TYPE_NEWS -> {
                layoutWrapper.visibility = View.INVISIBLE
                val layoutParams = layoutWrapper.layoutParams
                layoutParams.height = BubbleUtils.dp2px(30)
                tv_title.text = "新闻"
                currentFragment = RsNewsFragment()
//                val wellChosenFragment = WellChosenFragment("home")
//                val transaction = supportFragmentManager.beginTransaction()
//                transaction.add(R.id.flWrapper, wellChosenFragment, WellChosenFragment::class.java.toString())
//                transaction.show(wellChosenFragment)
//                transaction.commitAllowingStateLoss()
            }
            Constant.WRAPPER_TYPE_BOOK -> {
                tv_title.text = "书城"
                currentFragment = ReaderFragment()
            }
            Constant.WRAPPER_TYPE_FRIENDS -> {
                tv_title.text = "瓜分百万现金福利"
                currentFragment = FriendsFragment(true)
            }
            Constant.WRAPPER_TYPE_KYL -> {
                tv_title.text = "来电秀"
                currentFragment = KuYinYueFragment()
            }
            Constant.WRAPPER_TYPE_WZ -> {
                layoutWrapper.visibility = View.GONE
                currentFragment = WzFragment(true)
            }
            else -> {
                tv_title.text = "瓜分百万现金福利"
                currentFragment = FriendsFragment(true)
            }
        }

        if (!currentFragment.isAdded) {
            // 提交事务
            supportFragmentManager.beginTransaction()
                    .add(R.id.flWrapper, currentFragment,currentFragment.tag).commitAllowingStateLoss()
        }
    }

    private fun initListener() {
        iv_left_icon.setOnClickListener(this)
    }
}
