package com.mints.goodmoney.ui.activitys

import android.Manifest
import android.os.Bundle
import android.text.TextPaint
import android.text.TextUtils
import android.text.style.ClickableSpan
import android.view.KeyEvent
import android.view.View
import cn.sharesdk.framework.ShareSDK
import cn.sharesdk.wechat.friends.Wechat
import com.mints.goodmoney.MintsApplication
import com.mints.goodmoney.R
import com.mints.goodmoney.common.AppConfig
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.login.LoginApi
import com.mints.goodmoney.login.OnLoginListener
import com.mints.goodmoney.manager.*
import com.mints.goodmoney.mvp.model.WXInfo
import com.mints.goodmoney.mvp.presenters.LoginPresenter
import com.mints.goodmoney.mvp.views.LoginView
import com.mints.goodmoney.ui.activitys.base.BaseActivity
import com.mints.goodmoney.utils.SpanUtils
import com.mints.library.utils.CommonUtils
import com.mints.library.utils.json.JsonUtil
import com.mints.library.utils.nodoubleclick.AntiShake
import com.tbruyelle.rxpermissions.RxPermissions
import kotlinx.android.synthetic.main.activity_wx_login.*
import java.util.*


/**
 * 描述：微信登录
 * 作者：孟崔广
 * 时间：2020/12/2 13:50
 */
class WxLoginActivity : BaseActivity()
        , LoginView, View.OnClickListener, OnLoginListener {

    private val loginPresenter by lazy { LoginPresenter() }
    private val loginApi by lazy { LoginApi() }

    private var wxInfo: WXInfo? = null
    private var channel: String = ""

    override fun getContentViewLayoutID() = R.layout.activity_wx_login

    override fun toggleOverridePendingTransition() = true

    override fun getOverridePendingTransitionMode() = TransitionMode.BOTTOM

    override fun isApplyKitKatTranslucency() = false

    override fun initViewsAndEvents() {
        loginPresenter.attachView(this)
        channel = CommonUtils.getAppMetaData(MintsApplication.getContext(), "CHANNEL_NAME")
        initView()
        initListener()
    }

    override fun onDestroy() {
        super.onDestroy()
        loginApi.setOnLoginListener(null)
        loginPresenter.detachView()
    }

    override fun onKeyDown(keyCode: Int, event: KeyEvent): Boolean {
        return if (keyCode == KeyEvent.KEYCODE_BACK) {
            if (!TextUtils.equals(channel, Constant.CHANNEL_SHARE)) {
                finish()
            }
            true
        } else super.onKeyDown(keyCode, event)
    }

    override fun finish() {
        super.finish()
        //关闭窗体动画显示
        overridePendingTransition(0, R.anim.push_bottom_out)
    }

    override fun onClick(v: View?) {
        if (AntiShake.check(v?.id)) return

        when (v?.id) {
            R.id.ivLoginBack -> {
                if (!TextUtils.equals(channel, Constant.CHANNEL_SHARE)) {
                    finish()
                }
            }
            R.id.tvLoginMobile -> {
                readyGo(MobileLoginActivity::class.java)
//                readyGo(ZaActivity::class.java)
            }
            R.id.rlLoginWx -> {
                val wechat = ShareSDK.getPlatform(Wechat.NAME)
                if (!wechat.isClientValid) {
                    showToast("请先安装微信")
                    return
                }

                RxPermissions(this)
                        .request(Manifest.permission.READ_PHONE_STATE)
                        .subscribe { granted: Boolean ->
                            if (granted) {
                                loginApi.setOnLoginListener(this@WxLoginActivity)
                                loginApi.setPlatform(Wechat.NAME)
                                loginApi.login(this@WxLoginActivity)
                            } else {
                                showMissingPermissionDialog("设备")
                            }
                        }
            }
        }
    }

    override fun loginSuc() {
        try {
            // 登录成功初始化鱼玩盒子userid
            YwhzManager.init(baseApplication)
            YyzManager.initYyz(baseApplication)
        } catch (e: Exception) {
        }

        // 每日任务是否刷新任务数
        TrackManager.getInstance().innerApp()

        SceneManager.signIn(this)
        BxmManager.bindUserData()

        AppConfig.scene_idiom_flag = true

        showToast("登录成功")
        progressDialog?.dismiss()
        if (TextUtils.equals(channel, Constant.CHANNEL_SHARE)) {
            readyGo(MainActivity::class.java)

        }
        finish()
    }

    override fun sendCodeSuc() {

    }

    override fun mergeAccount(mobile: String, wxOpenId: String, key: String) {

    }

    override fun onLogin(platform: String?, res: HashMap<String, Any>): Boolean {
        try {
            wxInfo = WXInfo()
            wxInfo?.let {
                it.unionid = res["unionid"].toString() + ""
                it.openid = res["openid"].toString() + ""
                it.province = res["province"].toString() + ""
                it.city = res["city"].toString() + ""
                it.country = res["country"].toString() + ""
                it.headimgurl = res["headimgurl"].toString() + ""
                it.nickname = res["nickname"].toString() + ""
                it.sex = (res["sex"].toString() + "").toInt()
            }

            if (!isFinishing) {
                loginPresenter.login(JsonUtil.toJson(wxInfo))
            }
        } catch (e: Exception) {
            e.printStackTrace()
        }
        return false
    }

    private fun initView() {

        SpanUtils.with(tvLoginAgreement)
                .append("《用户注册协议》").setClickSpan(object : ClickableSpan() {
                    override fun onClick(widget: View) {
                        val bundle = Bundle()
                        bundle.putString(WebActivity.WEB_TITLE, getString(R.string.register_name))
                        bundle.putString(WebActivity.WEB_URL, Constant.REGISTER_URL)
                        readyGo(WebActivity::class.java, bundle)
                    }

                    override fun updateDrawState(ds: TextPaint) {
                        ds.color = resources.getColor(R.color.color_FF9837)
                        ds.isUnderlineText = false
                    }
                })
                .append("、")
                .append("《用户隐私协议》").setClickSpan(object : ClickableSpan() {
                    override fun onClick(widget: View) {
                        val bundle = Bundle()
                        bundle.putString(WebActivity.WEB_TITLE, getString(R.string.privacy_name))
                        bundle.putString(WebActivity.WEB_URL, Constant.PRIVACY_URL)
                        readyGo(WebActivity::class.java, bundle)
                    }

                    override fun updateDrawState(ds: TextPaint) {
                        ds.color = resources.getColor(R.color.color_FF9837)
                        ds.isUnderlineText = false
                    }
                })
                .append("与您的利益切身相关。请您注册前务必仔细阅读!点击登录即表示您同意并愿意遵守好赚钱协议")
                .create()

    }

    private fun initListener() {
        ivLoginBack.setOnClickListener(this)
        tvLoginMobile.setOnClickListener(this)
        rlLoginWx.setOnClickListener(this)
    }
}
