package com.mints.goodmoney.ui.activitys

import android.os.Bundle
import android.view.View
import android.widget.SeekBar
import androidx.recyclerview.widget.DividerItemDecoration
import androidx.recyclerview.widget.LinearLayoutManager
import com.mints.goodmoney.MintsApplication
import com.mints.goodmoney.R
import com.mints.goodmoney.ad.express.TTPreLoadExpressXmlyManager
import com.mints.goodmoney.common.AppConfig
import com.mints.goodmoney.manager.TrackManager
import com.mints.goodmoney.manager.UserManager
import com.mints.goodmoney.mvp.presenters.XmlyPlayPresenter
import com.mints.goodmoney.mvp.views.XmlyPlayView
import com.mints.goodmoney.ui.activitys.base.BaseActivity
import com.mints.goodmoney.ui.adapter.XmlyPlayAdapter
import com.mints.goodmoney.utils.LogUtil
import com.mints.goodmoney.utils.ToolUtil
import com.mints.goodmoney.utils.Utils
import com.mints.library.utils.GlideUtils
import com.mints.library.utils.nodoubleclick.AntiShake
import com.scwang.smartrefresh.layout.api.RefreshLayout
import com.scwang.smartrefresh.layout.listener.OnLoadMoreListener
import com.scwang.smartrefresh.layout.listener.OnRefreshListener
import com.ximalaya.ting.android.opensdk.constants.DTransferConstants
import com.ximalaya.ting.android.opensdk.datatrasfer.CommonRequest
import com.ximalaya.ting.android.opensdk.datatrasfer.IDataCallBack
import com.ximalaya.ting.android.opensdk.model.PlayableModel
import com.ximalaya.ting.android.opensdk.model.advertis.Advertis
import com.ximalaya.ting.android.opensdk.model.advertis.AdvertisList
import com.ximalaya.ting.android.opensdk.model.live.radio.Radio
import com.ximalaya.ting.android.opensdk.model.live.schedule.Schedule
import com.ximalaya.ting.android.opensdk.model.track.Track
import com.ximalaya.ting.android.opensdk.model.track.TrackList
import com.ximalaya.ting.android.opensdk.player.XmPlayerManager
import com.ximalaya.ting.android.opensdk.player.advertis.IXmAdsStatusListener
import com.ximalaya.ting.android.opensdk.player.appnotification.XmNotificationCreater
import com.ximalaya.ting.android.opensdk.player.service.IXmPlayerStatusListener
import com.ximalaya.ting.android.opensdk.player.service.XmPlayListControl
import com.ximalaya.ting.android.opensdk.player.service.XmPlayerException
import com.ximalaya.ting.android.opensdk.util.NetworkType
import kotlinx.android.synthetic.main.activity_xmly_play.*
import kotlinx.android.synthetic.main.header_layout.*

/**
 * 描述：喜马拉雅播放页面
 * 作者：孟崔广
 * 时间：2020/9/23 18:39
 */
class XmlyPlayActivity : BaseActivity(), View.OnClickListener, XmlyPlayAdapter.OnItemClickListener, OnRefreshListener, OnLoadMoreListener, XmlyPlayView {

    private val xmlyPlayPresenter by lazy { XmlyPlayPresenter() }

    private val userManager by lazy { UserManager.getInstance() }

    private var mCurrentPosition = 0

    private lateinit var mPlayerManager: XmPlayerManager

    override fun getContentViewLayoutID() = R.layout.activity_xmly_play

    override fun isApplyKitKatTranslucency() = false

    private var mUpdateProgress = true

    private lateinit var xmlyPlayAdapter: XmlyPlayAdapter
    private var xmlyData: MutableList<Track> = mutableListOf()

    private var mAlbumId = 0L
    private var mCategoryId = 0L
    private val mUnlockList: MutableList<String> = arrayListOf()

    // 分页
    private var xmlyPage = 1
    private val PAGE_SIZE = 20

    // 第一次播放毫秒值
    private var mStartListenTime = 0L

    // 总共播放时间
    private var mListenTime = 0L

    companion object {
        const val ALBUM_ID = "album_id"
        const val CATEGORY_ID = "category_id"
    }

    override fun getBundleExtras(extras: Bundle) {
        mAlbumId = extras.getLong(ALBUM_ID)
        mCategoryId = extras.getLong(CATEGORY_ID)
    }

    override fun initViewsAndEvents() {
        tv_title.text = "专辑列表"
        iv_left_icon.visibility = View.VISIBLE
        iv_left_icon.setImageResource(R.mipmap.ic_arrow_back)

        xmlyPlayPresenter.attachView(this)
        initRecyView()
        initListener()

        showLoading("加载中...")

        mPlayerManager = XmPlayerManager.getInstance(this)
        val mNotification = XmNotificationCreater.getInstanse(this)
                .initNotification(MintsApplication.getContext(), XmlyPlayActivity::class.java)
        mPlayerManager.init(System.currentTimeMillis().toInt(), mNotification)

        mPlayerManager.addPlayerStatusListener(mPlayerStatusListener)
        mPlayerManager.addAdsStatusListener(mAdsListener)
        mPlayerManager.addOnConnectedListerner(object : XmPlayerManager.IConnectListener {
            override fun onConnected() {
                hideLoading()

                mPlayerManager.removeOnConnectedListerner(this)
                mPlayerManager.playMode = XmPlayListControl.PlayMode.PLAY_MODEL_SINGLE_LOOP
//                Toast.makeText(this@XmlyPlayActivity, "播放器初始化成功", Toast.LENGTH_SHORT).show()

                loadUnlockMsg()
                loadData()
            }
        })
    }

    override fun onResume() {
        super.onResume()

        // 刷新喜马拉雅信息流
        TTPreLoadExpressXmlyManager.getInstance().loadTtFrameLayout()
    }

    private fun loadUnlockMsg() {
        xmlyPlayPresenter.getXmlyUnlockMsg(userManager.userID, mCategoryId.toString(), mAlbumId.toString())
    }

    private fun loadData() {
        val vo = hashMapOf<String, String>()
        // 专辑id
        vo[DTransferConstants.ALBUM_ID] = mAlbumId.toString()
        // 1-最火 2-最新 3-最多播放
        vo[DTransferConstants.PAGE] = xmlyPage.toString()
        vo[DTransferConstants.PAGE_SIZE] = PAGE_SIZE.toString()
        CommonRequest.getTracks(vo, object : IDataCallBack<TrackList> {
            override fun onSuccess(p0: TrackList?) {
                // 判断activity是否已被销毁
                if (Utils.isDestroy(this@XmlyPlayActivity)) return

                if (p0 != null && p0.tracks != null && p0.tracks.size != 0) {
                    runOnUiThread {
                        if (xmlyPage == 1) {
                            message.text = p0.tracks[0].trackTitle
                            time.text = "[00.00/" + ToolUtil.formatTime(p0.tracks[0].duration.toLong()).toString() + "]"
                            tv_title.text = p0.albumTitle

                            GlideUtils.loadImageView(this@XmlyPlayActivity, p0.coverUrlMiddle, sound_cover)
                        }
                        control_bar.visibility = View.VISIBLE
                        getDataSuc(p0.tracks)
                    }

                } else {
                    getDataFail()
                }
            }

            override fun onError(p0: Int, p1: String?) {
                LogUtil.e(p1)
                getDataFail()
            }

        })
    }

    override fun onRefresh(refreshLayout: RefreshLayout) {
        xmlyPage = 1
//        xmlyData.clear()
        loadData()
    }

    override fun onLoadMore(refreshLayout: RefreshLayout) {
        xmlyPage = ++xmlyPage
        loadData()
    }

    /**
     * 获取数据失败
     */
    private fun getDataFail() {
        srl_xmly.finishRefresh(false)
        srl_xmly.finishLoadMore(false)
        xmlyPage = if (xmlyPage == 1) 1 else xmlyPage - 1
    }

    /**
     * 获取数据成功
     */
    private fun getDataSuc(list: List<Track>) {
        if (::xmlyPlayAdapter.isInitialized) {
            xmlyData.addAll(list)
            if (xmlyPage == 1) {
                srl_xmly.finishRefresh(true)
                xmlyPlayAdapter.notifyDataSetChanged()
            } else {
                if (list.size < PAGE_SIZE) {
                    srl_xmly.finishLoadMoreWithNoMoreData()
                } else {
                    srl_xmly.finishLoadMore()
                }
                xmlyPlayAdapter.notifyItemChanged(list.size)
            }
        }
    }

    private fun initRecyView() {
        val linearLayoutManager = LinearLayoutManager(context)
        xmlyPageVip.layoutManager = linearLayoutManager
        xmlyPageVip.addItemDecoration(DividerItemDecoration(this, DividerItemDecoration.VERTICAL))
        xmlyPlayAdapter = XmlyPlayAdapter(xmlyData, mUnlockList)
        xmlyPageVip.adapter = xmlyPlayAdapter
        xmlyPlayAdapter.setOnItemClickListener(this)
    }

    private val mPlayerStatusListener: IXmPlayerStatusListener = object : IXmPlayerStatusListener {
        override fun onSoundPrepared() {
            seek_bar.isEnabled = true
            buffering_progress.visibility = View.GONE
        }

        override fun onSoundSwitch(laModel: PlayableModel?, curModel: PlayableModel?) {
            val model = mPlayerManager.currSound
            if (model != null) {
                var title: String? = null
                var coverUrl: String? = null
                when (model) {
                    is Track -> {
                        title = model.trackTitle
                        coverUrl = model.coverUrlLarge
                    }
                    is Schedule -> {
                        title = model.relatedProgram.programName
                        coverUrl = model.relatedProgram.backPicUrl
                    }
                    is Radio -> {
                        title = model.radioName
                        coverUrl = model.coverUrlLarge
                    }
                }
                message.text = title
                GlideUtils.loadImageView(this@XmlyPlayActivity, coverUrl, sound_cover)
            }
            updateButtonStatus()
        }

        private fun updateButtonStatus() {
            pre_sound.isEnabled = mPlayerManager.hasPreSound()
            next_sound.isEnabled = mPlayerManager.hasNextSound()
        }

        override fun onPlayStop() {
            mListenTime += System.currentTimeMillis() - mStartListenTime
            play_or_pause.setImageResource(R.mipmap.widget_play_normal)
        }

        override fun onPlayStart() {
            mStartListenTime = System.currentTimeMillis()

            play_or_pause.setImageResource(R.mipmap.widget_pause_normal)
        }

        override fun onPlayProgress(currPos: Int, duration: Int) {
            var title: String? = ""
            val info = mPlayerManager.currSound
            if (info != null) {
                when (info) {
                    is Track -> {
                        title = info.trackTitle
                    }
                    is Schedule -> {
                        title = info.relatedProgram.programName
                    }
                    is Radio -> {
                        title = info.radioName
                    }
                }
            }
            message.text = title
            time.text = "[" + ToolUtil.formatTime(currPos.toLong()).toString() + "/" + ToolUtil.formatTime(duration.toLong()).toString() + "]"
            if (mUpdateProgress && duration != 0) {
                seek_bar.progress = (100 * currPos / duration.toFloat()).toInt()
            }
        }

        override fun onPlayPause() {
            mListenTime += System.currentTimeMillis() - mStartListenTime

            play_or_pause.setImageResource(R.mipmap.widget_play_normal)
        }

        override fun onSoundPlayComplete() {
            mListenTime += System.currentTimeMillis() - mStartListenTime

            play_or_pause.setImageResource(R.mipmap.widget_play_normal)
        }

        override fun onError(exception: XmPlayerException): Boolean {
            play_or_pause.setImageResource(R.mipmap.widget_play_normal)
            if (!NetworkType.isConnectTONetWork(mContext)) {
                showToast("网络出小差儿了~")
            }
            return false
        }

        override fun onBufferProgress(position: Int) {
            seek_bar.secondaryProgress = position
        }

        override fun onBufferingStart() {
            seek_bar.isEnabled = false
            buffering_progress.visibility = View.VISIBLE
        }

        override fun onBufferingStop() {
            seek_bar.isEnabled = true
            buffering_progress.visibility = View.GONE
        }
    }

    private val mAdsListener: IXmAdsStatusListener = object : IXmAdsStatusListener {
        override fun onStartPlayAds(ad: Advertis, position: Int) {
            play_or_pause.isEnabled = true
            play_or_pause.setImageResource(R.mipmap.widget_pause_normal)
        }

        override fun onStartGetAdsInfo() {
            play_or_pause.isEnabled = false
            seek_bar.isEnabled = false
        }

        override fun onGetAdsInfo(ads: AdvertisList) {}
        override fun onError(what: Int, extra: Int) {
        }

        override fun onCompletePlayAds() {
            play_or_pause.isEnabled = true
            seek_bar.isEnabled = true
            val model = mPlayerManager.currSound
            if (model != null && model is Track) {
                GlideUtils.loadImageView(this@XmlyPlayActivity, model.coverUrlMiddle, sound_cover)
            }
        }

        override fun onAdsStopBuffering() {}

        override fun onAdsStartBuffering() {}
    }

    override fun onClick(v: View?) {
        if (AntiShake.check(v?.id)) return

        when (v?.id) {
            R.id.iv_left_icon -> finish()
            R.id.play_or_pause -> {
                if (mPlayerManager.playListSize == 0) {
                    mCurrentPosition = 0
                    mPlayerManager.playList(xmlyData, 0)
                    return
                }

                // 播放或暂停
                if (mPlayerManager.isPlaying) {
                    mPlayerManager.pause()
                } else {
                    mPlayerManager.play()
                }
            }
            R.id.next_sound -> {
                // 下一首
                for (s in mUnlockList) {
                    if (s == (mCurrentPosition + 2).toString()) {
                        mPlayerManager.playNext()
                        return
                    }
                }

                showToast("第" + (mCurrentPosition + 2) + "条尚未解锁，点击即可解锁")

                // 广告解锁
//                if (AppConfig.xmlyAdFlag) {
//                    readyGo(XmlyAwardActivity::class.java)
//                    xmlyPlayPresenter.pushXmlyUnlockMsg(userManager.userID, mCategoryId.toString(), mAlbumId.toString(), (mCurrentPosition + 2).toString())
//                    mUnlockList.add((mCurrentPosition + 2).toString())
//                    xmlyPlayAdapter.notifyItemChanged(mCurrentPosition + 1)
//                } else {
//                    showToast("解锁失败，请重试")
//                }
            }
            R.id.pre_sound -> {
                // 上一首
                for (s in mUnlockList) {
                    if (s == (mCurrentPosition).toString()) {
                        mPlayerManager.playPre()
                        return
                    }
                }

                showToast("第" + mCurrentPosition + "条尚未解锁，点击即可解锁")

                // 广告解锁
//                if (AppConfig.xmlyAdFlag) {
//                    readyGo(XmlyAwardActivity::class.java)
//                    xmlyPlayPresenter.pushXmlyUnlockMsg(userManager.userID, mCategoryId.toString(), mAlbumId.toString(), (mCurrentPosition).toString())
//                    mUnlockList.add((mCurrentPosition).toString())
//                    xmlyPlayAdapter.notifyItemChanged(mCurrentPosition)
//                } else {
//                    showToast("解锁失败，请重试")
//                }
            }
        }
    }

    override fun onDestroy() {
        if (::mPlayerManager.isInitialized) {
            mPlayerManager.removePlayerStatusListener(mPlayerStatusListener)
        }
        XmPlayerManager.release()
        CommonRequest.release()
        super.onDestroy()
    }

    private fun initListener() {
        srl_xmly.setOnRefreshListener(this)
        srl_xmly.setOnLoadMoreListener(this)

        iv_left_icon.setOnClickListener(this)
        play_or_pause.setOnClickListener(this)
        next_sound.setOnClickListener(this)
        pre_sound.setOnClickListener(this)

        seek_bar.setOnSeekBarChangeListener(object : SeekBar.OnSeekBarChangeListener {
            override fun onProgressChanged(seekBar: SeekBar, progress: Int, fromUser: Boolean) {}

            override fun onStartTrackingTouch(seekBar: SeekBar?) {
                mUpdateProgress = false
            }

            override fun onStopTrackingTouch(seekBar: SeekBar) {
                mPlayerManager.seekToByPercent(seekBar.progress / seekBar.max.toFloat())
                mUpdateProgress = true
            }

        })
    }

    override fun finish() {
        if (mPlayerManager.isPlaying && mStartListenTime != 0L) {
            mListenTime += System.currentTimeMillis() - mStartListenTime
        }
        if (mListenTime != 0L) {
            TrackManager.getInstance().addXmlyTime((mListenTime / 1000).toInt())
        }
        super.finish()
    }

    override fun onItemClick(position: Int) {
        for (s in mUnlockList) {
            if (s == (position + 1).toString()) {
                mCurrentPosition = position
                mPlayerManager.playList(xmlyData, position)
                return
            }
        }

        // 广告解锁
        if (AppConfig.xmlyAdFlag) {
            readyGo(XmlyAwardActivity::class.java)
            xmlyPlayPresenter.pushXmlyUnlockMsg(userManager.userID, mCategoryId.toString(), mAlbumId.toString(), (position + 1).toString())
            mUnlockList.add((position + 1).toString())
            xmlyPlayAdapter.notifyItemChanged(position)
        } else {
            showToast("解锁失败，请重试")
            // 刷新喜马拉雅信息流
            TTPreLoadExpressXmlyManager.getInstance().loadTtFrameLayout()
        }
    }

    override fun getXmlyUnlockMsgSuc(list: List<String>) {
        mUnlockList.clear()
        mUnlockList.addAll(list)
        xmlyPlayAdapter.notifyDataSetChanged()
    }

    override fun pushXmlyUnlockMsgSuc() {}
}
