package com.mints.goodmoney.ui.adapter

import android.content.Context
import android.net.Uri
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.*
import androidx.recyclerview.widget.RecyclerView
import com.mints.goodmoney.R
import com.mints.goodmoney.call.widget.CustomVideoView
import com.mints.goodmoney.mvp.model.DrawVideoBean
import com.mints.goodmoney.ui.activitys.DrawNativeVideoActivity
import com.mints.goodmoney.ui.adapter.listener.OnItemClickListener
import com.mints.library.utils.GlideUtils

//class DrawVideoAdapter(context: Context, datas: List<DrawVideoBean>) : RecyclerView.Adapter<RecyclerView.ViewHolder>() {
class DrawVideoAdapter(datas: List<DrawVideoBean>) : RecyclerView.Adapter<RecyclerView.ViewHolder>() {

    private var mContext:Context?=null
    private var mDrawVideoData: List<DrawVideoBean> = datas

    private var mOnItemClickListener: OnItemClickListener? = null

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): RecyclerView.ViewHolder {
        mContext=parent.context
        val view = LayoutInflater.from(mContext).inflate(R.layout.item_view_pager, parent, false)
        return ViewHolder(view)
    }

    override fun getItemViewType(position: Int): Int {
        return mDrawVideoData[position].type
    }

    override fun onBindViewHolder(viewHolder: RecyclerView.ViewHolder, position: Int) {
        val holder = viewHolder as ViewHolder

        var view: View? = View(mContext)
        val item: DrawVideoBean? = mDrawVideoData[position]
        if (item?.type == DrawNativeVideoActivity.TYPE_COMMON_ITEM) {
            GlideUtils.loadImageView(mContext, item.ImgId, holder.img_thumb)
            view = getView()
            (view as VideoView).setVideoURI(Uri.parse(mDrawVideoData[position].videoUrl))
        } else if (item?.type == DrawNativeVideoActivity.TYPE_AD_ITEM && item.ad != null) {
            view = item.ad.expressAdView
        }
        holder.videoLayout.removeAllViews()
        if (view?.parent != null) {
            (view.parent as ViewGroup).removeView(view)
        }
        holder.videoLayout.addView(view)
        if (item != null) {
            changeUIVisibility(holder, item.type)
        }
    }

    private fun changeUIVisibility(holder: ViewHolder, type: Int) {
        var visibilable = true
        if (type == DrawNativeVideoActivity.TYPE_AD_ITEM) {
            visibilable = false
        }
        holder.img_play.visibility = if (visibilable) View.VISIBLE else View.GONE
        holder.img_thumb.visibility = if (visibilable) View.VISIBLE else View.GONE
    }

    private fun getView(): View {
        val videoView = CustomVideoView(mContext)
        val layoutParams = FrameLayout.LayoutParams(FrameLayout.LayoutParams.MATCH_PARENT, FrameLayout.LayoutParams.MATCH_PARENT)
        videoView.layoutParams = layoutParams
        return videoView
    }

    override fun getItemCount(): Int {
        return mDrawVideoData.size
    }

    inner class ViewHolder(itemView: View) : RecyclerView.ViewHolder(itemView) {
        val img_thumb: ImageView = itemView.findViewById(R.id.img_thumb)
        val img_play: ImageView = itemView.findViewById(R.id.img_play)
        val rootView: RelativeLayout = itemView.findViewById(R.id.root_view)
        val videoLayout: FrameLayout = itemView.findViewById(R.id.video_layout)
    }

    fun setOnItemClickListener(listener: OnItemClickListener) {
        mOnItemClickListener = listener
    }

}