package com.mints.goodmoney.ui.fragment

import android.annotation.SuppressLint
import android.app.Dialog
import android.text.TextUtils
import android.view.View
import android.view.animation.AccelerateDecelerateInterpolator
import androidx.core.content.ContextCompat
import androidx.recyclerview.widget.DividerItemDecoration
import androidx.recyclerview.widget.RecyclerView
import androidx.viewpager.widget.ViewPager
import com.daimajia.androidanimations.library.Techniques
import com.daimajia.androidanimations.library.YoYo
import com.mints.goodmoney.R
import com.mints.goodmoney.common.AppConfig
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.manager.UserManager
import com.mints.goodmoney.mvp.model.FriendHallMsgBean
import com.mints.goodmoney.mvp.presenters.FriendsPresenter
import com.mints.goodmoney.mvp.views.FriendsView
import com.mints.goodmoney.ui.activitys.DrawcashActivity
import com.mints.goodmoney.ui.activitys.FriendsActivity
import com.mints.goodmoney.ui.activitys.WxLoginActivity
import com.mints.goodmoney.ui.adapter.FriendsPagerAdapter
import com.mints.goodmoney.ui.adapter.InvitedAdapter
import com.mints.goodmoney.ui.fragment.base.BaseFragment
import com.mints.goodmoney.ui.widgets.dialog.DialogListener
import com.mints.goodmoney.ui.widgets.ShareDialog
import com.mints.goodmoney.ui.widgets.dialog.DialogUtils
import com.mints.goodmoney.ui.widgets.seekbar.BubbleUtils
import com.mints.goodmoney.utils.SpanUtils
import com.scwang.smartrefresh.layout.api.RefreshLayout
import com.scwang.smartrefresh.layout.listener.OnRefreshListener
import kotlinx.android.synthetic.main.fragment_main_friends.*
import kotlinx.android.synthetic.main.header_layout.*
import net.grandcentrix.tray.AppPreferences
import java.math.BigDecimal

/**
 * 描述：邀请好友
 * 作者：孟崔广
 * 时间：2020/9/20 17:30
 */
@SuppressLint("SetTextI18n")
class FriendsFragment(private var isResume: Boolean = false) : BaseFragment(), FriendsView, OnRefreshListener, View.OnClickListener {

    private val friendsPresenter by lazy { FriendsPresenter() }

    private var viewPagerAdapter: FriendsPagerAdapter? = null

    // 收益总榜数据
    private var allData: MutableList<FriendHallMsgBean.ListBean> = mutableListOf()
    private var allAdapter: InvitedAdapter? = null

    // 今日贡献榜数据
    private var todayData: MutableList<FriendHallMsgBean.ListBean> = mutableListOf()
    private var todayAdapter: InvitedAdapter? = null

    // 昨日收益榜数据
    private var yesterdayData: MutableList<FriendHallMsgBean.ListBean> = mutableListOf()
    private var yesterdayAdapter: InvitedAdapter? = null

    private val recyList: MutableList<RecyclerView> = mutableListOf()

    private var mFriendsHallMsgBean: FriendHallMsgBean? = null

    private var rope: YoYo.YoYoString? = null

    private val ps by lazy { AppPreferences(context) }

    private val userManager by lazy { UserManager.getInstance() }

    override fun getContentViewLayoutID() = R.layout.fragment_main_friends

    override fun initViewsAndEvents() {
        friendsPresenter.attachView(this)
        srl_my.setOnRefreshListener(this)

        if (isResume) {
            friendsLayout.visibility = View.GONE
        } else {
            friendsLayout.visibility = View.VISIBLE
        }

        initView()
        initRecy()
    }

    @SuppressLint("ClickableViewAccessibility")
    private fun initView() {
        tv_right_subtitle.visibility = View.VISIBLE
        tv_right_subtitle.text = "玩法规则"
        tv_right_subtitle.setTextColor(ContextCompat.getColor(mContext, R.color.color_666))
        tv_right_subtitle.setOnClickListener { }
        tv_title.text = "瓜分百万现金福利"

        btn_get_bonus.setOnClickListener(this)
        tv_right_subtitle.setOnClickListener(this)
        btn_invite.setOnClickListener(this)
        tv_detail.setOnClickListener(this)
        tv_friends_directly.setOnClickListener(this)
        tv_friends_indirect.setOnClickListener(this)
    }

    private fun initRecy() {
        val recyAll = View.inflate(mContext, R.layout.item_friends_recy, null) as RecyclerView
        val recyToday = View.inflate(mContext, R.layout.item_friends_recy, null) as RecyclerView
        val recyYesterday = View.inflate(mContext, R.layout.item_friends_recy, null) as RecyclerView

        recyAll.addItemDecoration(DividerItemDecoration(mContext, DividerItemDecoration.VERTICAL))
        recyToday.addItemDecoration(DividerItemDecoration(mContext, DividerItemDecoration.VERTICAL))
        recyYesterday.addItemDecoration(DividerItemDecoration(mContext, DividerItemDecoration.VERTICAL))

        allAdapter = InvitedAdapter(mContext, allData)
        yesterdayAdapter = InvitedAdapter(mContext, yesterdayData)
        todayAdapter = InvitedAdapter(mContext, todayData)

        recyAll.adapter = allAdapter
        recyToday.adapter = todayAdapter
        recyYesterday.adapter = yesterdayAdapter

        recyList.add(recyAll)
        recyList.add(recyToday)
        recyList.add(recyYesterday)

        val titleList = arrayListOf("总收益榜", "今日贡献榜", "昨日收益榜")
        viewPagerAdapter = FriendsPagerAdapter(titleList, recyList)
        view_pager_friends.adapter = viewPagerAdapter
        view_pager_friends.addOnPageChangeListener(object : ViewPager.OnPageChangeListener {
            override fun onPageScrolled(position: Int, positionOffset: Float, positionOffsetPixels: Int) {
            }

            override fun onPageSelected(position: Int) {
                when (view_pager_friends.currentItem) {
                    0 -> {
                        friendsPresenter.getContributionBigLeaders()
                    }
                    1 -> {
                        friendsPresenter.getFriendsGiveTodayList()
                    }
                    2 -> {
                        friendsPresenter.getContributionLeaders()
                    }
                    else -> {
                    }
                }
            }

            override fun onPageScrollStateChanged(state: Int) {
            }

        })

        tab_friends.setupWithViewPager(view_pager_friends)
    }

    override fun onHiddenChanged(hidden: Boolean) {
        if (hidden) { // 不在最前端界面显示
            onPause()
        } else { // 重新显示到最前端中
            onResume()
        }
        super.onHiddenChanged(hidden)
    }

    override fun onResume() {
        super.onResume()
        if (AppConfig.fragmentClickFlag == Constant.FRAGMENT_CLICK_FOUR || isResume) {
            if (!TextUtils.isEmpty(UserManager.getInstance().userID)) {
                // 刷新分红数据
                friendsPresenter.getFriendHallMsg()

                when (view_pager_friends.currentItem) {
                    0 -> {
                        friendsPresenter.getContributionBigLeaders()
                    }
                    1 -> {
                        friendsPresenter.getFriendsGiveTodayList()
                    }
                    2 -> {
                        friendsPresenter.getContributionLeaders()
                    }
                }
            }

            mFriendsHallMsgBean?.let {
                if (it.button == "戳我分红") {
                    showRedbox(btn_get_bonus)
                }
            }
        }
    }

    override fun onPause() {
        super.onPause()
        mFriendsHallMsgBean?.let {
            if (it.button == "戳我分红") {
                stopRedbox()
            }
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        friendsPresenter.detachView()
        if (rope != null) {
            rope?.stop()
            rope = null
        }
    }

    override fun onRefresh(refreshLayout: RefreshLayout) {
        if (UserManager.getInstance().userID.isNotEmpty()) {
            // 刷新分红数据
            friendsPresenter.getFriendHallMsg()

            when (view_pager_friends.currentItem) {
                0 -> {
                    friendsPresenter.getContributionBigLeaders()
                }
                1 -> {
                    friendsPresenter.getFriendsGiveTodayList()
                }
                2 -> {
                    friendsPresenter.getContributionLeaders()
                }
            }
        }
    }


    /**
     * 显示红包动画
     */
    fun showRedbox(view: View?) {
        rope = null
        rope = YoYo.with(Techniques.Pulse).duration(1200)
                .interpolate(AccelerateDecelerateInterpolator())
                .repeat(-1)
                .playOn(view)
    }

    fun stopRedbox() {
        if (rope != null) {
            rope?.stop()
        }
    }

    private fun generateData(data: FriendHallMsgBean) {
        friends_sum.text = "" + data.friendCount
        friends_directly_sum.text = "" + data.directFriendsCount
        friends_indirect_sum.text = "" + data.indirectFriendsCount

        btn_get_bonus.text = data.button
        btn_get_bonus.isEnabled = data.status == 0 && data.cash > 0

        if (data.button == "戳我分红") {
            btn_get_bonus.isEnabled = true
            btn_get_bonus.setTextColor(ContextCompat.getColor(mContext, R.color.white))
            btn_get_bonus.setBackgroundResource(R.drawable.shape_btn_friends_unenabled)
            showRedbox(btn_get_bonus)
        } else {
            stopRedbox()
        }

        tv_bonus_date.text = data.periods

        tv_bonus_sum.text = SpanUtils()
                .append("今日奖池 ").setForegroundColor(ContextCompat.getColor(mContext, R.color.black))
                .append(data.titleMsg).setFontSize(BubbleUtils.dp2px(28)).setForegroundColor(ContextCompat.getColor(mContext, R.color.color_E72C2B))
                .append(" 元").setForegroundColor(ContextCompat.getColor(mContext, R.color.black))
                .create()

        tv_yesterday_bonus.text = SpanUtils()
                .append(data.contribution_yesterday.toString()).setForegroundColor(ContextCompat.getColor(mContext, R.color.color_FF7C00))
                .create()

        tv_today_bonus.text = SpanUtils()
                .append(data.contribution_today.toString()).setForegroundColor(ContextCompat.getColor(mContext, R.color.color_E72C2B))
                .create()

        tv_bonus_money.text = SpanUtils()
                .append(data.cash.toString()).setForegroundColor(ContextCompat.getColor(mContext, R.color.color_E72C2B))
                .append("元").setFontSize(BubbleUtils.dp2px(14)).setForegroundColor(ContextCompat.getColor(mContext, R.color.color_E72C2B))
                .create()

        tv_bonus_rate.text = SpanUtils()
                .append("昨日汇率：").setForegroundColor(ContextCompat.getColor(mContext, R.color.black))
                .append(data.rate).setForegroundColor(ContextCompat.getColor(mContext, R.color.color_E72C2B))
                .create()
        tv_bonus_hint.text = data.remark
    }

    private fun hintDialog(flag: Boolean) {
        if (flag) {
            DialogUtils.showBonusDialog(mContext, "什么是直接亲友", "经你本人直接邀请的亲友，就是你的直接亲友。", "知道了", object : DialogListener() {
                override fun onClick(dialog: Dialog?, v: View?) {
                    when (v?.id) {
                        R.id.btn_submit -> {
                            if (activity != null && !activity!!.isFinishing && dialog != null && dialog.isShowing) {
                                dialog.dismiss()
                            }
                        }
                    }
                }
            })
        } else {
            DialogUtils.showBonusDialog(mContext, "什么是间接亲友", "经你直接亲友邀请的亲友，就是你的间接亲友。", "知道了", object : DialogListener() {
                override fun onClick(dialog: Dialog?, v: View?) {
                    when (v?.id) {
                        R.id.btn_submit -> {
                            if (activity != null && !activity!!.isFinishing && dialog != null && dialog.isShowing) {
                                dialog.dismiss()
                            }
                        }
                    }
                }
            })
        }
    }

    private fun ruleDialog() {
        if (mFriendsHallMsgBean?.rules != null) {
            DialogUtils.showBonusDialog(mContext, "玩法规则", mFriendsHallMsgBean?.rules!!, "知道了", object : DialogListener() {
                override fun onClick(dialog: Dialog?, v: View?) {
                    when (v?.id) {
                        R.id.btn_submit -> {
                            if (activity != null && !activity!!.isFinishing && dialog != null && dialog.isShowing) {
                                dialog.dismiss()
                            }
                        }
                    }
                }
            })
        }
    }

    override fun onClick(v: View?) {
        when (v?.id) {
            R.id.tv_detail -> {
                // 亲友团详情
                readyGo(FriendsActivity::class.java)
            }
            R.id.tv_friends_directly -> {
                // 直接亲友弹框
                hintDialog(true)
            }
            R.id.tv_friends_indirect -> {
                // 间接亲友弹框
                hintDialog(false)
            }
            R.id.btn_invite -> {
                // 邀请好友
                if (!UserManager.getInstance().userIsLogin()) {
                    readyGo(WxLoginActivity::class.java)
                    return
                }

                if (!ps.getBoolean(Constant.FIRST_SHARE_INVITED, false)) {
                    // 第一次邀请提示弹框
                    firstWeChatInvite()
                } else {
                    shareImgDialog()
                }

            }
            R.id.tv_right_subtitle -> {
                // 玩法规则
                ruleDialog()
            }
            R.id.btn_get_bonus -> {
                // 领取收益
                mFriendsHallMsgBean?.let {
                    if (it.cash.toInt() > 0 && it.status == 0) {
                        shareImgBounsDialog()
                    } else {
                        if (it.button == "戳我分红") {
                            // 玩法规则
                            ruleDialog()
                        } else {
                            showToast("您的贡献值未达到提现要求")
                        }
                    }
                }

            }
        }
    }

    // 总收益榜
    override fun getContributionBigLeadersSuc(data: FriendHallMsgBean) {
        srl_my.finishRefresh(true)

        allData.clear()
        allData.addAll(data.list)
        allAdapter?.notifyDataSetChanged()
    }

    override fun getFriendsHallMsgSuc(data: FriendHallMsgBean) {
        srl_my.finishRefresh(true)
        mFriendsHallMsgBean = data
        generateData(data)
    }

    // 昨日收益榜
    override fun getContributionLeadersSuc(data: FriendHallMsgBean) {
        srl_my.finishRefresh(true)

        yesterdayData.clear()
        yesterdayData.addAll(data.list)
        yesterdayAdapter?.notifyDataSetChanged()
    }

    // 今日贡献榜
    override fun getFriendsGiveTodayListSuc(data: FriendHallMsgBean) {
        srl_my.finishRefresh(true)

        todayData.clear()
        todayData.addAll(data.list)
        todayAdapter?.notifyDataSetChanged()
    }

    // 提现成功
    override fun getContributionOutToCashSuc() {
        DialogUtils.showBonusDialog(mContext, "提示", "收益已领取成功", "去查看", object : DialogListener() {
            override fun onClick(dialog: Dialog?, v: View?) {
                when (v?.id) {
                    R.id.btn_submit -> {
                        if (activity != null && !activity!!.isFinishing && dialog != null && dialog.isShowing) {
                            readyGo(DrawcashActivity::class.java)
                            dialog.dismiss()
                        }
                    }
                }
            }
        })
    }

    /**
     * 图片分享
     */
    private fun shareImgDialog() {
        val shareDialog = ShareDialog(requireActivity())
        val title: String
        if (userManager.wxName.isEmpty()) {
            var mobile = userManager.mobile
            if (mobile.isNotEmpty()) {
                mobile = mobile.substring(0, 3) + "****" + mobile.substring(mobile.length - 4, mobile.length)
            }
            title = "Hi,我是$mobile"
        } else {
            title = "Hi,我是" + userManager.wxName
        }
        val content = "送你一个赚钱的新模式，\r\n快点加入跟我一起赚钱吧"
        shareDialog.run {
            setShareAvatar(userManager.wxHeader)
            setShareTitle(title)
            setShareContent(content)
            show()
        }
    }

    /**
     * 领取分红分享
     */
    private fun shareImgBounsDialog() {
        val shareDialog = ShareDialog(requireActivity())
        val title: String
        if (userManager.wxName.isEmpty()) {
            var mobile = userManager.mobile
            if (mobile.isNotEmpty()) {
                mobile = mobile.substring(0, 3) + "****" + mobile.substring(mobile.length - 4, mobile.length)
            }
            title = "Hi,我是$mobile"
        } else {
            title = "Hi,我是" + userManager.wxName
        }
        val sumCoin = if (TextUtils.isEmpty(userManager.userSumGold)) {
            "0"
        } else {
            val allcoinBig = BigDecimal(userManager.userSumGold)
            val rateBig = BigDecimal("1000")
            allcoinBig.divide(rateBig).setScale(2, BigDecimal.ROUND_DOWN).toString()
        }
        val content = SpanUtils()
                .append("我已在好赚钱赚了")
                .append(sumCoin).setFontSize(BubbleUtils.dp2px(10)).setForegroundColor(ContextCompat.getColor(mContext, R.color.color_E72C2B))
                .append("元 ，快来跟我一起赚钱吧，满")
                .append("0.3").setFontSize(BubbleUtils.dp2px(10)).setForegroundColor(ContextCompat.getColor(mContext, R.color.color_E72C2B))
                .append("元就可以提现")
                .create()
        shareDialog.run {
            setOnShareCompleteListener(object : ShareDialog.OnShareCompleteListener {
                override fun onShareComplete() {
                    // 去提现
                    friendsPresenter.getContributionOutToCash()
                }
            })
            setShareAvatar(userManager.wxHeader)
            setShareTitle(title)
            setShareTips("Tips:分享朋友圈成功后领取分红收益")
            setShareWithNoWechatFavoiter(true)
            setShareContent(content)
            show()
        }
    }

    /**
     * 第一次微信分享弹框
     */
    private fun firstWeChatInvite() {
        DialogUtils.showDialog(mContext, "提示", "被邀请人成功提现0.5元后发放贡献", "取消", "打开微信", object : DialogListener() {
            override fun onClick(dialog: Dialog?, v: View?) {
                dialog?.dismiss()

                when (v?.id) {
                    R.id.dialog_btn_right -> {
                        if (activity != null && !activity!!.isFinishing) {
                            ps.put(Constant.FIRST_SHARE_INVITED, true)

                            shareImgDialog()
                        }
                    }
                }
            }
        })
    }

}