package com.mints.goodmoney.ui.fragment

import android.os.Bundle
import android.os.Handler
import android.os.Looper
import android.text.TextUtils
import android.view.Gravity
import android.view.View
import android.widget.FrameLayout
import android.widget.LinearLayout
import androidx.fragment.app.FragmentTransaction
import com.daimajia.androidanimations.library.Techniques
import com.daimajia.androidanimations.library.YoYo
import com.mints.goodmoney.R
import com.mints.goodmoney.common.AppConfig
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.mvp.model.MainVideoMsgBean
import com.mints.goodmoney.mvp.presenters.HorizChannelPresenter
import com.mints.goodmoney.mvp.views.HorizChannelView
import com.mints.goodmoney.ui.activitys.AwardActivity
import com.mints.goodmoney.ui.fragment.base.BaseFragment
import com.mints.goodmoney.ui.widgets.countdowntimer.CountDownTimerSupport
import com.mints.goodmoney.ui.widgets.countdowntimer.OnCountDownTimerListener
import com.mints.goodmoney.ui.widgets.seekbar.BubbleUtils
import com.mints.goodmoney.utils.TimeRender
import com.yilan.sdk.player.ylplayer.YLPlayerConfig
import com.yilan.sdk.player.ylplayer.callback.OnPlayerCallBack
import com.yilan.sdk.ui.category.ChannelFragment
import kotlinx.android.synthetic.main.layout_red_bag.*
import kotlinx.android.synthetic.main.layout_red_box.*
import net.grandcentrix.tray.AppPreferences

private val TAG = HorizonChannelFragment::class.java.simpleName

/**
 * 描述：横版视频页面
 * 作者：孟崔广
 * 时间：2020/10/29 13:48
 */
class HorizonChannelFragment : BaseFragment(), HorizChannelView, View.OnClickListener {

    private val horizChannelPresenter by lazy { HorizChannelPresenter() }

    private val ps by lazy { AppPreferences(context) }

    private var channelFragment: ChannelFragment? = null

    // 是否是第一次观看完视频
    private var isFirstWatchVideo = true
    private var isFirstLoadVideo = true // 首次加载视频初始化
    private var rewardDoubleCoin = 0 // 大金币
    private var rewardCoin = 0 // 小金币
    private var isToCreateReward = true // 是否还有剩余红包 服务器返回
    private var isAward = false // 是否可以领金币 本地判断

    // 福袋相关
    private var rope: YoYo.YoYoString? = null
    private var mRedBoxTimer: CountDownTimerSupport? = null
    private var mRedBoxCoin = 0
    private var mRedBoxCoinDouble = 0

    override fun initViewsAndEvents() {
        horizChannelPresenter.attachView(this)

        initChannelFragment()
        initListener()
    }

    override fun getContentViewLayoutID() = R.layout.fragment_horiz_channel

    override fun setUserVisibleHint(isVisibleToUser: Boolean) {
        super.setUserVisibleHint(isVisibleToUser)
        channelFragment?.userVisibleHint = isVisibleToUser
    }

    override fun onHiddenChanged(hidden: Boolean) {
        if (hidden) {
            onPause()
        } else {
            onResume()
        }
        super.onHiddenChanged(hidden)
        channelFragment?.onHiddenChanged(hidden)
    }

    override fun onResume() {
        super.onResume()
        if (AppConfig.fragmentClickFlag == Constant.FRAGMENT_CLICK_TWO) {
            // 调用金币视频信息接口
            horizChannelPresenter.getSmallHomeVedioBaseMsg()

            registerPlayerCallBack()
            channelFragment?.onResume()

            if (isToCreateReward) {
                // 防止界面切换 重置红包动画
                // 好兔视频已加载 且 红包已转满
                if (!cdvvYilanTime.isPlaying) {
                    cdvvYilanTime.startAnim()
                }
            }
        }
    }

    override fun onPause() {
        super.onPause()

        if (AppConfig.fragmentClickFlag == Constant.FRAGMENT_CLICK_TWO) {
            YLPlayerConfig.config().unRegisterPlayerCallback()
        }
        // 福袋动画停止
        stopRedbox()
        // 倒计时红包暂停
        pauseDownloadTime()
        channelFragment?.onPause()

        destoryTimerRedbox()

        if (isToCreateReward) {
            // 防止界面切换 重置红包动画
            // 好兔视频已加载 且 红包已转满
            if (!cdvvYilanTime.isPlaying) {
                cdvvYilanTime.stopAnim()
            }
        }
    }

    override fun onDestroyView() {
        if (rope != null) {
            rope?.stop()
            rope = null
        }

        cdvvYilanTime?.setCountDownVideoListener(null)
        cdvvYilanTime?.onDestroy()
        super.onDestroyView()
    }

    override fun onDestroy() {
        super.onDestroy()
        YLPlayerConfig.config().unRegisterPlayerCallback()
        horizChannelPresenter.detachView()
    }

    override fun onClick(v: View?) {
        when (v?.id) {
            R.id.rl_fragment_main_redbox -> {
                val bundle = Bundle()
                bundle.putInt(Constant.MAIN_CUR_COIN, mRedBoxCoin)
                bundle.putString(Constant.MAIN_CARRIER_TYPE, Constant.CARRIER_BLESSINGBAG)
                bundle.putString(Constant.MAIN_EXTRA_ID, mRedBoxCoinDouble.toString())
                readyGo(AwardActivity::class.java, bundle)
            }
            R.id.cdvvYilanTime -> {
                if (isAward && isToCreateReward) {
                    isAward = false

                    val bundle = Bundle()
                    bundle.putInt(Constant.MAIN_CUR_COIN, rewardCoin)
                    bundle.putString(Constant.MAIN_CARRIER_TYPE, Constant.CARRIER_SMALLHOMEVEDIO)
                    bundle.putString(Constant.MAIN_EXTRA_ID, rewardDoubleCoin.toString())
                    readyGo(AwardActivity::class.java, bundle)
                }
            }
        }
    }

    override fun getHomeVedioMsgFail() {
        tv_fragment_main_redbox.text = "--:--"
        rl_fragment_main_redbox.isClickable = false
    }

    override fun getHomeVedioMsgSuc(data: MainVideoMsgBean) {
        if (activity == null || requireActivity().isFinishing) {
            return
        }

        ps.put(Constant.MAIN_VEDIO_TIME, data.createRewardNeedTime)

        rewardCoin = data.rewardCoin
        rewardDoubleCoin = data.rewardDoubleCoin
        isToCreateReward = data.isToCreateReward

        if (isToCreateReward) {
            // 防止界面切换 重置倒计时
            // 第一次能过 isFirstLoadVedio 判断好兔先加载视频
            if (!isFirstLoadVideo && !cdvvYilanTime.isPlaying && !isAward) {
                cdvvYilanTime?.stopRedbox()
                cdvvYilanTime?.reset()
                cdvvYilanTime?.start()
            }
        } else {
            stopDownloadTime()
        }


        data.blessingBigMsgBean?.let {
            if (it.surplusCount > 0) {
                if (rl_fragment_main_redbox.visibility == View.GONE) {
                    rl_fragment_main_redbox.visibility = View.VISIBLE
                }
                mRedBoxCoin = it.coin
                mRedBoxCoinDouble = it.doubleCoin
                startTimer(it.surplusSeconds.toLong())
            } else {
                stopRedbox()
                rl_fragment_main_redbox.visibility = View.GONE
            }
        }
    }

    /**
     * 红包倒计时初始化
     */
    private fun initTimeView() {
        cdvvYilanTime.setCountDownVideoListener {
            if (isFirstWatchVideo) {
                // 第一次观看完视频提醒用户
                vs_tips.visibility = View.VISIBLE
                Handler(Looper.getMainLooper()).postDelayed({
                    vs_tips.visibility = View.GONE
                }, 3000)
                isFirstWatchVideo = false
            }

            // 转满一圈，可领金币标记
            isAward = true
            cdvvYilanTime?.showRedbox()
            stopDownloadTime()
        }
        val videoTime = ps.getInt(Constant.MAIN_VEDIO_TIME, 30)
        cdvvYilanTime.setTime(videoTime)
        cdvvYilanTime.start()
    }

    private fun initListener() {
        val params = LinearLayout.LayoutParams(LinearLayout.LayoutParams.WRAP_CONTENT, LinearLayout.LayoutParams.WRAP_CONTENT)
        params.setMargins(0, 0, 0, BubbleUtils.dp2px(30))
        cdvvYilanTime.layoutParams = params

        val paramsRedBox = FrameLayout.LayoutParams(FrameLayout.LayoutParams.WRAP_CONTENT, FrameLayout.LayoutParams.WRAP_CONTENT)
        paramsRedBox.setMargins(0, BubbleUtils.dp2px(120), 0, 0)
        paramsRedBox.gravity = Gravity.END
        rl_fragment_main_redbox.layoutParams = paramsRedBox

        cdvvYilanTime.setOnClickListener(this)
        rl_fragment_main_redbox.setOnClickListener(this)
        rl_fragment_main_redbox.isClickable = false
    }

    private fun initChannelFragment() {
        val transaction: FragmentTransaction = childFragmentManager.beginTransaction()
        if (channelFragment == null) {

            channelFragment = ChannelFragment()
            transaction.add(R.id.yilan_fragment_frame_container, channelFragment!!, ChannelFragment::class.java.simpleName)
        } else {
            transaction.show(channelFragment!!)
        }
        transaction.commitAllowingStateLoss()

    }

    /**
     * 倒计时红包暂停
     */
    private fun pauseDownloadTime() {
        cdvvYilanTime?.pause()
    }

    /**
     *用户主动暂时或网络异常结束后 重新加载倒计时红包
     */
    private fun resumeDownloadTime(id: String) {
        if (!TextUtils.isEmpty(id)) {
            if (!isAward) {
                cdvvYilanTime?.resume()
            }
        }
    }

    /**
     * 停止转动
     */
    private fun stopDownloadTime() {
        cdvvYilanTime?.stop()
    }

    /**
     * 显示福袋动画
     */
    fun showRedbox(view: View?) {
        rope = null
        rope = YoYo.with(Techniques.Tada).duration(1000).repeat(-1).playOn(view)
    }

    /**
     * 停止福袋动画
     */
    fun stopRedbox() {
        if (rope != null && rope!!.isRunning) {
            rope?.stop()
            rope = null
        }
    }

    /**
     * 开始福袋定时器
     */
    private fun startTimer(time: Long) {
        if (time > 0) {
            if (rl_fragment_main_redbox.visibility != View.VISIBLE) {
                rl_fragment_main_redbox.visibility = View.VISIBLE
            }
            stopRedbox()



            destoryTimerRedbox()
            mRedBoxTimer = CountDownTimerSupport(time * 1000, 1000)
            rl_fragment_main_redbox.isClickable = false

            mRedBoxTimer?.setOnCountDownTimerListener(object : OnCountDownTimerListener {
                override fun onTick(millisUntilFinished: Long) {
                    if (!requireActivity().isFinishing) {
                        stopRedbox()
                        tv_fragment_main_redbox.text = TimeRender.ms2MS(millisUntilFinished.toInt())
                    }
                }

                override fun onFinish() {
                    if (!requireActivity().isFinishing) {
                        tv_fragment_main_redbox.text = "可拆开"
                        rl_fragment_main_redbox.isClickable = true
                        showRedbox(rl_fragment_main_redbox)
                    }
                }
            })
            mRedBoxTimer?.start()
        } else {
            tv_fragment_main_redbox.text = "可拆开"
            rl_fragment_main_redbox.isClickable = true
            showRedbox(rl_fragment_main_redbox)
        }
    }

    private fun registerPlayerCallBack() {
        // 设置点击的item播放状态,callback返回true标识用户已经处理了event，返回false，标识使用播放器内部逻辑处理event。
        YLPlayerConfig.config().registerPlayerCallBack(object : OnPlayerCallBack {

            override fun onStart(p0: String?, videoid: String, p2: String?) {
                // 防止网络异常时， 第一次加载倒计时红包
                if (isFirstLoadVideo) {
                    isFirstLoadVideo = false
                    initTimeView()
                } else {
                    resumeDownloadTime(videoid)
                }
            }

            override fun onPause(p0: String?, p1: String?, p2: String?) {
                pauseDownloadTime()
            }

            override fun onResume(p0: String?, videoid: String, p2: String?) {
                resumeDownloadTime(videoid)
            }

            override fun onComplete(p0: String?, videoid: String, p2: String?) {

            }

            override fun onLoopComplete(pager: String?, videoID: String, taskID: String?, num: Int) {
                pauseDownloadTime()
            }

            override fun onStuckStart(p0: String?, p1: String?, p2: String?) {
            }

            override fun onStuckEnd(p0: String?, p1: String?, p2: String?) {
            }

            override fun onError(p0: String?, p1: String?, p2: String?) {
                pauseDownloadTime()
            }

            override fun onStop(p0: String?, p1: String?, p2: String?) {
//                pauseDownloadTime()
            }
        })
    }

    private fun destoryTimerRedbox() {
        mRedBoxTimer?.stop()
        mRedBoxTimer?.setOnCountDownTimerListener(null)
        mRedBoxTimer = null
    }
}