package com.mints.goodmoney.ui.fragment

import android.os.Bundle
import androidx.recyclerview.widget.GridLayoutManager
import com.bytedance.sdk.openadsdk.*
import com.mints.goodmoney.R
import com.mints.goodmoney.manager.TtCsjAdManager
import com.mints.goodmoney.mvp.model.DrawVideoBean
import com.mints.goodmoney.mvp.model.KylBean
import com.mints.goodmoney.mvp.presenters.KuYinYuePagePresenter
import com.mints.goodmoney.mvp.views.KuYinYuePageView
import com.mints.goodmoney.ui.activitys.DrawNativeVideoActivity
import com.mints.goodmoney.ui.adapter.KylPageAdapter
import com.mints.goodmoney.ui.fragment.base.LazyLoadBaseFragment
import com.mints.goodmoney.utils.LogUtil
import com.scwang.smartrefresh.layout.api.RefreshLayout
import com.scwang.smartrefresh.layout.listener.OnLoadMoreListener
import com.scwang.smartrefresh.layout.listener.OnRefreshListener
import kotlinx.android.synthetic.main.fragment_main_kyl_page.*

/**
 * 描述：首页列表详情
 * 作者：孟崔广
 */
class KuYinYuePageFragment(private val targetid: String) : LazyLoadBaseFragment(),
        KuYinYuePageView,
        OnRefreshListener,
        OnLoadMoreListener,
        KylPageAdapter.OnItemClickListener {
    private var mTTAdNative: TTAdNative? = null

    private val kuYinYuePagePresenter by lazy { KuYinYuePagePresenter() }

    private lateinit var kylPageAdapter: KylPageAdapter

    private var kylData: MutableList<KylBean.Data> = mutableListOf()
    private var curPage = 1 // 分页
    private val PAGE_SIZE = 6
    private var feedAd: TTFeedAd? = null

    override fun getContentViewLayoutID() = R.layout.fragment_main_kyl_page

    override fun initViewsAndEvents() {
    }

    override fun onFragmentFirstVisible() {
        super.onFragmentFirstVisible()
        kuYinYuePagePresenter.attachView(this)

        mTTAdNative = TTAdSdk.getAdManager().createAdNative(context)

        initRvView()
        initListener()

//        loadListAd()
        getXfPageMsg()
    }

    override fun onDestroy() {
        super.onDestroy()

        kuYinYuePagePresenter.detachView()
    }

    override fun onItemClick(position: Int) {
        if (kylData.size > 0) {
//            val bundle = Bundle()
//            bundle.putString(KylVideoActivity.VIDEO_URL, kylData[position].url)
//            bundle.putString(KylVideoActivity.VIDEO_ID, kylData[position].vedioId)
//            readyGo(KylVideoActivity::class.java, bundle)

            val dataList = arrayListOf<DrawVideoBean>()
            val index = position % PAGE_SIZE // 余数

            for (i in position until PAGE_SIZE * curPage) {
                val curVedioIndex = index / PAGE_SIZE + i
                dataList.add(DrawVideoBean(DrawNativeVideoActivity.TYPE_COMMON_ITEM, null,
                        kylData[curVedioIndex].vedioId,
                        kylData[curVedioIndex].url,
                        kylData[curVedioIndex].pvurl))
            }

            val bundle = Bundle()
            bundle.putParcelableArrayList(DrawNativeVideoActivity.VIDEO_DATA, dataList)
            bundle.putInt(DrawNativeVideoActivity.CURRENT_PAGE, curPage)
            bundle.putString(DrawNativeVideoActivity.TARGET_ID, targetid)
            readyGo(DrawNativeVideoActivity::class.java, bundle)
        }

    }

    override fun onRefresh(refreshLayout: RefreshLayout) {
        curPage = 1
        kylData.clear()
        srl_kyl.resetNoMoreData()
//        loadListAd()
        getXfPageMsg()
    }

    override fun onLoadMore(refreshLayout: RefreshLayout) {
        curPage = ++curPage
//        loadListAd()
        getXfPageMsg()
    }

    override fun getXfPageMsgSuc(data: KylBean) {
        if (::kylPageAdapter.isInitialized) {

//            if (feedAd != null) {
//                for (i in 0..data.data.size - 1) {
//                    if (i == 4) {
//                        val data1 = KylBean.Data()
//                        data1.adBean = feedAd
//                        kylData.add(data1)
//                        continue
//                    }
//                    kylData.add(data.data[i])
//                }
//            } else {
//                kylData.addAll(data.data)
//            }
            kylData.addAll(data.data)

            if (curPage == 1) {
                srl_kyl.finishRefresh(true)
                kylPageAdapter.notifyDataSetChanged()
            } else {
                if (data.data.size < PAGE_SIZE) {
                    srl_kyl.finishLoadMoreWithNoMoreData()
                } else {
                    srl_kyl.finishLoadMore()
                }
                kylPageAdapter.notifyItemChanged(data.data.size)
            }
        }
    }

    override fun getXfPageMsgFail() {
        srl_kyl.finishRefresh(false)
        srl_kyl.finishLoadMore(false)
        curPage = if (curPage == 1) 1 else curPage - 1
    }

    private fun initRvView() {
        val gridLayoutManager = GridLayoutManager(context, 2)
        rvPageKyl.layoutManager = gridLayoutManager
        kylPageAdapter = KylPageAdapter(kylData)
        rvPageKyl.adapter = kylPageAdapter
        kylPageAdapter.setOnItemClickListener(this)
    }

    private fun initListener() {
        srl_kyl.setOnRefreshListener(this)
        srl_kyl.setOnLoadMoreListener(this)
    }

    /**
     * 加载feed广告
     */
    private fun loadListAd() {
        feedAd = null
        val adSlot = AdSlot.Builder()
                .setCodeId(TtCsjAdManager.TT_AD_NATIVEEXPRESS_AWARD)
                .setImageAcceptedSize(640, 320)
                //[start支持模板样式]:需要支持模板广告和原生广告样式的切换，需要调用supportRenderControl和setExpressViewAcceptedSize
                .supportRenderControl()
                .setExpressViewAcceptedSize(500f, 500f)//设置模板宽高（dp）
                .setAdCount(1) //请求广告数量为1到3条
                .build()
        mTTAdNative?.loadFeedAd(adSlot, object : TTAdNative.FeedAdListener {
            override fun onError(code: Int, message: String) {
                LogUtil.d("KuYinYuePageFragment", "code:${code} message:${message}")
                getXfPageMsg()
            }

            override fun onFeedAdLoad(ads: List<TTFeedAd>) {
                if (ads.isEmpty()) {
                    getXfPageMsg()
                    return
                }
                for (ad in ads) {
                    if (ad.imageMode == TTAdConstant.IMAGE_MODE_LARGE_IMG) {
                        feedAd = ad
                    }
                }
                getXfPageMsg()
            }
        })
    }

    private fun getXfPageMsg() {
        kuYinYuePagePresenter.getXfPageMsg(targetid, curPage, PAGE_SIZE)
    }
}