package com.mints.goodmoney.ui.fragment

import android.os.Bundle
import android.view.View
import androidx.fragment.app.FragmentTransaction
import com.chineseall.reader17ksdk.ChineseAllReaderApplication
import com.chineseall.reader17ksdk.callbacks.OnReadCallBack
import com.chineseall.reader17ksdk.feature.main.bookshop.wellchosen.WellChosenFragment
import com.mints.goodmoney.R
import com.mints.goodmoney.common.AppConfig
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.mvp.presenters.BookPresenter
import com.mints.goodmoney.mvp.views.BookView
import com.mints.goodmoney.ui.activitys.AwardActivity
import com.mints.goodmoney.ui.fragment.base.LazyLoadBaseFragment
import com.mints.goodmoney.utils.LogUtil
import com.mints.goodmoney.utils.SpanUtils
import kotlinx.android.synthetic.main.fragment_main_zy.*

/**
 * 描述：听读
 * 作者：孟崔广
 * 时间：2021/04/08 10:55
 */
class ReaderFragment : LazyLoadBaseFragment(), BookView, OnReadCallBack {

    private val wellChosenFragment by lazy { WellChosenFragment("home") }
    private val bookPresenter by lazy { BookPresenter() }

    override fun getContentViewLayoutID() = R.layout.fragment_main_zy

    override fun initViewsAndEvents() {}

    override fun onFragmentFirstVisible() {
        bookPresenter.attachView(this)

        val transaction: FragmentTransaction = supportFragmentManager.beginTransaction()
        transaction.add(R.id.fragment, wellChosenFragment, ReaderFragment::class.java.simpleName)
        transaction.show(wellChosenFragment)
        transaction.commitAllowingStateLoss()

        //间隔30秒 回调一次  间隔任意设置
        ChineseAllReaderApplication.setOnReadCallBack(this, 30 * 1000)
    }

    override fun onFragmentResume() {
        super.onFragmentResume()
        if (AppConfig.fragmentClickFlag == Constant.FRAGMENT_CLICK_ONE) {
            bookPresenter.getReadInfo()
        }
    }

    override fun onDestroy() {
        super.onDestroy()

        ChineseAllReaderApplication.destory()
        bookPresenter.detachView()
    }

    override fun readSecondsSuc(coin: Int) {
        if (coin > 0) {
            val bundle = Bundle()
            bundle.putString(Constant.MAIN_CARRIER_TYPE, Constant.CARRIER_ZHANGYUE)
            bundle.putInt(Constant.MAIN_CUR_COIN, coin)
            readyGo(AwardActivity::class.java, bundle)
        }
    }

    override fun readInfo(sumTime: Int, sumCoin: Int, readTime: Int) {
        //阅读{10}分钟，奖励{xx}金币，已读{x}分钟
        tvZhangContent.visibility = View.VISIBLE
        if (readTime >= sumTime) {
            tvZhangContent.text = "今日阅读任务已完成"
        } else {
            tvZhangContent.text = SpanUtils()
                    .append("阅读").append("${sumTime / 60}").setForegroundColor(mContext.resources.getColor(R.color.color_FF9837)).append("分钟, ")
                    .append("奖励").append("$sumCoin").setForegroundColor(mContext.resources.getColor(R.color.color_cb4a39)).append("金币, ")
                    .append("已读").append("${readTime / 60}").setForegroundColor(mContext.resources.getColor(R.color.color_FF9837)).append("分钟")
                    .create()
        }
    }

    override fun onReceive(map: Map<String, Any>) {
        val time = map.get("time").toString().toInt()
        val seconds = (time / 1000)
        // 阅读5秒以上 保存时长
        if (seconds > 5) {
            bookPresenter.addReadSeconds(seconds)
        }
        LogUtil.d("ReaderFragment", "time:-->${time}")
    }

}