package com.mints.goodmoney.ui.fragment

import android.text.TextUtils
import androidx.fragment.app.FragmentTransaction
import com.fly.scenemodule.fragment.IdiomFragment
import com.mints.goodmoney.R
import com.mints.goodmoney.common.AppConfig
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.manager.UserManager
import com.mints.goodmoney.ui.fragment.base.BaseFragment
import com.mints.goodmoney.ui.fragment.base.LazyLoadBaseFragment
import com.scwang.smartrefresh.layout.api.RefreshLayout
import com.scwang.smartrefresh.layout.listener.OnRefreshListener
import kotlinx.android.synthetic.main.fragment_main_idiom.*
import java.util.*
import kotlin.concurrent.schedule

/**
 * 描述：聚乐云-猜成语
 * 作者：孟崔广
 * 时间：2021/2/23 15:50
 */
class SceneIdiomFragment : BaseFragment(), OnRefreshListener {

    private val idiomFragment by lazy { IdiomFragment.newInstance("") }

    override fun getContentViewLayoutID() = R.layout.fragment_main_idiom

    override fun initViewsAndEvents() {
        srl_idiom.setOnRefreshListener(this)

        val transaction: FragmentTransaction = supportFragmentManager.beginTransaction()
        transaction.add(R.id.flIdiom, idiomFragment, IdiomFragment::class.java.simpleName)
        transaction.show(idiomFragment)
        transaction.commitAllowingStateLoss()
    }

    override fun onHiddenChanged(hidden: Boolean) {
        if (hidden) { // 不在最前端界面显示
            onPause()
        } else { // 重新显示到最前端中
            onResume()
        }
        super.onHiddenChanged(hidden)
    }

    override fun onResume() {
        super.onResume()
        if (AppConfig.fragmentClickFlag == Constant.FRAGMENT_CLICK_FOUR) {
            if (TextUtils.isEmpty(UserManager.getInstance().userID)) {
                // 游客登录
                showToast("请先登录账号")
            } else {
                // 防止界面切换没有刷新
                // 只有用户token失效、登录、手动退出、我的界面-猜成语时 scene_idiom_flag=true
                if (AppConfig.scene_idiom_flag) {
                    AppConfig.scene_idiom_flag = false
                    idiomFragment.refreshData(0)
                }
            }
        }
    }

    override fun onRefresh(refreshLayout: RefreshLayout) {
        Timer().schedule(800) {
            activity?.runOnUiThread {
                srl_idiom.finishRefresh(true)
                idiomFragment.refreshData(0)
            }
        }
    }
}