package com.mints.goodmoney.ui.fragment

import android.content.BroadcastReceiver
import android.content.Context
import android.content.Intent
import android.content.IntentFilter
import android.os.Bundle
import android.text.TextUtils
import android.view.View
import androidx.recyclerview.widget.GridLayoutManager
import com.mints.goodmoney.BuildConfig
import com.mints.goodmoney.R
import com.mints.goodmoney.ad.download.CoralDownload
import com.mints.goodmoney.common.AppConfig
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.common.DeviceInfo
import com.mints.goodmoney.manager.AppTryPlayManager
import com.mints.goodmoney.manager.DownloadApkManager
import com.mints.goodmoney.manager.TrackManager
import com.mints.goodmoney.mvp.model.CpdModelBean
import com.mints.goodmoney.mvp.model.SydCpdListBean
import com.mints.goodmoney.mvp.model.TzTaskBean
import com.mints.goodmoney.mvp.presenters.TaskPresenter
import com.mints.goodmoney.mvp.views.TaskView
import com.mints.goodmoney.service.AppInstallService
import com.mints.goodmoney.ui.activitys.AwardActivity
import com.mints.goodmoney.ui.activitys.TaskCpdActivity
import com.mints.goodmoney.ui.adapter.TaskAdapter
import com.mints.goodmoney.ui.adapter.listener.OnItemChildClickListener
import com.mints.goodmoney.ui.fragment.base.BaseFragment
import com.mints.goodmoney.ui.widgets.dialog.DialogListener
import com.mints.goodmoney.ui.widgets.dialog.TaskCpdDialog
import com.mints.goodmoney.ui.widgets.dialog.TaskDialog
import com.mints.goodmoney.utils.*
import com.mints.goodmoney.utils.rxutil.CommonRxTask
import com.mints.goodmoney.utils.rxutil.RxjavaUtil
import com.scwang.smartrefresh.layout.api.RefreshLayout
import com.scwang.smartrefresh.layout.listener.OnRefreshListener
import com.tz.sdk.coral.ad.CoralAD
import com.tz.sdk.coral.callback.h5.DownloadProcess
import kotlinx.android.synthetic.main.activity_task.*

private val TAG = TaskCpdFragment::class.java.simpleName

class TaskCpdFragment : BaseFragment(), TaskView,
        OnRefreshListener,
        CoralDownload.OnAdLoadListener,
        OnItemChildClickListener,
        DownloadApkManager.OnMyDownloadListener {

    private val taskPresenter by lazy { TaskPresenter() }
    private var mTaskAdapter: TaskAdapter? = null

    private val mFakeTaskList: MutableList<TzTaskBean> = mutableListOf()

    // 任务弹框
    private var taskDialog: TaskDialog? = null
    private var taskCpdDialog: TaskCpdDialog? = null

    // 天卓下载广告请求
    private var mCoralDownload: CoralDownload? = null
    private var mDownloadProcess: DownloadProcess? = null

    // APP下载回调广播
    private var mReceiverBroadcastReceiver: BroadcastReceiver? = null

    // 试完时间不足弹窗
    private var tryTimeOut = false

    // 圣于地第二次拉取重复不拉取
//    private var isTwiceGetCpd = false

    // 圣于地是否是List请求 TODO

    private val outNetIp by lazy { SPUtil.getInstance().getString(Constant.OUT_NET_IP) }

    private var mCoin = 0
    private var needUseTime = -1// 应用试玩时间

    private var shMax = 0 //珊瑚 广告最大填充数
    private var cpdMax = 0 //CPD 广告最大填充数

    @Volatile
    private var shLoadCountTime = 0 // 珊瑚 加载广告次数

    @Volatile
    private var cpdLoadCountTime = 0 // CPD 加载广告次数

    override fun initViewsAndEvents() {
        taskPresenter.attachView(this)

        mCoralDownload = CoralDownload().setOnAdLoadListener(this)

        CacheUtil.clearAllCache()

        initView()
        initListener()

        loadData()
    }

    private fun initView() {
        val gridLayoutManager = GridLayoutManager(activity, 3)
        recy_task.layoutManager = gridLayoutManager
        recy_task.addItemDecoration(SpacesItemDecoration(3, SpacesItemDecoration.px2dp(10f)))
        mTaskAdapter = TaskAdapter(mFakeTaskList, activity!!)
        recy_task.adapter = mTaskAdapter
        recy_task.setItemViewCacheSize(10)
        mTaskAdapter?.setOnItemChildClickListener(this)
    }

    private fun initListener() {
        srl_task.setOnRefreshListener(this)
    }

    override fun onHiddenChanged(hidden: Boolean) {
        if (hidden) { // 不在最前端界面显示
            onPause()
        } else { // 重新显示到最前端中
            onResume()
        }
        super.onHiddenChanged(hidden)
    }

    override fun onResume() {
        super.onResume()

        DownloadApkManager.tryOnceInstallApk()

        try {
            if (needUseTime != -1) {
                refreshDemoTask()
            }
        } catch (e: Exception) {
            LogUtil.e(e.printStackTrace())
        }
    }

    override fun getContentViewLayoutID() = R.layout.activity_task

    override fun getShCpdTimeSuc(time: Int, coin: Int, CPD: Int, CPD_SYD: Int, CPD_ORDER: String?) {
        needUseTime = time
        mCoin = coin
        shMax = CPD
        cpdMax = CPD_SYD

        if ((shMax + cpdMax) <= 0) {
            hideLoading()
//            showToast("今日任务已完成,请明日再试")

            notifyDataAndShowAd()

            // 跳转试玩任务
            if (AppConfig.useAppCpdModelShow) {
                (activity as TaskCpdActivity).selectTwoFragment()
            }
            return
        }

//        isTwiceGetCpd = false
        shLoadCountTime = 0
        cpdLoadCountTime = 0
        mFakeTaskList.clear()

        if (TextUtils.isEmpty(CPD_ORDER)) {
            notifyDataAndShowAd()
            return
        }

        // 珊瑚和CPD展示顺序
        when (CPD_ORDER) {
            "CPD_SYD" -> {
                when {
                    cpdMax > 0 -> {
                        // 拉取数组数据
//                        loadCPDDataList()
                        // 循环拉取数据
                        loadCPDDataCycle()
                    }
                    shMax > 0 -> {
                        loadShDataList()
                    }
                    else -> {
                        notifyDataAndShowAd()
                    }
                }
            }
            "CPD_SH" -> {
                when {
                    shMax > 0 -> {
                        loadShDataList()
                    }
                    cpdMax > 0 -> {
                        loadCPDDataCycle()
                    }
                    else -> {
                        notifyDataAndShowAd()
                    }
                }
            }
            else -> {
                notifyDataAndShowAd()
            }
        }
    }

    private fun loadShDataList() {
        // 珊瑚CPD广告拉取
        for (i in shLoadCountTime until shMax) {
            mCoralDownload?.pull()
        }
    }

    private fun loadCPDDataCycle() {
        // 循环拉取圣于地CPD广告拉取
        for (i in cpdLoadCountTime until cpdMax) {
            loadCPDData()
        }
    }

    private fun loadCPDData() {
        LogUtil.d(TAG, "syd loadCPDData")
        taskPresenter.getCpdDetail(outNetIp)
    }

//    private fun loadCPDDataList() {
//        // 圣于地CPD广告拉取
//        taskPresenter.getCpdListDetail(outNetIp, cpdMax)
//    }

    override fun getCpdModelSuc(dataBean: CpdModelBean.DataBean) {

        for (material in dataBean.materials) {
            // 校验包名、下载apk为空 跳过
            if (TextUtils.isEmpty(material.app_apk_name) || TextUtils.isEmpty(material.app_url)) {
                if (BuildConfig.DEBUG) {
                    LogUtil.d(TAG, "syd getCpdModelSuc 校验包名、下载apk为空 跳过${dataBean.uuid}")
                }
                continue
            }

            val tzTaskBean = TzTaskBean(material.icons, material.description, material.title, false, mCoin, 0, material.app_apk_name)
            tzTaskBean.app_url = material.app_url
            tzTaskBean.trackerBean = material.tracker
            mFakeTaskList.add(tzTaskBean)
        }

        // 圣于地广告 循环完成后去重
        if (cpdLoadCountTime++ >= cpdMax - 1) {

            if (shMax == 0 || shLoadCountTime >= shMax) {
                getCpdRepeatPkg()
            } else {
                // 圣于地拉取完成后 调用珊瑚广告
                loadShDataList()
            }
        }

        LogUtil.d(TAG, "syd getCpdModelSuc $cpdLoadCountTime")
    }


    override fun getCpdModelFail() {
        LogUtil.d(TAG, "syd getCpdModelFail")

        if (cpdLoadCountTime++ >= cpdMax - 1) {

            if (shMax == 0 || shLoadCountTime >= shMax) {
                getCpdRepeatPkg()
            } else {
                // 圣于地拉取完成后 调用珊瑚广告
                loadShDataList()
            }
        }
//        getCpdRepeatPkg()

        LogUtil.d(TAG, "syd getCpdModelFail $cpdLoadCountTime")
    }

    override fun getCpdListModelSuc(dataBean: SydCpdListBean.DataBean) {

        for (material in dataBean.materials) {
            // 校验包名、下载apk为空 跳过
            if (TextUtils.isEmpty(material.app_apk_name) || TextUtils.isEmpty(material.app_url)) {
                if (BuildConfig.DEBUG) {
                    LogUtil.d(TAG, "syd getCpdModelSuc 校验包名、下载apk为空 跳过${dataBean.uuid}")
                }
                continue
            }

            val tzTaskBean = TzTaskBean(material.icons, material.app_name, material.description, false, mCoin, 0, material.app_apk_name)
            tzTaskBean.app_url = material.app_url
            tzTaskBean.trackerListBean = material.tracker
            mFakeTaskList.add(tzTaskBean)
        }

        if (shMax == 0 || shLoadCountTime >= shMax) {
            // 圣于地广告 循环完成后去重
            getCpdRepeatPkg()
        } else {
            cpdLoadCountTime = cpdMax

            // 圣于地拉取完成后 调用珊瑚广告
            loadShDataList()
        }
    }

    override fun onRefresh(refreshLayout: RefreshLayout) {
        onDestroyBroadcastReceiver()

        loadData()
    }

    /**
     * 遍历去重APP包名
     */
    private fun getCpdRepeatPkg() {
//        if (isTwiceGetCpd) {
//            notifyDataAndShowAd()
//            return
//        }

//        cpdLoadCountTime = cpdMax

        RxjavaUtil.executeRxTask<MutableList<TzTaskBean>>(object : CommonRxTask<MutableList<TzTaskBean>>() {
            override fun doInIOThread() {

                val newPkgData = mutableListOf<TzTaskBean>()

                var flag = false

                for (oldTaskBean in mFakeTaskList) {
                    // 珊瑚无须去重操作，直接添加
                    if (oldTaskBean.isShCpd) {
                        newPkgData.add(oldTaskBean)
                    } else {
                        for (newTaskBean in newPkgData) {
                            LogUtil.d(newTaskBean.title)
                            if (!newTaskBean.isShCpd && !oldTaskBean.isShCpd) {
                                flag = newTaskBean.downLoadPkgName == oldTaskBean.downLoadPkgName
                            }
                        }

                        if (!flag) {
                            // 添加未安装app
                            if (!TextUtils.isEmpty(oldTaskBean.downLoadPkgName) && !DeviceInfo.instance.isLoadingPkg(oldTaskBean.downLoadPkgName)) {
                                newPkgData.add(oldTaskBean)
                            }
                        }
                    }
                }

//                for (i in 0 until mFakeTaskList.size) {
//
//                    if (mFakeTaskList[i].isShCpd) {
//                        newPkgData.add(mFakeTaskList[i])
//                    } else {
//                        for (j in 0 until mFakeTaskList.size) {
//                            if (!mFakeTaskList[i].isShCpd && !mFakeTaskList[j].isShCpd) {
//                                // 数据重复
//                                if (j != i && mFakeTaskList[i].downLoadPkgName == mFakeTaskList[j].downLoadPkgName) {
//                                    LogUtil.d(TAG, "syd currentPkgName:" + mFakeTaskList[j].downLoadPkgName)
//
//                                    flag = false
//                                    break
//                                }
//                            }
//                        }
//
//                        if (flag) {
//                            // 添加未安装app
//                            if (!TextUtils.isEmpty(mFakeTaskList[i].downLoadPkgName) && !DeviceInfo.instance.isLoadingPkg(mFakeTaskList[i].downLoadPkgName)) {
////                                cpdLoadCountTime--
//                                newPkgData.add(mFakeTaskList[i])
//                            }
//                        }
//                    }
//                }

                t = newPkgData
            }

            override fun doInUIThread() {
                mFakeTaskList.clear()
                mFakeTaskList.addAll(t)

                notifyDataAndShowAd()

                // 重新获取数据
//                if (cpdLoadCountTime in 1..cpdMax) {
//                    isTwiceGetCpd = true
//
//                    for (i in 0 until cpdLoadCountTime) {
//                        loadCPDData()
//                    }
//                    cpdLoadCountTime = cpdMax - cpdLoadCountTime
//                } else {
//                    notifyDataAndShowAd()
//                }
            }
        })
    }

    private fun notifyDataAndShowAd() {
        hideLoading()
        srl_task.finishRefresh()
        mTaskAdapter?.notifyDataSetChanged()

        if (mFakeTaskList.size == 0) {
            iv_empty.visibility = View.VISIBLE
            return
        } else {
            iv_empty.visibility = View.GONE
        }

        uploadSydImp()
    }

    /**
     * 上报圣于地展示
     */
    private fun uploadSydImp() {

        for (tzTaskBean in mFakeTaskList) {
            if (!tzTaskBean.isShCpd) {

                val trackerBean = tzTaskBean.trackerBean
//                val trackerBean = tzTaskBean.trackerBean
                if (trackerBean != null) {
                    LogUtil.d("CPD -> show")

                    // 上报CPD显示
                    taskPresenter.cmtImp(trackerBean.show[0])
                }
            }
        }
    }

    override fun onLoadSuccess(dataList: MutableList<CoralAD>?) {
        LogUtil.d(TAG, "shanhu onLoadSuccess times")
        dataList?.let {
            for (coralAD in it) {
                val tzTaskBean = TzTaskBean(coralAD.icon, coralAD.title, coralAD.description, true, mCoin, 0, null)
                tzTaskBean.coralAd = coralAD
                mFakeTaskList.add(tzTaskBean)
            }
        }

        // 珊瑚循环完成后 调用圣于地广告
        if (shLoadCountTime++ >= shMax - 1) {
            LogUtil.d(TAG, "shanhu onLoadSuccess")

            if (cpdMax == 0 || cpdLoadCountTime >= cpdMax) {
                getCpdRepeatPkg()
            } else {
                // 珊瑚拉取完成后 调用圣于地广告
                loadCPDDataCycle()
            }

        }

    }

    override fun onLoadFail() {
        // 次数刷新完 且未拿到数据 提示
        if (shLoadCountTime++ >= shMax - 1) {
            if (cpdMax == 0) {
                getCpdRepeatPkg()
                return
            }

//            for (i in 0 until cpdMax) {
//                loadCPDData()
//            }
            loadCPDDataCycle()
        }
    }

    override fun onSDKDownloadStart() {
        taskDialog?.dismiss()

        registerBroad()
    }

    override fun onGetDownloadProcess(downloadProcess: DownloadProcess?) {
        // 点击之后回调下载数据
        mDownloadProcess = downloadProcess

        // 跳转去下载
        val downloadUrl = downloadProcess!!.downloadUrl
        val packageName = downloadProcess.packageName
        DownloadApkManager.setOnMyDownloadListener(this)
        DownloadApkManager.downloadApk(requireActivity(), downloadUrl, packageName)
    }

    override fun onDestroy() {
        mCoralDownload?.destroy()
        mDownloadProcess = null
        DownloadApkManager.destroy()

        onDestroyBroadcastReceiver()

        taskPresenter.detachView()
        super.onDestroy()
    }

    override fun onItemChildClick(view: View?, position: Int) {
        when (mFakeTaskList[position].state) {
            // 0 立即下载, 1 去试玩, 2 领取奖励 3 已领取 4 继续试玩
            0 -> {
                tryTimeOut = false
                if (AppUtil.isOpenUsageStats()) {
                    clickDialog(position)
                } else {
                    AppTryPlayManager.openAppUsageStats(requireActivity())
                }
            }
            1 -> {
                mTaskAdapter?.let {
                    val currentPkgName = mFakeTaskList[it.getPosition()].currentPkgName
                    if (currentPkgName == null) {
                        showToast("任务异常，请重试~")
                        mFakeTaskList[it.getPosition()].state = 0
                        it.notifyItemChanged(it.getPosition())
                    } else {
                        if (AppUtil.checkPackInfo(activity!!, currentPkgName)) {

                            AppTryPlayManager.toTryPlay(currentPkgName)
                        } else {
                            showToast("未找到当前APP、可能被卸载，请重试~")

                            // 重置当前列表状态
                            mFakeTaskList[it.getPosition()].state = 0
                            it.notifyItemChanged(it.getPosition())
                        }
                    }
                }
            }
            2 -> {
                val bundle = Bundle()
                bundle.putInt(Constant.MAIN_CUR_COIN, mCoin)
                mTaskAdapter?.let {
                    if (mFakeTaskList[it.getPosition()].isShCpd) {
                        bundle.putString(Constant.MAIN_CARRIER_TYPE, Constant.CARRIER_CPD)
                    } else {
                        bundle.putString(Constant.MAIN_CARRIER_TYPE, Constant.CARRIER_CPD_SYD)
                    }
                }
                readyGo(AwardActivity::class.java, bundle)

                activity?.finish()
            }
            3 -> {
                showToast("当前任务已完成，试试其他任务吧！")
            }
            4 -> {
                mTaskAdapter?.let {
                    val currentPkgName = mFakeTaskList[it.getPosition()].currentPkgName
                    if (currentPkgName == null) {
                        showToast("任务异常，请重试~")
                        mFakeTaskList[it.getPosition()].state = 0
                        it.notifyItemChanged(it.getPosition())
                    } else {
                        if (AppUtil.checkPackInfo(activity!!, currentPkgName)) {
                            AppTryPlayManager.toTryPlay(currentPkgName)
                        } else {
                            showToast("未找到当前APP、可能被卸载，请重试~")

                            // 重置当前列表状态
                            mFakeTaskList[it.getPosition()].state = 0
                            it.notifyItemChanged(it.getPosition())
                        }
                    }
                }
            }
        }
    }

    private fun clickDialog(position: Int) {
        if (needUseTime == -1) return

        if (mFakeTaskList[position].isShCpd) {
            taskDialog = TaskDialog(requireActivity())
            taskDialog?.show()
            taskDialog?.setData(mFakeTaskList[position].coralAd, needUseTime, mCoin)
        } else {
            taskCpdDialog = TaskCpdDialog(requireActivity(), object : DialogListener() {
                override fun onClick(v: View?) {
                    val trackerBean = mFakeTaskList[position].trackerBean
                    if (trackerBean != null) {
                        LogUtil.d("CPD -> clikc")

                        // 上报CPD点击
                        taskPresenter.cmtImp(trackerBean.clikc[0])
                    }

                    DownloadApkManager.setOnMyDownloadListener(this@TaskCpdFragment)
                    DownloadApkManager.downloadApk(requireActivity(), mFakeTaskList[position].app_url, mFakeTaskList[position].downLoadPkgName)
                }
            })
            taskCpdDialog?.setData(mFakeTaskList[position].title, mFakeTaskList[position].description, mFakeTaskList[position].icon, needUseTime, mCoin)
            taskCpdDialog?.show()
        }
    }


    /**
     * 注册试玩任务监听
     */
    private fun registerBroad() {
        if (mReceiverBroadcastReceiver != null) return

        activity?.startService(Intent(activity, AppInstallService::class.java))

        mReceiverBroadcastReceiver = object : BroadcastReceiver() {
            override fun onReceive(context: Context?, intent: Intent?) {
                if (intent == null) return

                try {
                    taskDialog?.dismiss()
                    taskCpdDialog?.dismiss()

                    val pkg = intent.getStringExtra("pkg")

                    if (mTaskAdapter == null) return

                    val position = mTaskAdapter!!.getPosition()

                    mFakeTaskList[position].currentPkgName = pkg
                    mFakeTaskList[position].state = 1
                    mTaskAdapter!!.notifyItemChanged(position)

                    if (mFakeTaskList[position].isShCpd) {
                        // 上报后台珊瑚安装完成
                        TrackManager.getInstance().saveInstallAppRecord(pkg, mFakeTaskList[position].description, mFakeTaskList[position].icon)

                        // 上报珊瑚安装完成
                        mDownloadProcess?.reportInstallSuccess(false)
                    } else {
                        val trackerBean = mFakeTaskList[position].trackerBean
                        if (trackerBean != null) {
                            // 上报CPD开始安装
                            LogUtil.d("CPD -> install_start")
                            taskPresenter.cmtImp(trackerBean.install_start[0])

                            // 上报CPD安装完成
                            LogUtil.d("CPD -> install_finish")
                            taskPresenter.cmtImp(trackerBean.install_finish[0])
                        }
                    }
                } catch (e: Exception) {
                    e.printStackTrace()
                }
            }
        }

        val intentFilter = IntentFilter()
        intentFilter.addAction(AppInstallService.APP_INSTALL_ACTION)
        activity?.registerReceiver(this.mReceiverBroadcastReceiver, intentFilter)
    }


    /**
     * 刷新高额任务
     */
    private fun refreshDemoTask() {
        mTaskAdapter?.let {
            val position = it.getPosition()
            if (mFakeTaskList.size == 0 || mFakeTaskList[position].state == 3) return

            val currentPkgName = mFakeTaskList[position].currentPkgName
            if (currentPkgName != null) {

                onDestroyBroadcastReceiver()

                // 时间为0
                if (needUseTime == 0) {
                    mFakeTaskList[position].state = 2
                    it.notifyItemChanged(position)

                    if (mFakeTaskList[position].isShCpd) {
                        // 上报珊瑚激活完成
                        mDownloadProcess?.reportAppActivated()
                    } else {
                        val trackerBean = mFakeTaskList[position].trackerBean
                        if (trackerBean != null) {

                            // 上报CPD激活完成
                            LogUtil.d("CPD -> activation")
                            taskPresenter.cmtImp(trackerBean.activation[0])
                        }
                    }
                    return
                }

                if (AppTryPlayManager.getTryPlayIsOK(currentPkgName, needUseTime)) {
                    // 完成试玩任务
                    mFakeTaskList[position].state = 2
                    it.notifyItemChanged(position)


                    if (mFakeTaskList[position].isShCpd) {
                        // 上报珊瑚激活完成
                        mDownloadProcess?.reportAppActivated()
                    } else {
                        val trackerBean = mFakeTaskList[position].trackerBean
                        if (trackerBean != null) {
                            // 上报CPD激活完成
                            LogUtil.d("CPD -> activation")

                            taskPresenter.cmtImp(trackerBean.activation[0])
                        }
                    }

                } else {
                    if (AppTryPlayManager.getTryPlayIsOK(currentPkgName, 5)) {
                        // 试玩时间不足
                        if (tryTimeOut) {
                            return
                        }
                        tryTimeOut = true
                        mFakeTaskList[position].state = 4
                        it.notifyItemChanged(it.getPosition())

                        val bundle = Bundle()
                        bundle.putInt(Constant.MAIN_CUR_COIN, 0)
                        bundle.putString(Constant.MAIN_CARRIER_TYPE, Constant.CARRIER_CPD)
                        readyGo(AwardActivity::class.java, bundle)
                    } else {
                        // 试玩时间不足5秒
                        mFakeTaskList[position].state = 1
                        it.notifyItemChanged(it.getPosition())
                    }
                }
            }
        }
    }

    private fun loadData() {
        taskPresenter.getShCpdTime()
    }

    /**
     * 开始下载
     */
    override fun onDownloadStart() {
        taskDialog?.dismiss()
        taskCpdDialog?.dismiss()

        val position = mTaskAdapter!!.getPosition()
        if (mFakeTaskList[position].isShCpd) {
            // 上报珊瑚开始下载
            mDownloadProcess?.reportDownloadStart(false)
        } else {
            LogUtil.d("CPD -> onDownloadStart")

            val trackerBean = mFakeTaskList[position].trackerBean
            if (trackerBean != null) {
                // 上报CPD下载开始
                taskPresenter.cmtImp(trackerBean.download_start[0])
            }
        }

        registerBroad()
    }

    /**
     * 下载成功
     */
    override fun onDownloadSuccess(path: String) {
        val position = mTaskAdapter!!.getPosition()
        if (mFakeTaskList[position].isShCpd) {
            // 上报珊瑚下载成功
            mDownloadProcess?.reportDownloadSuccess(path, false)
        } else {
            LogUtil.d("CPD -> onDownloadSuccess")

            val trackerBean = mFakeTaskList[position].trackerBean
            if (trackerBean != null) {
                // 上报CPD下载成功
                taskPresenter.cmtImp(trackerBean.download_finish[0])
            }
        }
    }

    private fun onDestroyBroadcastReceiver() {
        if (mReceiverBroadcastReceiver != null) {
            mContext.stopService(Intent(context, AppInstallService::class.java))
            mContext.unregisterReceiver(mReceiverBroadcastReceiver)
            mReceiverBroadcastReceiver = null
        }
    }
}