package com.mints.goodmoney.ui.fragment

import android.os.Bundle
import android.view.View
import androidx.recyclerview.widget.LinearLayoutManager
import com.mints.goodmoney.R
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.common.DeviceInfo
import com.mints.goodmoney.manager.AppTryPlayManager
import com.mints.goodmoney.mvp.model.TaskCpdBean
import com.mints.goodmoney.mvp.model.TzTaskBean
import com.mints.goodmoney.mvp.presenters.TaskCpdHistoryPresenter
import com.mints.goodmoney.mvp.views.TaskCpdHistoryView
import com.mints.goodmoney.ui.activitys.AwardActivity
import com.mints.goodmoney.ui.adapter.TaskCpdHistoryAdapter
import com.mints.goodmoney.ui.adapter.listener.OnItemChildClickListener
import com.mints.goodmoney.ui.fragment.base.LazyLoadBaseFragment
import com.mints.goodmoney.utils.*
import com.mints.goodmoney.utils.rxutil.CommonRxTask
import com.mints.goodmoney.utils.rxutil.RxjavaUtil
import com.scwang.smartrefresh.layout.api.RefreshLayout
import com.scwang.smartrefresh.layout.listener.OnRefreshListener
import kotlinx.android.synthetic.main.activity_task.*

class TaskCpdHistoryFragment : LazyLoadBaseFragment(), TaskCpdHistoryView,
        OnRefreshListener,
        OnItemChildClickListener {

    private val taskCpdHistoryPresenter by lazy { TaskCpdHistoryPresenter() }
    private var mTaskAdapter: TaskCpdHistoryAdapter? = null

    private val mFakeTaskList: MutableList<TzTaskBean> = arrayListOf()

    // 试完时间不足弹窗
    private var tryTimeOut = false

    private var needUseTime = -1

    override fun initViewsAndEvents() {}

    private fun initView() {
        val linearLayoutManager = LinearLayoutManager(activity)
        recy_task.layoutManager = linearLayoutManager
        mTaskAdapter = TaskCpdHistoryAdapter(mFakeTaskList, activity!!)
        recy_task.adapter = mTaskAdapter
        mTaskAdapter?.setOnItemChildClickListener(this)
    }

    override fun onFragmentFirstVisible() {
        super.onFragmentFirstVisible()

        taskCpdHistoryPresenter.attachView(this)

        initView()
        initListener()

        loadData()
    }

    private fun initListener() {
        srl_task.setOnRefreshListener(this)
    }

    override fun onHiddenChanged(hidden: Boolean) {
        if (hidden) { // 不在最前端界面显示
            onPause()
        } else { // 重新显示到最前端中
            onResume()
        }
        super.onHiddenChanged(hidden)
    }

    override fun onResume() {
        super.onResume()

        try {
            if (needUseTime != -1) {
                refreshDemoTask()
            }
        } catch (e: Exception) {
            LogUtil.e(e.printStackTrace())
        }
    }

    override fun getContentViewLayoutID() = R.layout.activity_task

    override fun onRefresh(refreshLayout: RefreshLayout) {
        loadData()
    }

    override fun onDestroyView() {
        taskCpdHistoryPresenter.detachView()
        super.onDestroyView()
    }

    override fun onItemChildClick(view: View?, position: Int) {
        when (mFakeTaskList[position].state) {
            // 1 去试玩, 2 领取奖励 3 已领取 4 继续试玩
            1 -> {
                if (!AppUtil.isOpenUsageStats()) {
                    AppTryPlayManager.openAppUsageStats(requireActivity())
                    return
                }

                mTaskAdapter?.let {
                    val currentPkgName = mFakeTaskList[it.getPosition()].currentPkgName
                    if (currentPkgName == null) {
                        showToast("任务异常，请重试~")
                        mFakeTaskList[it.getPosition()].state = 3
                        it.notifyItemChanged(it.getPosition())
                    } else {
                        if (AppUtil.checkPackInfo(activity!!, currentPkgName)) {

                            AppTryPlayManager.toTryPlay(currentPkgName)
                        } else {
                            showToast("未找到当前APP、可能被卸载，请重试~")

                            // 重置当前列表状态
                            mFakeTaskList[it.getPosition()].state = 3
                            it.notifyItemChanged(it.getPosition())
                        }
                    }
                }
            }
            2 -> {
                val bundle = Bundle()
                bundle.putInt(Constant.MAIN_CUR_COIN, mFakeTaskList[position].coin)
                mTaskAdapter?.let {
                    bundle.putString(Constant.MAIN_CARRIER_TYPE, Constant.CARRIER_CPD_USEAPP)
                }
                bundle.putString(Constant.MAIN_AID, mFakeTaskList[position].aid)
                readyGo(AwardActivity::class.java, bundle)

                mFakeTaskList[position].state = 3
            }
            3 -> {
                showToast("当前任务已完成，试试其他任务吧！")
            }
            4 -> {
                mTaskAdapter?.let {
                    val currentPkgName = mFakeTaskList[it.getPosition()].currentPkgName
                    if (currentPkgName == null) {
                        showToast("任务异常，请重试~")
                        mFakeTaskList[it.getPosition()].state = 3
                        it.notifyItemChanged(it.getPosition())
                    } else {
                        if (AppUtil.checkPackInfo(activity!!, currentPkgName)) {
                            AppTryPlayManager.toTryPlay(currentPkgName)
                        } else {
                            showToast("未找到当前APP、可能被卸载，请重试~")

                            // 重置当前列表状态
                            mFakeTaskList[it.getPosition()].state = 3
                            it.notifyItemChanged(it.getPosition())
                        }
                    }
                }
            }
        }
    }

    /**
     * 刷新高额任务
     */
    private fun refreshDemoTask() {
        mTaskAdapter?.let {
            val position = it.getPosition()
            if (mFakeTaskList[position].state == 3) return

            val currentPkgName = mFakeTaskList[position].currentPkgName
            if (currentPkgName != null) {

                // 时间为0
                if (needUseTime == 0) {
                    mFakeTaskList[position].state = 2
                    it.notifyItemChanged(position)
                }

                if (AppTryPlayManager.getTryPlayIsOK(currentPkgName, needUseTime)) {
                    // 完成试玩任务
                    mFakeTaskList[position].state = 2
                    it.notifyItemChanged(position)

                } else {
                    if (AppTryPlayManager.getTryPlayIsOK(currentPkgName, 5)) {
                        // 试玩时间不足
                        if (tryTimeOut) {
                            return
                        }
                        tryTimeOut = true
                        mFakeTaskList[position].state = 4
                        it.notifyItemChanged(it.getPosition())

                        val bundle = Bundle()
                        bundle.putInt(Constant.MAIN_CUR_COIN, 0)
                        bundle.putString(Constant.MAIN_CARRIER_TYPE, Constant.CARRIER_CPD_USEAPP)
                        readyGo(AwardActivity::class.java, bundle)
                    } else {
                        // 试玩时间不足5秒
                        mFakeTaskList[position].state = 4
                        it.notifyItemChanged(it.getPosition())
                    }
                }
            }
        }
    }

    private fun loadData() {
        taskCpdHistoryPresenter.getCpdUseAppModelMsg()
    }

    override fun getCpdUseAppModelMsgSuc(taskCpdBean: TaskCpdBean) {

        mFakeTaskList.clear()
        needUseTime = taskCpdBean.needSeconds
        for (bean in taskCpdBean.list) {
            mFakeTaskList.add(TzTaskBean(bean.icon, bean.name, bean.coin, 1, bean.pkg, bean.aid))
        }

        // 去除已经安装过的APP
        getCpdRepeatPkg()
    }

    /**
     * 遍历去重APP包名
     */
    private fun getCpdRepeatPkg() {
        RxjavaUtil.executeRxTask<MutableList<TzTaskBean>>(object : CommonRxTask<MutableList<TzTaskBean>>() {
            override fun doInIOThread() {

                val newPkgData = mutableListOf<TzTaskBean>()
                for (i in 0 until mFakeTaskList.size) {

                    // 添加安装过的app
                    if (DeviceInfo.instance.isLoadingPkg(mFakeTaskList[i].currentPkgName)) {
                        newPkgData.add(mFakeTaskList[i])
                    }
                }

                t = newPkgData
            }

            override fun doInUIThread() {
                mFakeTaskList.clear()
                mFakeTaskList.addAll(t)
                notifyDataAndShowAd()
            }
        })

    }

    override fun getCpdUseAppModelMsgFail() {
        notifyDataAndShowAd()
    }

    private fun notifyDataAndShowAd() {
        hideLoading()
        srl_task.finishRefresh()
        mTaskAdapter?.setNeedUseTime(needUseTime)
        mTaskAdapter?.notifyDataSetChanged()

        if (mFakeTaskList.size == 0) {
            iv_empty.visibility = View.VISIBLE
            return
        } else {
            iv_empty.visibility = View.GONE
        }
    }

}