package com.mints.goodmoney.ui.fragment

import android.Manifest
import android.animation.ValueAnimator
import android.graphics.Bitmap
import android.graphics.BitmapFactory
import android.graphics.Color
import android.os.Bundle
import android.text.TextUtils
import android.view.View
import android.widget.AdapterView
import android.widget.ImageView
import androidx.core.content.ContextCompat
import com.daimajia.androidanimations.library.Techniques
import com.daimajia.androidanimations.library.YoYo
import com.mints.goodmoney.MintsApplication
import com.mints.goodmoney.R
import com.mints.goodmoney.common.AppConfig
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.manager.MokuManager
import com.mints.goodmoney.manager.TrackManager
import com.mints.goodmoney.manager.UserManager
import com.mints.goodmoney.mvp.model.ClickTurnBean
import com.mints.goodmoney.mvp.model.TurnBean
import com.mints.goodmoney.mvp.presenters.TurnTablePresenter
import com.mints.goodmoney.mvp.views.TurnTableView
import com.mints.goodmoney.ui.activitys.*
import com.mints.goodmoney.ui.adapter.TurnTableAdapter
import com.mints.goodmoney.ui.fragment.base.BaseFragment
import com.mints.goodmoney.ui.widgets.seekbar.BubbleUtils
import com.mints.goodmoney.ui.widgets.wheelsruf.listener.RotateListener
import com.mints.goodmoney.ui.widgets.wheelsruf.view.WheelSurfView
import com.mints.goodmoney.utils.LogUtil
import com.mints.goodmoney.utils.SpanUtils
import com.mints.library.net.netstatus.NetUtils
import com.tbruyelle.rxpermissions.RxPermissions
import kotlinx.android.synthetic.main.fragment_main_turntable.*
import kotlinx.android.synthetic.main.layout_turn_btn.*
import net.grandcentrix.tray.AppPreferences
import java.util.*
import kotlin.collections.ArrayList
import kotlin.concurrent.schedule

/**
 * 描述：大转盘
 * 作者：孟崔广
 * 时间：2021/3/22 10:20
 */
class TurnTableFragment : BaseFragment(), TurnTableView, AdapterView.OnItemClickListener {

    private val turnTablePresenter by lazy { TurnTablePresenter() }
    private val userManager by lazy { UserManager.getInstance() }
    private val ps by lazy { AppPreferences(context) }

    private var rope: YoYo.YoYoString? = null

    // 转盘
    private val firstColor = "#FF7C00"
    private val secondColor = "#fbaa7e"
    private var desList: MutableList<String> = ArrayList()
    private var colorsArray: MutableList<Int> = ArrayList()
    private var bitmapList: MutableList<Bitmap> = ArrayList()
    private var isTurnTable = true
    private var clickTurnData: ClickTurnBean? = null
    private var turnTableData: TurnBean? = null

    // 第一次拉取的转盘size 若size被改变 需要重置转盘
    private var firstPanSize = 0

    // 提现列表展示
    private var drawcashList: MutableList<String> = mutableListOf()

    override fun getContentViewLayoutID() = R.layout.fragment_main_turntable

    override fun initViewsAndEvents() {
        turnTablePresenter.attachView(this)
        gvTurnTable.onItemClickListener = this
        tvTurnMore.setOnClickListener {
            val activity: MainActivity? = activity as MainActivity?
            activity?.let {
                it.turnDayTask()
            }
        }

        if (!TextUtils.isEmpty(userManager.userID) && !TextUtils.isEmpty(MintsApplication.OAID)) {
            MokuManager.initOaid(MintsApplication.OAID)
        }
    }

    override fun onHiddenChanged(hidden: Boolean) {
        if (hidden) { // 不在最前端界面显示
            onPause()
        } else { // 重新显示到最前端中
            onResume()
        }
        super.onHiddenChanged(hidden)
    }

    override fun onResume() {
        super.onResume()
        if (AppConfig.fragmentClickFlag == Constant.FRAGMENT_CLICK_THREE) {
            if (!TextUtils.isEmpty(userManager.userID)) {
                // 通用
                turnTablePresenter.getTurnMsg()
            } else {
                // 游客登录
                turnTablePresenter.userLogin()
            }
            marqueeView.startFlipping()
        }
    }

    override fun onPause() {
        super.onPause()
        rope?.stop()
        marqueeView.stopFlipping()
    }

    override fun onDestroy() {
        super.onDestroy()

        turnTableView.setRotateListener(null)
        turnTablePresenter.detachView()
    }

    override fun onItemClick(parent: AdapterView<*>?, view: View?, position: Int, id: Long) {
        turnTableData?.let {
            actionPageForType(it.bottoms[position].toOtherKey, position)
        }
    }

    override fun getTurnTableSuc(data: TurnBean) {
        TrackManager.getInstance().getAdWeight()

        if (AppConfig.fragmentClickFlag != Constant.FRAGMENT_CLICK_THREE ||
                activity == null || requireActivity().isFinishing) {
            return
        }

        if (drawcashList.size == 0) {
            turnTablePresenter.cashoutLeaders()
        }

        initTurnView(data)
    }

    override fun cashoutLeadersSuc(data: ArrayList<String>) {
        drawcashList = data
        initMarqueeView()
    }

    override fun clickForTurnSuc(data: ClickTurnBean) {
        if (AppConfig.fragmentClickFlag != Constant.FRAGMENT_CLICK_THREE ||
                activity == null || requireActivity().isFinishing) {
            return
        }

        clickTurnData = data
        val position = data.config.index
        turnTableView.startRotate(bitmapList.size - position + 1)
    }

    private fun initTurnView(data: TurnBean) {
        if (AppConfig.fragmentClickFlag != Constant.FRAGMENT_CLICK_THREE ||
                activity == null || requireActivity().isFinishing) {
            return
        }

        LogUtil.d("initTurnView", "initTurnView")

        turnTableData = data

        if (data.configs.size == 0) {
            showToast("网络数据异常，请联系客服")
            return
        }

        // 大转盘异常校验
        if (firstPanSize == 0) {
            firstPanSize = data.configs.size
        }
        if (firstPanSize != data.configs.size) {
            showToast("大转盘异常，请退出应用，重新进入")
            return
        }

        colorsArray.clear()
        desList.clear()
        bitmapList.clear()
        for (index in 0..data.configs.size - 1) {
            //颜色
            if (index % 2 == 0) {
                colorsArray.add(Color.parseColor(firstColor))
            } else {
                colorsArray.add(Color.parseColor(secondColor))
            }
            //图标
            if (TextUtils.equals(data.configs[index].type, "coin")) {
                bitmapList.add(BitmapFactory.decodeResource(resources, R.mipmap.ic_turn_gold))
            } else {
                bitmapList.add(BitmapFactory.decodeResource(resources, R.mipmap.ic_turn_money))
            }
            //文字
            desList.add(data.configs[index].title)
        }

        //主动旋转一下图片
        bitmapList = WheelSurfView.rotateBitmaps(bitmapList) as ArrayList<Bitmap>
        val build = WheelSurfView.Builder()
                .setmColors(colorsArray.toTypedArray())
                .setmDeses(desList.toTypedArray())
                .setmIcons(bitmapList)
                .setmType(1)
                .setmMinTimes(5)
                .setmTypeNum(data.configs.size)
                .setmTextColor(Color.parseColor("#FFFFFF"))
                .build()
        turnTableView.setConfig(build)
        //添加滚动监听
        turnTableView.setRotateListener(object : RotateListener {
            override fun rotateEnd(position: Int, des: String) {
                isTurnTable = true

                clickTurnData?.let {
                    val bundle = Bundle()
                    bundle.putInt(Constant.MAIN_CUR_COIN, it.config.count)
                    bundle.putString(Constant.MAIN_CARRIER_TYPE, Constant.CARRIER_CHALLENGE_TURN)
                    bundle.putString(Constant.MAIN_EXTRA_ID, it.turntableKey)
                    readyGo(AwardActivity::class.java, bundle)
                }
            }

            override fun rotating(valueAnimator: ValueAnimator) {}
            override fun rotateBefore(goImg: ImageView) {
                if (!NetUtils.isNetworkConnected(context)) {
                    showToast("网络异常,请检测网络")
                    return
                }

                if (data.surplus <= 0) {
                    showToast("抽奖次数已用完")
                    return
                }
                if (isTurnTable) {
                    isTurnTable = false
                    turnTablePresenter.clickForTurn()
                }
            }
        })

        tvHintTurnTable.text = data.titleMsg
        tvTurnTimes.text = SpanUtils()
                .append("本轮抽奖将剩余").setForegroundColor(ContextCompat.getColor(mContext, R.color.black))
                .append(data.surplus.toString()).setFontSize(BubbleUtils.dp2px(28)).setForegroundColor(ContextCompat.getColor(mContext, R.color.color_E72C2B))
                .append("次机会").setForegroundColor(ContextCompat.getColor(mContext, R.color.black))
                .create()
        gvTurnTable.setAdapter(TurnTableAdapter(activity, data.bottoms))

        Timer().schedule(1000) {
            activity?.runOnUiThread {
                rope = YoYo.with(Techniques.Pulse).duration(1000).repeat(-1).playOn(tvTurnMore)
            }
        }
    }

    private fun actionPageForType(toOtherKey: String, position: Int) {
        if (!userManager.userIsLogin()) {
            readyGo(WxLoginActivity::class.java)
            return
        }

        //0-微转，1-珊瑚下载，2-分红，3-鱼丸盒子，4-每日任务
        when (toOtherKey) {
            "0" -> {
                shareArticle()
            }
            "1" -> {
                readyGo(TaskCpdActivity::class.java)
            }
            "2" -> {
                val bundle = Bundle()
                bundle.putInt(Constant.WRAPPER_TYPE, Constant.WRAPPER_TYPE_FRIENDS)
                readyGo(WrapperActivity::class.java, bundle)
            }
            "3" -> {
                gotoMoku()
            }
        }

        turnTableData?.let {
            if (!TextUtils.isEmpty(it.bottoms[position].rewardTitle)) {
                turnTablePresenter.addTurnToOtherMsg(toOtherKey)
            }
        }
    }

    /**
     * 分享文章
     */
    private fun shareArticle() {
        val bundle = Bundle()
        bundle.putInt(Constant.WRAPPER_TYPE, Constant.WRAPPER_TYPE_WZ)
        readyGo(WrapperActivity::class.java, bundle)
    }

    private fun gotoMoku() {
        RxPermissions(requireActivity())
                .request(Manifest.permission.READ_PHONE_STATE,
                        Manifest.permission.READ_EXTERNAL_STORAGE,
                        Manifest.permission.WRITE_EXTERNAL_STORAGE)
                .subscribe { granted: Boolean ->
                    if (granted) {
                        MokuManager.gotoMoku(requireContext())

                        if (ps.getBoolean(Constant.MOKU_FLAG_GUIDE, true)) {
                            readyGo(MokuGuideActivity::class.java)
                            ps.put(Constant.MOKU_FLAG_GUIDE, false)
                        }
                    } else {
                        showMissingPermissionDialog("设备,存储")
                    }
                }
    }

    private fun initMarqueeView() {
        marqueeView.startWithList(drawcashList)
    }
}