package com.mints.goodmoney.ui.widgets

import android.app.Dialog
import android.content.Context
import android.graphics.Bitmap
import android.text.Spanned
import android.text.TextUtils
import android.view.*
import android.widget.CheckBox
import android.widget.ImageView
import android.widget.LinearLayout
import android.widget.TextView
import androidx.viewpager.widget.ViewPager
import cn.sharesdk.framework.Platform
import cn.sharesdk.framework.Platform.ShareParams
import cn.sharesdk.framework.PlatformActionListener
import cn.sharesdk.framework.ShareSDK
import cn.sharesdk.wechat.friends.Wechat
import cn.sharesdk.wechat.moments.WechatMoments
import com.mints.goodmoney.BuildConfig
import com.mints.goodmoney.MintsApplication
import com.mints.goodmoney.R
import com.mints.goodmoney.common.Constant
import com.mints.goodmoney.manager.UserManager
import com.mints.goodmoney.ui.adapter.SharePagerAdapter
import com.mints.goodmoney.ui.widgets.seekbar.BubbleUtils
import com.mints.goodmoney.utils.QRCodeUtil
import com.mints.goodmoney.utils.ToastUtil
import com.mints.library.utils.GlideUtils
import java.util.*
import kotlin.collections.ArrayList
import kotlin.concurrent.schedule

class ShareDialog(context: Context) : Dialog(context, R.style.dialog) {

    private val llDialogShareWx: LinearLayout
    private val llDialogShareQq: LinearLayout
    private val tvDialogShareNext: TextView
    private val tvDialogShareTips: TextView

    private var mOnShareOKListener: OnShareOKListener? = null
    private var mOnShareCompleteListener: OnShareCompleteListener? = null

    private val viewPager: ViewPager
    private val pagerAdapter: SharePagerAdapter
    private val mViews: ArrayList<View>

    private val wechat by lazy { ShareSDK.getPlatform(Wechat.NAME) }
    private val wechatMoments by lazy { ShareSDK.getPlatform(WechatMoments.NAME) }

    init {
        setContentView(R.layout.dialog_share)
        // 设置window属性
        window?.let {
            val lp = it.attributes
            lp.gravity = Gravity.BOTTOM
            lp.width = WindowManager.LayoutParams.MATCH_PARENT
            lp.height = WindowManager.LayoutParams.WRAP_CONTENT
            lp.windowAnimations = R.style.DialogAnimBottom
            it.attributes = lp
        }

        // 设置外部不可关闭
        setCancelable(false)
        setCanceledOnTouchOutside(false)
        setOnKeyListener { _, i, _ ->
            i == KeyEvent.KEYCODE_BACK
        }

        llDialogShareWx = findViewById<View>(R.id.llDialogShareWx) as LinearLayout
        llDialogShareQq = findViewById<View>(R.id.llDialogShareQq) as LinearLayout
        tvDialogShareNext = findViewById<View>(R.id.tvDialogShareNext) as TextView
        tvDialogShareTips = findViewById<View>(R.id.tvDialogShareTips) as TextView

        viewPager = findViewById(R.id.view_pager)
        viewPager.pageMargin = BubbleUtils.dp2px(30)

        val SHARE_URL: String = BuildConfig.MainIp + "wxShare/toShare?shareId=" + UserManager.getInstance().userID
        val QRCode = QRCodeUtil.createQRCode(SHARE_URL, 50)
        val inflater = LayoutInflater.from(context)
        val view1 = inflater.inflate(R.layout.item_share_view, null)
        val view2 = inflater.inflate(R.layout.item_share_view, null)
        view1.findViewById<View>(R.id.item_iv_bg).setBackgroundResource(R.mipmap.bg_share_1)
        view2.findViewById<View>(R.id.item_iv_bg).setBackgroundResource(R.mipmap.bg_share_2)
        view1.findViewById<ImageView>(R.id.item_iv_qrcode).setImageBitmap(QRCode)
        view2.findViewById<ImageView>(R.id.item_iv_qrcode).setImageBitmap(QRCode)

        mViews = arrayListOf()
        mViews.add(view1)
        mViews.add(view2)
        pagerAdapter = SharePagerAdapter(mViews)
        viewPager.adapter = pagerAdapter

        val cb2 = view2.findViewById<CheckBox>(R.id.item_cb_check)
        val cb1 = view1.findViewById<CheckBox>(R.id.item_cb_check)

        cb1.isChecked = true

        viewPager.addOnPageChangeListener(object : ViewPager.OnPageChangeListener {
            override fun onPageScrolled(position: Int, positionOffset: Float, positionOffsetPixels: Int) {
            }

            override fun onPageSelected(position: Int) {
                if (position == 0) {
                    cb1.isChecked = true
                    cb2.isChecked = false
                } else {
                    cb1.isChecked = false
                    cb2.isChecked = true
                }
            }

            override fun onPageScrollStateChanged(state: Int) {}

        })

        llDialogShareWx.setOnClickListener {
            shareWechat()
        }

        llDialogShareQq.setOnClickListener {
            shareWechatFavoite()
        }

        tvDialogShareNext.setOnClickListener {
            dismiss()
        }
    }

    fun setOnShareOKListener(onShareOKListener: OnShareOKListener) {
        mOnShareOKListener = onShareOKListener
    }

    interface OnShareOKListener {
        fun onShareOk()
    }

    fun setOnShareCompleteListener(onShareCompleteListener: OnShareCompleteListener) {
        mOnShareCompleteListener = onShareCompleteListener
    }

    interface OnShareCompleteListener {
        fun onShareComplete()
    }

    fun setShareAvatar(imgSrc: String) {
        mViews.forEach {
            val avatar = it.findViewById<ImageView>(R.id.item_iv_avatar)
            GlideUtils.loadImageViewLoding(context, imgSrc, avatar, R.mipmap.ic_my, R.mipmap.ic_my)
        }
    }

    fun setShareTitle(title: String) {
        mViews.forEach {
            it.findViewById<TextView>(R.id.item_tv_name).text = title
        }
    }

    fun setShareContent(content: String) {
        mViews.forEach {
            it.findViewById<TextView>(R.id.item_tv_info).text = content
        }
    }

    fun setShareContent(content: Spanned) {
        mViews.forEach {
            it.findViewById<TextView>(R.id.item_tv_info).text = content
        }
    }

    fun setShareWithNoWechatFavoiter(flag: Boolean) {
        if (flag) {
            llDialogShareWx.visibility = View.GONE
        }
    }

    fun setShareTips(tips: String) {
        if (!TextUtils.isEmpty(tips)) {
            tvDialogShareTips.visibility = View.VISIBLE
            tvDialogShareTips.text = tips
        }
    }

    private fun shareWechat() {
        val currentItem = viewPager.currentItem
        val child = mViews[currentItem].findViewById<View>(R.id.item_iv_bg)
        child.isDrawingCacheEnabled = true
        child.drawingCacheQuality = View.DRAWING_CACHE_QUALITY_HIGH
        child.buildDrawingCache()
        val bitmap: Bitmap = child.drawingCache

        val wechatSp = ShareParams()
        wechatSp.shareType = Platform.SHARE_IMAGE
        wechatSp.imageData = bitmap

        if (wechat.isClientValid) {
            wechat.platformActionListener = object : PlatformActionListener {
                override fun onComplete(p0: Platform?, p1: Int, p2: HashMap<String, Any>?) {
                    mOnShareCompleteListener?.onShareComplete()
                }

                override fun onError(p0: Platform?, p1: Int, p2: Throwable?) {
                }

                override fun onCancel(p0: Platform?, p1: Int) {
                }
            }

            mOnShareOKListener?.onShareOk()
            wechat.share(wechatSp)
        } else {
            ToastUtil.show(MintsApplication.getContext(), "请先安装微信")
        }

        Timer().schedule(1000) {
            dismiss()
        }
    }

    private fun shareWechatFavoite() {
        val currentItem = viewPager.currentItem
        val child = mViews[currentItem].findViewById<View>(R.id.item_iv_bg)
        child.isDrawingCacheEnabled = true
        child.drawingCacheQuality = View.DRAWING_CACHE_QUALITY_HIGH
        child.buildDrawingCache()
        val bitmap: Bitmap = child.drawingCache

        val wechatSp = ShareParams()
        wechatSp.shareType = Platform.SHARE_IMAGE
        wechatSp.imageData = bitmap

        if (wechatMoments.isClientValid) {
            wechatMoments.platformActionListener = object : PlatformActionListener {
                override fun onComplete(p0: Platform?, p1: Int, p2: HashMap<String, Any>?) {
                    mOnShareCompleteListener?.onShareComplete()
                }

                override fun onError(p0: Platform?, p1: Int, p2: Throwable?) {
                }

                override fun onCancel(p0: Platform?, p1: Int) {
                }
            }

            mOnShareOKListener?.onShareOk()
            wechatMoments.share(wechatSp)
        } else {
            ToastUtil.show(MintsApplication.getContext(), "请先安装微信")
        }

        Timer().schedule(1000) {
            dismiss()
        }
    }

}