package com.mints.goodmoney.utils

import android.app.ActivityManager
import android.app.ActivityManager.RunningTaskInfo
import android.app.Service
import android.app.usage.UsageStats
import android.app.usage.UsageStatsManager
import android.content.Context
import android.content.Intent
import android.content.pm.PackageInfo
import android.content.pm.PackageManager
import android.os.Build
import android.provider.Settings
import com.fly.scenemodule.util.StringUtilMy
import com.mints.goodmoney.BuildConfig
import com.mints.goodmoney.MintsApplication
import java.text.SimpleDateFormat
import java.util.*


/**
 * 描述：应用使用记录权限管理
 * 时间：2020/11/4 11:10
 */
object AppUtil {

    fun getAppName(pkgName: String, context: Context): String {
        var info: PackageInfo? = null
        val pm: PackageManager = context.packageManager
        try {
            info = pm.getPackageInfo(pkgName, PackageManager.GET_ACTIVITIES)
        } catch (e: PackageManager.NameNotFoundException) {
            e.printStackTrace()
        }

        return info?.applicationInfo?.loadLabel(pm).toString()
    }

    /**
     *  是否有应用使用情况权限
     *  @return flag
     */
    fun isHasUsageStats(): Boolean {
        val packageManager: PackageManager = MintsApplication.getContext().packageManager
        val intent = Intent(Settings.ACTION_USAGE_ACCESS_SETTINGS)
        val list = packageManager.queryIntentActivities(intent, PackageManager.MATCH_DEFAULT_ONLY)
        return list.size > 0
    }

    /**
     *  是否开启应用使用情况权限
     *  @return flag
     */
    fun isOpenUsageStats(): Boolean {
        if (Build.VERSION.SDK_INT > Build.VERSION_CODES.LOLLIPOP) {
            val ts = System.currentTimeMillis()
            val usageStatsManager =
                    MintsApplication.getContext().getSystemService(Service.USAGE_STATS_SERVICE) as UsageStatsManager
            val queryUsageStats = usageStatsManager.queryUsageStats(
                    UsageStatsManager.INTERVAL_BEST, 0, ts)
            if (queryUsageStats == null || queryUsageStats.isEmpty()) {
                return false
            }
            return true
        }
        return false
    }

    fun openUsageStats(ctx: Context) {
        val intent = Intent(Settings.ACTION_USAGE_ACCESS_SETTINGS)
        ctx.startActivity(intent)
    }

    fun getAppUseTime(ctx: Context, pkg: String): Long {
        var time = 0L
        try {
            time = getLollipopFGAppUseTime(ctx, pkg)
        } catch (e: Exception) {
            e.printStackTrace()
        }
        return time
    }

    private fun getLollipopFGAppUseTime(ctx: Context, pkg: String): Long {
        try {
            val usageStatsManager = ctx.getSystemService("usagestats") as UsageStatsManager
            val time = System.currentTimeMillis()
            // 过去5分钟内app使用情况
            val queryUsageStats = usageStatsManager.queryUsageStats(UsageStatsManager.INTERVAL_DAILY, time - 5 * 6 * 1000, time)
            var totalTime = 0L
            if (queryUsageStats.size > 0) {
                for (usageStat in queryUsageStats) {
                    if (usageStat.packageName == pkg) {
                        totalTime = usageStat.totalTimeInForeground
                    }

                }
            }
            return totalTime
        } catch (e: Exception) {
            e.printStackTrace()
        }

        return 0L
    }

    fun openThirdApp(ctx: Context, pkg: String) {
        val intent: Intent? = ctx.packageManager.getLaunchIntentForPackage(pkg)
        if (intent != null) {
//            intent.putExtra("type", "-")
            intent.flags = Intent.FLAG_ACTIVITY_NEW_TASK
            ctx.startActivity(intent)
        }
    }

    /**
     * 检查包是否存在
     *
     * @param pkg
     * @return
     */
    fun checkPackInfo(ctx: Context, pkg: String): Boolean {
        var packageInfo: PackageInfo? = null
        try {
            packageInfo = ctx.packageManager.getPackageInfo(pkg, 0)
        } catch (e: PackageManager.NameNotFoundException) {
            e.printStackTrace()
        }
        return packageInfo != null
    }

    fun getTimePkgUsed(paramContext: Context, paramString: String): Int {
        if (StringUtilMy.stringAvalable(paramString) && checkPackInfo(paramContext, paramString) && Build.VERSION.SDK_INT >= 21) {
            val usageStatsManager = paramContext.getSystemService("usagestats") as UsageStatsManager
            var l = System.currentTimeMillis()
            val list = usageStatsManager.queryUsageStats(UsageStatsManager.INTERVAL_BEST, l - 5 * 60 * 1000L, l)
            if (list != null && list.size > 0) for (i in list.indices) {
//                val str = (list[i] as UsageStats).packageName
//                l = (list[i] as UsageStats).totalTimeInForeground

                // 如果当前上次使用时间 小于 当前时间-5分钟，判断合规
                if (paramString == (list[i] as UsageStats).packageName) {
                    return (list[i] as UsageStats).totalTimeInForeground.toInt() / 1000
                }
            }
        }
        return -1
    }

    fun isAppRunning(paramContext: Context, paramString: String): Boolean {
        try {
            val list: List<*> = (paramContext.getSystemService("activity") as ActivityManager).getRunningTasks(100)
            if (list.size <= 0) return false
            val iterator = list.iterator()
            while (iterator.hasNext()) {
                val bool = (iterator.next() as RunningTaskInfo).baseActivity!!.packageName == paramString
                if (bool) return true
            }
        } catch (exception: java.lang.Exception) {
            exception.printStackTrace()
        }
        return false
    }


}